create table Account_ (
	accountId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	parentAccountId int8,
	name varchar(75),
	legalName varchar(75),
	legalId varchar(75),
	legalType varchar(75),
	sicCode varchar(75),
	tickerSymbol varchar(75),
	industry varchar(75),
	type_ varchar(75),
	size_ varchar(75)
)
extent size 16 next size 16
lock mode row;

create table Address (
	uuid_ varchar(75),
	addressId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	street1 varchar(75),
	street2 varchar(75),
	street3 varchar(75),
	city varchar(75),
	zip varchar(75),
	regionId int8,
	countryId int8,
	typeId int,
	mailing boolean,
	primary_ boolean
)
extent size 16 next size 16
lock mode row;

create table AnnouncementsDelivery (
	deliveryId int8 not null primary key,
	companyId int8,
	userId int8,
	type_ varchar(75),
	email boolean,
	sms boolean,
	website boolean
)
extent size 16 next size 16
lock mode row;

create table AnnouncementsEntry (
	uuid_ varchar(75),
	entryId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	title varchar(75),
	content lvarchar,
	url lvarchar,
	type_ varchar(75),
	displayDate datetime YEAR TO FRACTION,
	expirationDate datetime YEAR TO FRACTION,
	priority int,
	alert boolean
)
extent size 16 next size 16
lock mode row;

create table AnnouncementsFlag (
	flagId int8 not null primary key,
	userId int8,
	createDate datetime YEAR TO FRACTION,
	entryId int8,
	value int
)
extent size 16 next size 16
lock mode row;

create table AssetCategory (
	uuid_ varchar(75),
	categoryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	parentCategoryId int8,
	leftCategoryId int8,
	rightCategoryId int8,
	name varchar(75),
	title lvarchar,
	description lvarchar,
	vocabularyId int8
)
extent size 16 next size 16
lock mode row;

create table AssetCategoryProperty (
	categoryPropertyId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	categoryId int8,
	key_ varchar(75),
	value varchar(75)
)
extent size 16 next size 16
lock mode row;

create table AssetEntries_AssetCategories (
	categoryId int8 not null,
	entryId int8 not null,
	primary key (categoryId, entryId)
)
extent size 16 next size 16
lock mode row;

create table AssetEntries_AssetTags (
	entryId int8 not null,
	tagId int8 not null,
	primary key (entryId, tagId)
)
extent size 16 next size 16
lock mode row;

create table AssetEntry (
	entryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	classUuid varchar(75),
	classTypeId int8,
	visible boolean,
	startDate datetime YEAR TO FRACTION,
	endDate datetime YEAR TO FRACTION,
	publishDate datetime YEAR TO FRACTION,
	expirationDate datetime YEAR TO FRACTION,
	mimeType varchar(75),
	title lvarchar,
	description lvarchar,
	summary lvarchar,
	url lvarchar,
	layoutUuid varchar(75),
	height int,
	width int,
	priority float,
	viewCount int
)
extent size 16 next size 16
lock mode row;

create table AssetLink (
	linkId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	entryId1 int8,
	entryId2 int8,
	type_ int,
	weight int
)
extent size 16 next size 16
lock mode row;

create table AssetTag (
	tagId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name varchar(75),
	assetCount int
)
extent size 16 next size 16
lock mode row;

create table AssetTagProperty (
	tagPropertyId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	tagId int8,
	key_ varchar(75),
	value varchar(255)
)
extent size 16 next size 16
lock mode row;

create table AssetTagStats (
	tagStatsId int8 not null primary key,
	tagId int8,
	classNameId int8,
	assetCount int
)
extent size 16 next size 16
lock mode row;

create table AssetVocabulary (
	uuid_ varchar(75),
	vocabularyId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name varchar(75),
	title lvarchar,
	description lvarchar,
	settings_ lvarchar
)
extent size 16 next size 16
lock mode row;

create table BackgroundTask (
	backgroundTaskId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name varchar(75),
	servletContextNames varchar(255),
	taskExecutorClassName varchar(200),
	taskContext text,
	completed boolean,
	completionDate datetime YEAR TO FRACTION,
	status int
)
extent size 16 next size 16
lock mode row;

create table BlogsEntry (
	uuid_ varchar(75),
	entryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	title varchar(150),
	urlTitle varchar(150),
	description lvarchar,
	content text,
	displayDate datetime YEAR TO FRACTION,
	allowPingbacks boolean,
	allowTrackbacks boolean,
	trackbacks text,
	smallImage boolean,
	smallImageId int8,
	smallImageURL lvarchar,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table BlogsStatsUser (
	statsUserId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	entryCount int,
	lastPostDate datetime YEAR TO FRACTION,
	ratingsTotalEntries int,
	ratingsTotalScore float,
	ratingsAverageScore float
)
extent size 16 next size 16
lock mode row;

create table BookmarksEntry (
	uuid_ varchar(75),
	entryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	resourceBlockId int8,
	folderId int8,
	name varchar(255),
	url lvarchar,
	description lvarchar,
	visits int,
	priority int,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table BookmarksFolder (
	uuid_ varchar(75),
	folderId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	resourceBlockId int8,
	parentFolderId int8,
	name varchar(75),
	description lvarchar,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table BrowserTracker (
	browserTrackerId int8 not null primary key,
	userId int8,
	browserKey int8
)
extent size 16 next size 16
lock mode row;

create table CalEvent (
	uuid_ varchar(75),
	eventId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	title varchar(75),
	description lvarchar,
	location lvarchar,
	startDate datetime YEAR TO FRACTION,
	endDate datetime YEAR TO FRACTION,
	durationHour int,
	durationMinute int,
	allDay boolean,
	timeZoneSensitive boolean,
	type_ varchar(75),
	repeating boolean,
	recurrence text,
	remindBy int,
	firstReminder int,
	secondReminder int
)
extent size 16 next size 16
lock mode row;

create table ClassName_ (
	classNameId int8 not null primary key,
	value varchar(200)
)
extent size 16 next size 16
lock mode row;

create table ClusterGroup (
	clusterGroupId int8 not null primary key,
	name varchar(75),
	clusterNodeIds varchar(75),
	wholeCluster boolean
)
extent size 16 next size 16
lock mode row;

create table Company (
	companyId int8 not null primary key,
	accountId int8,
	webId varchar(75),
	key_ text,
	mx varchar(75),
	homeURL lvarchar,
	logoId int8,
	system boolean,
	maxUsers int,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table Contact_ (
	contactId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	accountId int8,
	parentContactId int8,
	emailAddress varchar(75),
	firstName varchar(75),
	middleName varchar(75),
	lastName varchar(75),
	prefixId int,
	suffixId int,
	male boolean,
	birthday datetime YEAR TO FRACTION,
	smsSn varchar(75),
	aimSn varchar(75),
	facebookSn varchar(75),
	icqSn varchar(75),
	jabberSn varchar(75),
	msnSn varchar(75),
	mySpaceSn varchar(75),
	skypeSn varchar(75),
	twitterSn varchar(75),
	ymSn varchar(75),
	employeeStatusId varchar(75),
	employeeNumber varchar(75),
	jobTitle varchar(100),
	jobClass varchar(75),
	hoursOfOperation varchar(75)
)
extent size 16 next size 16
lock mode row;

create table Counter (
	name varchar(75) not null primary key,
	currentId int8
)
extent size 16 next size 16
lock mode row;

create table Country (
	countryId int8 not null primary key,
	name varchar(75),
	a2 varchar(75),
	a3 varchar(75),
	number_ varchar(75),
	idd_ varchar(75),
	zipRequired boolean,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table CyrusUser (
	userId varchar(75) not null primary key,
	password_ varchar(75) not null
)
extent size 16 next size 16
lock mode row;

create table CyrusVirtual (
	emailAddress varchar(75) not null primary key,
	userId varchar(75) not null
)
extent size 16 next size 16
lock mode row;

create table DDLRecord (
	uuid_ varchar(75),
	recordId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	versionUserId int8,
	versionUserName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	DDMStorageId int8,
	recordSetId int8,
	version varchar(75),
	displayIndex int
)
extent size 16 next size 16
lock mode row;

create table DDLRecordSet (
	uuid_ varchar(75),
	recordSetId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	DDMStructureId int8,
	recordSetKey varchar(75),
	name lvarchar,
	description lvarchar,
	minDisplayRows int,
	scope int
)
extent size 16 next size 16
lock mode row;

create table DDLRecordVersion (
	recordVersionId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	DDMStorageId int8,
	recordSetId int8,
	recordId int8,
	version varchar(75),
	displayIndex int,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table DDMContent (
	uuid_ varchar(75),
	contentId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name lvarchar,
	description lvarchar,
	xml text
)
extent size 16 next size 16
lock mode row;

create table DDMStorageLink (
	uuid_ varchar(75),
	storageLinkId int8 not null primary key,
	classNameId int8,
	classPK int8,
	structureId int8
)
extent size 16 next size 16
lock mode row;

create table DDMStructure (
	uuid_ varchar(75),
	structureId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	parentStructureId int8,
	classNameId int8,
	structureKey varchar(75),
	name lvarchar,
	description lvarchar,
	xsd text,
	storageType varchar(75),
	type_ int
)
extent size 16 next size 16
lock mode row;

create table DDMStructureLink (
	structureLinkId int8 not null primary key,
	classNameId int8,
	classPK int8,
	structureId int8
)
extent size 16 next size 16
lock mode row;

create table DDMTemplate (
	uuid_ varchar(75),
	templateId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	templateKey varchar(75),
	name lvarchar,
	description lvarchar,
	type_ varchar(75),
	mode_ varchar(75),
	language varchar(75),
	script text,
	cacheable boolean,
	smallImage boolean,
	smallImageId int8,
	smallImageURL varchar(75)
)
extent size 16 next size 16
lock mode row;

create table DLContent (
	contentId int8 not null primary key,
	groupId int8,
	companyId int8,
	repositoryId int8,
	path_ varchar(255),
	version varchar(75),
	data_ blob,
	size_ int8
)
extent size 16 next size 16
lock mode row;

create table DLFileEntry (
	uuid_ varchar(75),
	fileEntryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	versionUserId int8,
	versionUserName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	repositoryId int8,
	folderId int8,
	name varchar(255),
	extension varchar(75),
	mimeType varchar(75),
	title varchar(255),
	description lvarchar,
	extraSettings text,
	fileEntryTypeId int8,
	version varchar(75),
	size_ int8,
	readCount int,
	smallImageId int8,
	largeImageId int8,
	custom1ImageId int8,
	custom2ImageId int8,
	manualCheckInRequired boolean
)
extent size 16 next size 16
lock mode row;

create table DLFileEntryMetadata (
	uuid_ varchar(75),
	fileEntryMetadataId int8 not null primary key,
	DDMStorageId int8,
	DDMStructureId int8,
	fileEntryTypeId int8,
	fileEntryId int8,
	fileVersionId int8
)
extent size 16 next size 16
lock mode row;

create table DLFileEntryType (
	uuid_ varchar(75),
	fileEntryTypeId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	fileEntryTypeKey varchar(75),
	name lvarchar,
	description lvarchar
)
extent size 16 next size 16
lock mode row;

create table DLFileEntryTypes_DDMStructures (
	structureId int8 not null,
	fileEntryTypeId int8 not null,
	primary key (structureId, fileEntryTypeId)
)
extent size 16 next size 16
lock mode row;

create table DLFileEntryTypes_DLFolders (
	fileEntryTypeId int8 not null,
	folderId int8 not null,
	primary key (fileEntryTypeId, folderId)
)
extent size 16 next size 16
lock mode row;

create table DLFileRank (
	fileRankId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	createDate datetime YEAR TO FRACTION,
	fileEntryId int8,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table DLFileShortcut (
	uuid_ varchar(75),
	fileShortcutId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	repositoryId int8,
	folderId int8,
	toFileEntryId int8,
	active_ boolean,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table DLFileVersion (
	uuid_ varchar(75),
	fileVersionId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	repositoryId int8,
	folderId int8,
	fileEntryId int8,
	extension varchar(75),
	mimeType varchar(75),
	title varchar(255),
	description lvarchar,
	changeLog varchar(75),
	extraSettings text,
	fileEntryTypeId int8,
	version varchar(75),
	size_ int8,
	checksum varchar(75),
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table DLFolder (
	uuid_ varchar(75),
	folderId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	repositoryId int8,
	mountPoint boolean,
	parentFolderId int8,
	name varchar(100),
	description lvarchar,
	lastPostDate datetime YEAR TO FRACTION,
	defaultFileEntryTypeId int8,
	hidden_ boolean,
	overrideFileEntryTypes boolean,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table EmailAddress (
	uuid_ varchar(75),
	emailAddressId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	address varchar(75),
	typeId int,
	primary_ boolean
)
extent size 16 next size 16
lock mode row;

create table ExpandoColumn (
	columnId int8 not null primary key,
	companyId int8,
	tableId int8,
	name varchar(75),
	type_ int,
	defaultData lvarchar,
	typeSettings lvarchar(4096)
)
extent size 16 next size 16
lock mode row;

create table ExpandoRow (
	rowId_ int8 not null primary key,
	companyId int8,
	modifiedDate datetime YEAR TO FRACTION,
	tableId int8,
	classPK int8
)
extent size 16 next size 16
lock mode row;

create table ExpandoTable (
	tableId int8 not null primary key,
	companyId int8,
	classNameId int8,
	name varchar(75)
)
extent size 16 next size 16
lock mode row;

create table ExpandoValue (
	valueId int8 not null primary key,
	companyId int8,
	tableId int8,
	columnId int8,
	rowId_ int8,
	classNameId int8,
	classPK int8,
	data_ lvarchar
)
extent size 16 next size 16
lock mode row;

create table Group_ (
	uuid_ varchar(75),
	groupId int8 not null primary key,
	companyId int8,
	creatorUserId int8,
	classNameId int8,
	classPK int8,
	parentGroupId int8,
	liveGroupId int8,
	treePath varchar(75),
	name varchar(150),
	description lvarchar,
	type_ int,
	typeSettings lvarchar(4096),
	friendlyURL varchar(255),
	site boolean,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table Groups_Orgs (
	groupId int8 not null,
	organizationId int8 not null,
	primary key (groupId, organizationId)
)
extent size 16 next size 16
lock mode row;

create table Groups_Roles (
	groupId int8 not null,
	roleId int8 not null,
	primary key (groupId, roleId)
)
extent size 16 next size 16
lock mode row;

create table Groups_UserGroups (
	groupId int8 not null,
	userGroupId int8 not null,
	primary key (groupId, userGroupId)
)
extent size 16 next size 16
lock mode row;

create table Image (
	imageId int8 not null primary key,
	modifiedDate datetime YEAR TO FRACTION,
	type_ varchar(75),
	height int,
	width int,
	size_ int
)
extent size 16 next size 16
lock mode row;

create table JournalArticle (
	uuid_ varchar(75),
	id_ int8 not null primary key,
	resourcePrimKey int8,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	folderId int8,
	classNameId int8,
	classPK int8,
	articleId varchar(75),
	version float,
	title lvarchar,
	urlTitle varchar(150),
	description lvarchar,
	content text,
	type_ varchar(75),
	structureId varchar(75),
	templateId varchar(75),
	layoutUuid varchar(75),
	displayDate datetime YEAR TO FRACTION,
	expirationDate datetime YEAR TO FRACTION,
	reviewDate datetime YEAR TO FRACTION,
	indexable boolean,
	smallImage boolean,
	smallImageId int8,
	smallImageURL lvarchar,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table JournalArticleImage (
	articleImageId int8 not null primary key,
	groupId int8,
	articleId varchar(75),
	version float,
	elInstanceId varchar(75),
	elName varchar(75),
	languageId varchar(75),
	tempImage boolean
)
extent size 16 next size 16
lock mode row;

create table JournalArticleResource (
	uuid_ varchar(75),
	resourcePrimKey int8 not null primary key,
	groupId int8,
	articleId varchar(75)
)
extent size 16 next size 16
lock mode row;

create table JournalContentSearch (
	contentSearchId int8 not null primary key,
	groupId int8,
	companyId int8,
	privateLayout boolean,
	layoutId int8,
	portletId varchar(200),
	articleId varchar(75)
)
extent size 16 next size 16
lock mode row;

create table JournalFeed (
	uuid_ varchar(75),
	id_ int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	feedId varchar(75),
	name varchar(75),
	description lvarchar,
	type_ varchar(75),
	structureId varchar(75),
	templateId varchar(75),
	rendererTemplateId varchar(75),
	delta int,
	orderByCol varchar(75),
	orderByType varchar(75),
	targetLayoutFriendlyUrl varchar(255),
	targetPortletId varchar(75),
	contentField varchar(75),
	feedFormat varchar(75),
	feedVersion float
)
extent size 16 next size 16
lock mode row;

create table JournalFolder (
	uuid_ varchar(75),
	folderId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	parentFolderId int8,
	name varchar(100),
	description lvarchar,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table Layout (
	uuid_ varchar(75),
	plid int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	privateLayout boolean,
	layoutId int8,
	parentLayoutId int8,
	name lvarchar,
	title lvarchar,
	description lvarchar,
	keywords lvarchar,
	robots lvarchar,
	type_ varchar(75),
	typeSettings lvarchar(4096),
	hidden_ boolean,
	friendlyURL varchar(255),
	iconImage boolean,
	iconImageId int8,
	themeId varchar(75),
	colorSchemeId varchar(75),
	wapThemeId varchar(75),
	wapColorSchemeId varchar(75),
	css text,
	priority int,
	layoutPrototypeUuid varchar(75),
	layoutPrototypeLinkEnabled boolean,
	sourcePrototypeLayoutUuid varchar(75)
)
extent size 16 next size 16
lock mode row;

create table LayoutBranch (
	LayoutBranchId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	layoutSetBranchId int8,
	plid int8,
	name varchar(75),
	description lvarchar,
	master boolean
)
extent size 16 next size 16
lock mode row;

create table LayoutFriendlyURL (
	uuid_ varchar(75),
	layoutFriendlyURLId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	plid int8,
	privateLayout boolean,
	friendlyURL varchar(255),
	languageId varchar(75)
)
extent size 16 next size 16
lock mode row;

create table LayoutPrototype (
	uuid_ varchar(75),
	layoutPrototypeId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name lvarchar,
	description lvarchar,
	settings_ lvarchar,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table LayoutRevision (
	layoutRevisionId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	layoutSetBranchId int8,
	layoutBranchId int8,
	parentLayoutRevisionId int8,
	head boolean,
	major boolean,
	plid int8,
	privateLayout boolean,
	name lvarchar,
	title lvarchar,
	description lvarchar,
	keywords lvarchar,
	robots lvarchar,
	typeSettings lvarchar(4096),
	iconImage boolean,
	iconImageId int8,
	themeId varchar(75),
	colorSchemeId varchar(75),
	wapThemeId varchar(75),
	wapColorSchemeId varchar(75),
	css text,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table LayoutSet (
	layoutSetId int8 not null primary key,
	groupId int8,
	companyId int8,
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	privateLayout boolean,
	logo boolean,
	logoId int8,
	themeId varchar(75),
	colorSchemeId varchar(75),
	wapThemeId varchar(75),
	wapColorSchemeId varchar(75),
	css text,
	pageCount int,
	settings_ text,
	layoutSetPrototypeUuid varchar(75),
	layoutSetPrototypeLinkEnabled boolean
)
extent size 16 next size 16
lock mode row;

create table LayoutSetBranch (
	layoutSetBranchId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	privateLayout boolean,
	name varchar(75),
	description lvarchar,
	master boolean,
	logo boolean,
	logoId int8,
	themeId varchar(75),
	colorSchemeId varchar(75),
	wapThemeId varchar(75),
	wapColorSchemeId varchar(75),
	css text,
	settings_ text,
	layoutSetPrototypeUuid varchar(75),
	layoutSetPrototypeLinkEnabled boolean
)
extent size 16 next size 16
lock mode row;

create table LayoutSetPrototype (
	uuid_ varchar(75),
	layoutSetPrototypeId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name lvarchar,
	description lvarchar,
	settings_ lvarchar,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table ListType (
	listTypeId int not null primary key,
	name varchar(75),
	type_ varchar(75)
)
extent size 16 next size 16
lock mode row;

create table Lock_ (
	uuid_ varchar(75),
	lockId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	className varchar(75),
	key_ varchar(200),
	owner varchar(255),
	inheritable boolean,
	expirationDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table MBBan (
	uuid_ varchar(75),
	banId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	banUserId int8
)
extent size 16 next size 16
lock mode row;

create table MBCategory (
	uuid_ varchar(75),
	categoryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	parentCategoryId int8,
	name varchar(75),
	description lvarchar,
	displayStyle varchar(75),
	threadCount int,
	messageCount int,
	lastPostDate datetime YEAR TO FRACTION,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table MBDiscussion (
	uuid_ varchar(75),
	discussionId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	threadId int8
)
extent size 16 next size 16
lock mode row;

create table MBMailingList (
	uuid_ varchar(75),
	mailingListId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	categoryId int8,
	emailAddress varchar(75),
	inProtocol varchar(75),
	inServerName varchar(75),
	inServerPort int,
	inUseSSL boolean,
	inUserName varchar(75),
	inPassword varchar(75),
	inReadInterval int,
	outEmailAddress varchar(75),
	outCustom boolean,
	outServerName varchar(75),
	outServerPort int,
	outUseSSL boolean,
	outUserName varchar(75),
	outPassword varchar(75),
	allowAnonymous boolean,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table MBMessage (
	uuid_ varchar(75),
	messageId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	categoryId int8,
	threadId int8,
	rootMessageId int8,
	parentMessageId int8,
	subject varchar(75),
	body text,
	format varchar(75),
	anonymous boolean,
	priority float,
	allowPingbacks boolean,
	answer boolean,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table MBStatsUser (
	statsUserId int8 not null primary key,
	groupId int8,
	userId int8,
	messageCount int,
	lastPostDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table MBThread (
	uuid_ varchar(75),
	threadId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	categoryId int8,
	rootMessageId int8,
	rootMessageUserId int8,
	messageCount int,
	viewCount int,
	lastPostByUserId int8,
	lastPostDate datetime YEAR TO FRACTION,
	priority float,
	question boolean,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table MBThreadFlag (
	uuid_ varchar(75),
	threadFlagId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	threadId int8
)
extent size 16 next size 16
lock mode row;

create table MDRAction (
	uuid_ varchar(75),
	actionId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	ruleGroupInstanceId int8,
	name lvarchar,
	description lvarchar,
	type_ varchar(255),
	typeSettings lvarchar(4096)
)
extent size 16 next size 16
lock mode row;

create table MDRRule (
	uuid_ varchar(75),
	ruleId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	ruleGroupId int8,
	name lvarchar,
	description lvarchar,
	type_ varchar(255),
	typeSettings lvarchar(4096)
)
extent size 16 next size 16
lock mode row;

create table MDRRuleGroup (
	uuid_ varchar(75),
	ruleGroupId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name lvarchar,
	description lvarchar
)
extent size 16 next size 16
lock mode row;

create table MDRRuleGroupInstance (
	uuid_ varchar(75),
	ruleGroupInstanceId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	ruleGroupId int8,
	priority int
)
extent size 16 next size 16
lock mode row;

create table MembershipRequest (
	membershipRequestId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	createDate datetime YEAR TO FRACTION,
	comments lvarchar,
	replyComments lvarchar,
	replyDate datetime YEAR TO FRACTION,
	replierUserId int8,
	statusId int
)
extent size 16 next size 16
lock mode row;

create table Organization_ (
	uuid_ varchar(75),
	organizationId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	parentOrganizationId int8,
	treePath lvarchar,
	name varchar(100),
	type_ varchar(75),
	recursable boolean,
	regionId int8,
	countryId int8,
	statusId int,
	comments lvarchar
)
extent size 16 next size 16
lock mode row;

create table OrgGroupRole (
	organizationId int8 not null,
	groupId int8 not null,
	roleId int8 not null,
	primary key (organizationId, groupId, roleId)
)
extent size 16 next size 16
lock mode row;

create table OrgLabor (
	orgLaborId int8 not null primary key,
	organizationId int8,
	typeId int,
	sunOpen int,
	sunClose int,
	monOpen int,
	monClose int,
	tueOpen int,
	tueClose int,
	wedOpen int,
	wedClose int,
	thuOpen int,
	thuClose int,
	friOpen int,
	friClose int,
	satOpen int,
	satClose int
)
extent size 16 next size 16
lock mode row;

create table PasswordPolicy (
	uuid_ varchar(75),
	passwordPolicyId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	defaultPolicy boolean,
	name varchar(75),
	description lvarchar,
	changeable boolean,
	changeRequired boolean,
	minAge int8,
	checkSyntax boolean,
	allowDictionaryWords boolean,
	minAlphanumeric int,
	minLength int,
	minLowerCase int,
	minNumbers int,
	minSymbols int,
	minUpperCase int,
	regex varchar(75),
	history boolean,
	historyCount int,
	expireable boolean,
	maxAge int8,
	warningTime int8,
	graceLimit int,
	lockout boolean,
	maxFailure int,
	lockoutDuration int8,
	requireUnlock boolean,
	resetFailureCount int8,
	resetTicketMaxAge int8
)
extent size 16 next size 16
lock mode row;

create table PasswordPolicyRel (
	passwordPolicyRelId int8 not null primary key,
	passwordPolicyId int8,
	classNameId int8,
	classPK int8
)
extent size 16 next size 16
lock mode row;

create table PasswordTracker (
	passwordTrackerId int8 not null primary key,
	userId int8,
	createDate datetime YEAR TO FRACTION,
	password_ varchar(75)
)
extent size 16 next size 16
lock mode row;

create table Phone (
	uuid_ varchar(75),
	phoneId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	number_ varchar(75),
	extension varchar(75),
	typeId int,
	primary_ boolean
)
extent size 16 next size 16
lock mode row;

create table PluginSetting (
	pluginSettingId int8 not null primary key,
	companyId int8,
	pluginId varchar(75),
	pluginType varchar(75),
	roles lvarchar,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table PollsChoice (
	uuid_ varchar(75),
	choiceId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	questionId int8,
	name varchar(75),
	description lvarchar
)
extent size 16 next size 16
lock mode row;

create table PollsQuestion (
	uuid_ varchar(75),
	questionId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	title lvarchar,
	description lvarchar,
	expirationDate datetime YEAR TO FRACTION,
	lastVoteDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table PollsVote (
	uuid_ varchar(75),
	voteId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	questionId int8,
	choiceId int8,
	voteDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table PortalPreferences (
	portalPreferencesId int8 not null primary key,
	ownerId int8,
	ownerType int,
	preferences text
)
extent size 16 next size 16
lock mode row;

create table Portlet (
	id_ int8 not null primary key,
	companyId int8,
	portletId varchar(200),
	roles lvarchar,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table PortletItem (
	portletItemId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name varchar(75),
	portletId varchar(200),
	classNameId int8
)
extent size 16 next size 16
lock mode row;

create table PortletPreferences (
	portletPreferencesId int8 not null primary key,
	ownerId int8,
	ownerType int,
	plid int8,
	portletId varchar(200),
	preferences text
)
extent size 16 next size 16
lock mode row;

create table RatingsEntry (
	entryId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	score float
)
extent size 16 next size 16
lock mode row;

create table RatingsStats (
	statsId int8 not null primary key,
	classNameId int8,
	classPK int8,
	totalEntries int,
	totalScore float,
	averageScore float
)
extent size 16 next size 16
lock mode row;

create table Region (
	regionId int8 not null primary key,
	countryId int8,
	regionCode varchar(75),
	name varchar(75),
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table Release_ (
	releaseId int8 not null primary key,
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	servletContextName varchar(75),
	buildNumber int,
	buildDate datetime YEAR TO FRACTION,
	verified boolean,
	state_ int,
	testString lvarchar(1024)
)
extent size 16 next size 16
lock mode row;

create table Repository (
	uuid_ varchar(75),
	repositoryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	name varchar(75),
	description lvarchar,
	portletId varchar(200),
	typeSettings lvarchar(4096),
	dlFolderId int8
)
extent size 16 next size 16
lock mode row;

create table RepositoryEntry (
	uuid_ varchar(75),
	repositoryEntryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	repositoryId int8,
	mappedId varchar(75),
	manualCheckInRequired boolean
)
extent size 16 next size 16
lock mode row;

create table ResourceAction (
	resourceActionId int8 not null primary key,
	name varchar(255),
	actionId varchar(75),
	bitwiseValue int8
)
extent size 16 next size 16
lock mode row;

create table ResourceBlock (
	resourceBlockId int8 not null primary key,
	companyId int8,
	groupId int8,
	name varchar(75),
	permissionsHash varchar(75),
	referenceCount int8
)
extent size 16 next size 16
lock mode row;

create table ResourceBlockPermission (
	resourceBlockPermissionId int8 not null primary key,
	resourceBlockId int8,
	roleId int8,
	actionIds int8
)
extent size 16 next size 16
lock mode row;

create table ResourcePermission (
	resourcePermissionId int8 not null primary key,
	companyId int8,
	name varchar(255),
	scope int,
	primKey varchar(255),
	roleId int8,
	ownerId int8,
	actionIds int8
)
extent size 16 next size 16
lock mode row;

create table ResourceTypePermission (
	resourceTypePermissionId int8 not null primary key,
	companyId int8,
	groupId int8,
	name varchar(75),
	roleId int8,
	actionIds int8
)
extent size 16 next size 16
lock mode row;

create table Role_ (
	uuid_ varchar(75),
	roleId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	name varchar(75),
	title lvarchar,
	description lvarchar,
	type_ int,
	subtype varchar(75)
)
extent size 16 next size 16
lock mode row;

create table SCFrameworkVersi_SCProductVers (
	frameworkVersionId int8 not null,
	productVersionId int8 not null,
	primary key (frameworkVersionId, productVersionId)
)
extent size 16 next size 16
lock mode row;

create table SCFrameworkVersion (
	frameworkVersionId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name varchar(75),
	url lvarchar,
	active_ boolean,
	priority int
)
extent size 16 next size 16
lock mode row;

create table SCLicense (
	licenseId int8 not null primary key,
	name varchar(75),
	url lvarchar,
	openSource boolean,
	active_ boolean,
	recommended boolean
)
extent size 16 next size 16
lock mode row;

create table SCLicenses_SCProductEntries (
	licenseId int8 not null,
	productEntryId int8 not null,
	primary key (licenseId, productEntryId)
)
extent size 16 next size 16
lock mode row;

create table SCProductEntry (
	productEntryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name varchar(75),
	type_ varchar(75),
	tags varchar(255),
	shortDescription lvarchar,
	longDescription lvarchar,
	pageURL lvarchar,
	author varchar(75),
	repoGroupId varchar(75),
	repoArtifactId varchar(75)
)
extent size 16 next size 16
lock mode row;

create table SCProductScreenshot (
	productScreenshotId int8 not null primary key,
	companyId int8,
	groupId int8,
	productEntryId int8,
	thumbnailId int8,
	fullImageId int8,
	priority int
)
extent size 16 next size 16
lock mode row;

create table SCProductVersion (
	productVersionId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	productEntryId int8,
	version varchar(75),
	changeLog lvarchar,
	downloadPageURL lvarchar,
	directDownloadURL varchar(2000),
	repoStoreArtifact boolean
)
extent size 16 next size 16
lock mode row;

create table ServiceComponent (
	serviceComponentId int8 not null primary key,
	buildNamespace varchar(75),
	buildNumber int8,
	buildDate int8,
	data_ text
)
extent size 16 next size 16
lock mode row;

create table Shard (
	shardId int8 not null primary key,
	classNameId int8,
	classPK int8,
	name varchar(75)
)
extent size 16 next size 16
lock mode row;

create table ShoppingCart (
	cartId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	itemIds lvarchar,
	couponCodes varchar(75),
	altShipping int,
	insure boolean
)
extent size 16 next size 16
lock mode row;

create table ShoppingCategory (
	categoryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	parentCategoryId int8,
	name varchar(75),
	description lvarchar
)
extent size 16 next size 16
lock mode row;

create table ShoppingCoupon (
	couponId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	code_ varchar(75),
	name varchar(75),
	description lvarchar,
	startDate datetime YEAR TO FRACTION,
	endDate datetime YEAR TO FRACTION,
	active_ boolean,
	limitCategories lvarchar,
	limitSkus lvarchar,
	minOrder float,
	discount float,
	discountType varchar(75)
)
extent size 16 next size 16
lock mode row;

create table ShoppingItem (
	itemId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	categoryId int8,
	sku varchar(75),
	name varchar(200),
	description lvarchar,
	properties lvarchar,
	fields_ boolean,
	fieldsQuantities lvarchar,
	minQuantity int,
	maxQuantity int,
	price float,
	discount float,
	taxable boolean,
	shipping float,
	useShippingFormula boolean,
	requiresShipping boolean,
	stockQuantity int,
	featured_ boolean,
	sale_ boolean,
	smallImage boolean,
	smallImageId int8,
	smallImageURL lvarchar,
	mediumImage boolean,
	mediumImageId int8,
	mediumImageURL lvarchar,
	largeImage boolean,
	largeImageId int8,
	largeImageURL lvarchar
)
extent size 16 next size 16
lock mode row;

create table ShoppingItemField (
	itemFieldId int8 not null primary key,
	itemId int8,
	name varchar(75),
	values_ lvarchar,
	description lvarchar
)
extent size 16 next size 16
lock mode row;

create table ShoppingItemPrice (
	itemPriceId int8 not null primary key,
	itemId int8,
	minQuantity int,
	maxQuantity int,
	price float,
	discount float,
	taxable boolean,
	shipping float,
	useShippingFormula boolean,
	status int
)
extent size 16 next size 16
lock mode row;

create table ShoppingOrder (
	orderId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	number_ varchar(75),
	tax float,
	shipping float,
	altShipping varchar(75),
	requiresShipping boolean,
	insure boolean,
	insurance float,
	couponCodes varchar(75),
	couponDiscount float,
	billingFirstName varchar(75),
	billingLastName varchar(75),
	billingEmailAddress varchar(75),
	billingCompany varchar(75),
	billingStreet varchar(75),
	billingCity varchar(75),
	billingState varchar(75),
	billingZip varchar(75),
	billingCountry varchar(75),
	billingPhone varchar(75),
	shipToBilling boolean,
	shippingFirstName varchar(75),
	shippingLastName varchar(75),
	shippingEmailAddress varchar(75),
	shippingCompany varchar(75),
	shippingStreet varchar(75),
	shippingCity varchar(75),
	shippingState varchar(75),
	shippingZip varchar(75),
	shippingCountry varchar(75),
	shippingPhone varchar(75),
	ccName varchar(75),
	ccType varchar(75),
	ccNumber varchar(75),
	ccExpMonth int,
	ccExpYear int,
	ccVerNumber varchar(75),
	comments lvarchar,
	ppTxnId varchar(75),
	ppPaymentStatus varchar(75),
	ppPaymentGross float,
	ppReceiverEmail varchar(75),
	ppPayerEmail varchar(75),
	sendOrderEmail boolean,
	sendShippingEmail boolean
)
extent size 16 next size 16
lock mode row;

create table ShoppingOrderItem (
	orderItemId int8 not null primary key,
	orderId int8,
	itemId varchar(75),
	sku varchar(75),
	name varchar(200),
	description lvarchar,
	properties lvarchar,
	price float,
	quantity int,
	shippedDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table SocialActivity (
	activityId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	createDate int8,
	activitySetId int8,
	mirrorActivityId int8,
	classNameId int8,
	classPK int8,
	parentClassNameId int8,
	parentClassPK int8,
	type_ int,
	extraData lvarchar,
	receiverUserId int8
)
extent size 16 next size 16
lock mode row;

create table SocialActivityAchievement (
	activityAchievementId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	createDate int8,
	name varchar(75),
	firstInGroup boolean
)
extent size 16 next size 16
lock mode row;

create table SocialActivityCounter (
	activityCounterId int8 not null primary key,
	groupId int8,
	companyId int8,
	classNameId int8,
	classPK int8,
	name varchar(75),
	ownerType int,
	currentValue int,
	totalValue int,
	graceValue int,
	startPeriod int,
	endPeriod int,
	active_ boolean
)
extent size 16 next size 16
lock mode row;

create table SocialActivityLimit (
	activityLimitId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	classNameId int8,
	classPK int8,
	activityType int,
	activityCounterName varchar(75),
	value varchar(75)
)
extent size 16 next size 16
lock mode row;

create table SocialActivitySet (
	activitySetId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	createDate int8,
	modifiedDate int8,
	classNameId int8,
	classPK int8,
	type_ int,
	extraData lvarchar,
	activityCount int
)
extent size 16 next size 16
lock mode row;

create table SocialActivitySetting (
	activitySettingId int8 not null primary key,
	groupId int8,
	companyId int8,
	classNameId int8,
	activityType int,
	name varchar(75),
	value lvarchar(1024)
)
extent size 16 next size 16
lock mode row;

create table SocialRelation (
	uuid_ varchar(75),
	relationId int8 not null primary key,
	companyId int8,
	createDate int8,
	userId1 int8,
	userId2 int8,
	type_ int
)
extent size 16 next size 16
lock mode row;

create table SocialRequest (
	uuid_ varchar(75),
	requestId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	createDate int8,
	modifiedDate int8,
	classNameId int8,
	classPK int8,
	type_ int,
	extraData lvarchar,
	receiverUserId int8,
	status int
)
extent size 16 next size 16
lock mode row;

create table Subscription (
	subscriptionId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	frequency varchar(75)
)
extent size 16 next size 16
lock mode row;

create table SystemEvent (
	systemEventId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	classUuid varchar(75),
	type_ int,
	extraData text
)
extent size 16 next size 16
lock mode row;

create table Team (
	teamId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	groupId int8,
	name varchar(75),
	description lvarchar
)
extent size 16 next size 16
lock mode row;

create table Ticket (
	ticketId int8 not null primary key,
	companyId int8,
	createDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	key_ varchar(75),
	type_ int,
	extraInfo text,
	expirationDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table TrashEntry (
	entryId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	typeSettings lvarchar(4096),
	status int
)
extent size 16 next size 16
lock mode row;

create table TrashVersion (
	versionId int8 not null primary key,
	entryId int8,
	classNameId int8,
	classPK int8,
	status int
)
extent size 16 next size 16
lock mode row;

create table User_ (
	uuid_ varchar(75),
	userId int8 not null primary key,
	companyId int8,
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	defaultUser boolean,
	contactId int8,
	password_ varchar(75),
	passwordEncrypted boolean,
	passwordReset boolean,
	passwordModifiedDate datetime YEAR TO FRACTION,
	digest varchar(255),
	reminderQueryQuestion varchar(75),
	reminderQueryAnswer varchar(75),
	graceLoginCount int,
	screenName varchar(75),
	emailAddress varchar(75),
	facebookId int8,
	ldapServerId int8,
	openId lvarchar(1024),
	portraitId int8,
	languageId varchar(75),
	timeZoneId varchar(75),
	greeting varchar(255),
	comments lvarchar,
	firstName varchar(75),
	middleName varchar(75),
	lastName varchar(75),
	jobTitle varchar(100),
	loginDate datetime YEAR TO FRACTION,
	loginIP varchar(75),
	lastLoginDate datetime YEAR TO FRACTION,
	lastLoginIP varchar(75),
	lastFailedLoginDate datetime YEAR TO FRACTION,
	failedLoginAttempts int,
	lockout boolean,
	lockoutDate datetime YEAR TO FRACTION,
	agreedToTermsOfUse boolean,
	emailAddressVerified boolean,
	status int
)
extent size 16 next size 16
lock mode row;

create table UserGroup (
	uuid_ varchar(75),
	userGroupId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	parentUserGroupId int8,
	name varchar(75),
	description lvarchar,
	addedByLDAPImport boolean
)
extent size 16 next size 16
lock mode row;

create table UserGroupGroupRole (
	userGroupId int8 not null,
	groupId int8 not null,
	roleId int8 not null,
	primary key (userGroupId, groupId, roleId)
)
extent size 16 next size 16
lock mode row;

create table UserGroupRole (
	userId int8 not null,
	groupId int8 not null,
	roleId int8 not null,
	primary key (userId, groupId, roleId)
)
extent size 16 next size 16
lock mode row;

create table UserGroups_Teams (
	teamId int8 not null,
	userGroupId int8 not null,
	primary key (teamId, userGroupId)
)
extent size 16 next size 16
lock mode row;

create table UserIdMapper (
	userIdMapperId int8 not null primary key,
	userId int8,
	type_ varchar(75),
	description varchar(75),
	externalUserId varchar(75)
)
extent size 16 next size 16
lock mode row;

create table UserNotificationEvent (
	uuid_ varchar(75),
	userNotificationEventId int8 not null primary key,
	companyId int8,
	userId int8,
	type_ varchar(75),
	timestamp int8,
	deliverBy int8,
	delivered boolean,
	payload text,
	archived boolean
)
extent size 16 next size 16
lock mode row;

create table Users_Groups (
	groupId int8 not null,
	userId int8 not null,
	primary key (groupId, userId)
)
extent size 16 next size 16
lock mode row;

create table Users_Orgs (
	organizationId int8 not null,
	userId int8 not null,
	primary key (organizationId, userId)
)
extent size 16 next size 16
lock mode row;

create table Users_Roles (
	roleId int8 not null,
	userId int8 not null,
	primary key (roleId, userId)
)
extent size 16 next size 16
lock mode row;

create table Users_Teams (
	teamId int8 not null,
	userId int8 not null,
	primary key (teamId, userId)
)
extent size 16 next size 16
lock mode row;

create table Users_UserGroups (
	userId int8 not null,
	userGroupId int8 not null,
	primary key (userId, userGroupId)
)
extent size 16 next size 16
lock mode row;

create table UserTracker (
	userTrackerId int8 not null primary key,
	companyId int8,
	userId int8,
	modifiedDate datetime YEAR TO FRACTION,
	sessionId varchar(200),
	remoteAddr varchar(75),
	remoteHost varchar(75),
	userAgent varchar(200)
)
extent size 16 next size 16
lock mode row;

create table UserTrackerPath (
	userTrackerPathId int8 not null primary key,
	userTrackerId int8,
	path_ lvarchar,
	pathDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table VirtualHost (
	virtualHostId int8 not null primary key,
	companyId int8,
	layoutSetId int8,
	hostname varchar(75)
)
extent size 16 next size 16
lock mode row;

create table WebDAVProps (
	webDavPropsId int8 not null primary key,
	companyId int8,
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	props text
)
extent size 16 next size 16
lock mode row;

create table Website (
	uuid_ varchar(75),
	websiteId int8 not null primary key,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	url lvarchar,
	typeId int,
	primary_ boolean
)
extent size 16 next size 16
lock mode row;

create table WikiNode (
	uuid_ varchar(75),
	nodeId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	name varchar(75),
	description lvarchar,
	lastPostDate datetime YEAR TO FRACTION,
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table WikiPage (
	uuid_ varchar(75),
	pageId int8 not null primary key,
	resourcePrimKey int8,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	nodeId int8,
	title varchar(255),
	version float,
	minorEdit boolean,
	content text,
	summary lvarchar,
	format varchar(75),
	head boolean,
	parentTitle varchar(255),
	redirectTitle varchar(255),
	status int,
	statusByUserId int8,
	statusByUserName varchar(75),
	statusDate datetime YEAR TO FRACTION
)
extent size 16 next size 16
lock mode row;

create table WikiPageResource (
	uuid_ varchar(75),
	resourcePrimKey int8 not null primary key,
	nodeId int8,
	title varchar(255)
)
extent size 16 next size 16
lock mode row;

create table WorkflowDefinitionLink (
	workflowDefinitionLinkId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	typePK int8,
	workflowDefinitionName varchar(75),
	workflowDefinitionVersion int
)
extent size 16 next size 16
lock mode row;

create table WorkflowInstanceLink (
	workflowInstanceLinkId int8 not null primary key,
	groupId int8,
	companyId int8,
	userId int8,
	userName varchar(75),
	createDate datetime YEAR TO FRACTION,
	modifiedDate datetime YEAR TO FRACTION,
	classNameId int8,
	classPK int8,
	workflowInstanceId int8
)
extent size 16 next size 16
lock mode row;


insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (1, 'canada', 'CA', 'CAN', '124', '001', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (2, 'china', 'CN', 'CHN', '156', '086', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (3, 'france', 'FR', 'FRA', '250', '033', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (4, 'germany', 'DE', 'DEU', '276', '049', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (5, 'hong-kong', 'HK', 'HKG', '344', '852', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (6, 'hungary', 'HU', 'HUN', '348', '036', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (7, 'israel', 'IL', 'ISR', '376', '972', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (8, 'italy', 'IT', 'ITA', '380', '039', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (9, 'japan', 'JP', 'JPN', '392', '081', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (10, 'south-korea', 'KR', 'KOR', '410', '082', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (11, 'netherlands', 'NL', 'NLD', '528', '031', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (12, 'portugal', 'PT', 'PRT', '620', '351', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (13, 'russia', 'RU', 'RUS', '643', '007', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (14, 'singapore', 'SG', 'SGP', '702', '065', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (15, 'spain', 'ES', 'ESP', '724', '034', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (16, 'turkey', 'TR', 'TUR', '792', '090', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (17, 'vietnam', 'VN', 'VNM', '704', '084', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (18, 'united-kingdom', 'GB', 'GBR', '826', '044', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (19, 'united-states', 'US', 'USA', '840', '001', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (20, 'afghanistan', 'AF', 'AFG', '4', '093', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (21, 'albania', 'AL', 'ALB', '8', '355', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (22, 'algeria', 'DZ', 'DZA', '12', '213', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (23, 'american-samoa', 'AS', 'ASM', '16', '684', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (24, 'andorra', 'AD', 'AND', '20', '376', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (25, 'angola', 'AO', 'AGO', '24', '244', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (26, 'anguilla', 'AI', 'AIA', '660', '264', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (27, 'antarctica', 'AQ', 'ATA', '10', '672', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (28, 'antigua-barbuda', 'AG', 'ATG', '28', '268', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (29, 'argentina', 'AR', 'ARG', '32', '054', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (30, 'armenia', 'AM', 'ARM', '51', '374', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (31, 'aruba', 'AW', 'ABW', '533', '297', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (32, 'australia', 'AU', 'AUS', '36', '061', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (33, 'austria', 'AT', 'AUT', '40', '043', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (34, 'azerbaijan', 'AZ', 'AZE', '31', '994', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (35, 'bahamas', 'BS', 'BHS', '44', '242', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (36, 'bahrain', 'BH', 'BHR', '48', '973', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (37, 'bangladesh', 'BD', 'BGD', '50', '880', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (38, 'barbados', 'BB', 'BRB', '52', '246', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (39, 'belarus', 'BY', 'BLR', '112', '375', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (40, 'belgium', 'BE', 'BEL', '56', '032', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (41, 'belize', 'BZ', 'BLZ', '84', '501', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (42, 'benin', 'BJ', 'BEN', '204', '229', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (43, 'bermuda', 'BM', 'BMU', '60', '441', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (44, 'bhutan', 'BT', 'BTN', '64', '975', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (45, 'bolivia', 'BO', 'BOL', '68', '591', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (46, 'bosnia-herzegovina', 'BA', 'BIH', '70', '387', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (47, 'botswana', 'BW', 'BWA', '72', '267', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (48, 'brazil', 'BR', 'BRA', '76', '055', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (49, 'british-virgin-islands', 'VG', 'VGB', '92', '284', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (50, 'brunei', 'BN', 'BRN', '96', '673', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (51, 'bulgaria', 'BG', 'BGR', '100', '359', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (52, 'burkina-faso', 'BF', 'BFA', '854', '226', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (53, 'burma-myanmar', 'MM', 'MMR', '104', '095', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (54, 'burundi', 'BI', 'BDI', '108', '257', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (55, 'cambodia', 'KH', 'KHM', '116', '855', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (56, 'cameroon', 'CM', 'CMR', '120', '237', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (57, 'cape-verde-island', 'CV', 'CPV', '132', '238', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (58, 'cayman-islands', 'KY', 'CYM', '136', '345', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (59, 'central-african-republic', 'CF', 'CAF', '140', '236', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (60, 'chad', 'TD', 'TCD', '148', '235', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (61, 'chile', 'CL', 'CHL', '152', '056', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (62, 'christmas-island', 'CX', 'CXR', '162', '061', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (63, 'cocos-islands', 'CC', 'CCK', '166', '061', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (64, 'colombia', 'CO', 'COL', '170', '057', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (65, 'comoros', 'KM', 'COM', '174', '269', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (66, 'republic-of-congo', 'CD', 'COD', '180', '242', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (67, 'democratic-republic-of-congo', 'CG', 'COG', '178', '243', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (68, 'cook-islands', 'CK', 'COK', '184', '682', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (69, 'costa-rica', 'CR', 'CRI', '188', '506', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (70, 'croatia', 'HR', 'HRV', '191', '385', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (71, 'cuba', 'CU', 'CUB', '192', '053', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (72, 'cyprus', 'CY', 'CYP', '196', '357', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (73, 'czech-republic', 'CZ', 'CZE', '203', '420', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (74, 'denmark', 'DK', 'DNK', '208', '045', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (75, 'djibouti', 'DJ', 'DJI', '262', '253', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (76, 'dominica', 'DM', 'DMA', '212', '767', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (77, 'dominican-republic', 'DO', 'DOM', '214', '809', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (78, 'ecuador', 'EC', 'ECU', '218', '593', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (79, 'egypt', 'EG', 'EGY', '818', '020', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (80, 'el-salvador', 'SV', 'SLV', '222', '503', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (81, 'equatorial-guinea', 'GQ', 'GNQ', '226', '240', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (82, 'eritrea', 'ER', 'ERI', '232', '291', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (83, 'estonia', 'EE', 'EST', '233', '372', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (84, 'ethiopia', 'ET', 'ETH', '231', '251', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (85, 'faeroe-islands', 'FO', 'FRO', '234', '298', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (86, 'falkland-islands', 'FK', 'FLK', '238', '500', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (87, 'fiji-islands', 'FJ', 'FJI', '242', '679', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (88, 'finland', 'FI', 'FIN', '246', '358', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (89, 'french-guiana', 'GF', 'GUF', '254', '594', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (90, 'french-polynesia', 'PF', 'PYF', '258', '689', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (91, 'gabon', 'GA', 'GAB', '266', '241', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (92, 'gambia', 'GM', 'GMB', '270', '220', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (93, 'georgia', 'GE', 'GEO', '268', '995', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (94, 'ghana', 'GH', 'GHA', '288', '233', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (95, 'gibraltar', 'GI', 'GIB', '292', '350', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (96, 'greece', 'GR', 'GRC', '300', '030', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (97, 'greenland', 'GL', 'GRL', '304', '299', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (98, 'grenada', 'GD', 'GRD', '308', '473', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (99, 'guadeloupe', 'GP', 'GLP', '312', '590', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (100, 'guam', 'GU', 'GUM', '316', '671', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (101, 'guatemala', 'GT', 'GTM', '320', '502', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (102, 'guinea', 'GN', 'GIN', '324', '224', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (103, 'guinea-bissau', 'GW', 'GNB', '624', '245', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (104, 'guyana', 'GY', 'GUY', '328', '592', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (105, 'haiti', 'HT', 'HTI', '332', '509', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (106, 'honduras', 'HN', 'HND', '340', '504', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (107, 'iceland', 'IS', 'ISL', '352', '354', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (108, 'india', 'IN', 'IND', '356', '091', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (109, 'indonesia', 'ID', 'IDN', '360', '062', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (110, 'iran', 'IR', 'IRN', '364', '098', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (111, 'iraq', 'IQ', 'IRQ', '368', '964', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (112, 'ireland', 'IE', 'IRL', '372', '353', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (113, 'ivory-coast', 'CI', 'CIV', '384', '225', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (114, 'jamaica', 'JM', 'JAM', '388', '876', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (115, 'jordan', 'JO', 'JOR', '400', '962', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (116, 'kazakhstan', 'KZ', 'KAZ', '398', '007', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (117, 'kenya', 'KE', 'KEN', '404', '254', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (118, 'kiribati', 'KI', 'KIR', '408', '686', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (119, 'kuwait', 'KW', 'KWT', '414', '965', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (120, 'north-korea', 'KP', 'PRK', '408', '850', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (121, 'kyrgyzstan', 'KG', 'KGZ', '471', '996', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (122, 'laos', 'LA', 'LAO', '418', '856', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (123, 'latvia', 'LV', 'LVA', '428', '371', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (124, 'lebanon', 'LB', 'LBN', '422', '961', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (125, 'lesotho', 'LS', 'LSO', '426', '266', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (126, 'liberia', 'LR', 'LBR', '430', '231', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (127, 'libya', 'LY', 'LBY', '434', '218', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (128, 'liechtenstein', 'LI', 'LIE', '438', '423', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (129, 'lithuania', 'LT', 'LTU', '440', '370', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (130, 'luxembourg', 'LU', 'LUX', '442', '352', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (131, 'macau', 'MO', 'MAC', '446', '853', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (132, 'macedonia', 'MK', 'MKD', '807', '389', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (133, 'madagascar', 'MG', 'MDG', '450', '261', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (134, 'malawi', 'MW', 'MWI', '454', '265', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (135, 'malaysia', 'MY', 'MYS', '458', '060', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (136, 'maldives', 'MV', 'MDV', '462', '960', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (137, 'mali', 'ML', 'MLI', '466', '223', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (138, 'malta', 'MT', 'MLT', '470', '356', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (139, 'marshall-islands', 'MH', 'MHL', '584', '692', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (140, 'martinique', 'MQ', 'MTQ', '474', '596', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (141, 'mauritania', 'MR', 'MRT', '478', '222', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (142, 'mauritius', 'MU', 'MUS', '480', '230', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (143, 'mayotte-island', 'YT', 'MYT', '175', '269', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (144, 'mexico', 'MX', 'MEX', '484', '052', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (145, 'micronesia', 'FM', 'FSM', '583', '691', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (146, 'moldova', 'MD', 'MDA', '498', '373', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (147, 'monaco', 'MC', 'MCO', '492', '377', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (148, 'mongolia', 'MN', 'MNG', '496', '976', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (149, 'montenegro', 'ME', 'MNE', '499', '382', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (150, 'montserrat', 'MS', 'MSR', '500', '664', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (151, 'morocco', 'MA', 'MAR', '504', '212', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (152, 'mozambique', 'MZ', 'MOZ', '508', '258', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (153, 'namibia', 'NA', 'NAM', '516', '264', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (154, 'nauru', 'NR', 'NRU', '520', '674', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (155, 'nepal', 'NP', 'NPL', '524', '977', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (156, 'netherlands-antilles', 'AN', 'ANT', '530', '599', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (157, 'new-caledonia', 'NC', 'NCL', '540', '687', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (158, 'new-zealand', 'NZ', 'NZL', '554', '064', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (159, 'nicaragua', 'NI', 'NIC', '558', '505', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (160, 'niger', 'NE', 'NER', '562', '227', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (161, 'nigeria', 'NG', 'NGA', '566', '234', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (162, 'niue', 'NU', 'NIU', '570', '683', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (163, 'norfolk-island', 'NF', 'NFK', '574', '672', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (164, 'norway', 'NO', 'NOR', '578', '047', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (165, 'oman', 'OM', 'OMN', '512', '968', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (166, 'pakistan', 'PK', 'PAK', '586', '092', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (167, 'palau', 'PW', 'PLW', '585', '680', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (168, 'palestine', 'PS', 'PSE', '275', '970', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (169, 'panama', 'PA', 'PAN', '591', '507', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (170, 'papua-new-guinea', 'PG', 'PNG', '598', '675', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (171, 'paraguay', 'PY', 'PRY', '600', '595', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (172, 'peru', 'PE', 'PER', '604', '051', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (173, 'philippines', 'PH', 'PHL', '608', '063', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (174, 'poland', 'PL', 'POL', '616', '048', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (175, 'puerto-rico', 'PR', 'PRI', '630', '787', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (176, 'qatar', 'QA', 'QAT', '634', '974', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (177, 'reunion-island', 'RE', 'REU', '638', '262', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (178, 'romania', 'RO', 'ROU', '642', '040', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (179, 'rwanda', 'RW', 'RWA', '646', '250', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (180, 'st-helena', 'SH', 'SHN', '654', '290', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (181, 'st-kitts', 'KN', 'KNA', '659', '869', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (182, 'st-lucia', 'LC', 'LCA', '662', '758', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (183, 'st-pierre-miquelon', 'PM', 'SPM', '666', '508', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (184, 'st-vincent', 'VC', 'VCT', '670', '784', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (185, 'san-marino', 'SM', 'SMR', '674', '378', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (186, 'sao-tome-principe', 'ST', 'STP', '678', '239', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (187, 'saudi-arabia', 'SA', 'SAU', '682', '966', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (188, 'senegal', 'SN', 'SEN', '686', '221', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (189, 'serbia', 'RS', 'SRB', '688', '381', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (190, 'seychelles', 'SC', 'SYC', '690', '248', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (191, 'sierra-leone', 'SL', 'SLE', '694', '249', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (192, 'slovakia', 'SK', 'SVK', '703', '421', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (193, 'slovenia', 'SI', 'SVN', '705', '386', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (194, 'solomon-islands', 'SB', 'SLB', '90', '677', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (195, 'somalia', 'SO', 'SOM', '706', '252', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (196, 'south-africa', 'ZA', 'ZAF', '710', '027', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (197, 'sri-lanka', 'LK', 'LKA', '144', '094', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (198, 'sudan', 'SD', 'SDN', '736', '095', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (199, 'suriname', 'SR', 'SUR', '740', '597', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (200, 'swaziland', 'SZ', 'SWZ', '748', '268', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (201, 'sweden', 'SE', 'SWE', '752', '046', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (202, 'switzerland', 'CH', 'CHE', '756', '041', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (203, 'syria', 'SY', 'SYR', '760', '963', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (204, 'taiwan', 'TW', 'TWN', '158', '886', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (205, 'tajikistan', 'TJ', 'TJK', '762', '992', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (206, 'tanzania', 'TZ', 'TZA', '834', '255', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (207, 'thailand', 'TH', 'THA', '764', '066', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (208, 'togo', 'TG', 'TGO', '768', '228', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (209, 'tonga', 'TO', 'TON', '776', '676', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (210, 'trinidad-tobago', 'TT', 'TTO', '780', '868', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (211, 'tunisia', 'TN', 'TUN', '788', '216', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (212, 'turkmenistan', 'TM', 'TKM', '795', '993', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (213, 'turks-caicos', 'TC', 'TCA', '796', '649', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (214, 'tuvalu', 'TV', 'TUV', '798', '688', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (215, 'uganda', 'UG', 'UGA', '800', '256', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (216, 'ukraine', 'UA', 'UKR', '804', '380', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (217, 'united-arab-emirates', 'AE', 'ARE', '784', '971', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (218, 'uruguay', 'UY', 'URY', '858', '598', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (219, 'uzbekistan', 'UZ', 'UZB', '860', '998', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (220, 'vanuatu', 'VU', 'VUT', '548', '678', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (221, 'vatican-city', 'VA', 'VAT', '336', '039', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (222, 'venezuela', 'VE', 'VEN', '862', '058', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (223, 'wallis-futuna', 'WF', 'WLF', '876', '681', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (224, 'western-samoa', 'WS', 'WSM', '882', '685', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (225, 'yemen', 'YE', 'YEM', '887', '967', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (226, 'zambia', 'ZM', 'ZMB', '894', '260', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (227, 'zimbabwe', 'ZW', 'ZWE', '716', '263', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (228, 'aland-islands', 'AX', 'ALA', '248', '359', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (229, 'bonaire-st-eustatius-saba', 'BQ', 'BES', '535', '599', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (230, 'bouvet-island', 'BV', 'BVT', '74', '047', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (231, 'british-indian-ocean-territory', 'IO', 'IOT', '86', '246', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (232, 'curacao', 'CW', 'CUW', '531', '599', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (233, 'french-southern-territories', 'TF', 'ATF', '260', '033', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (234, 'guernsey', 'GG', 'GGY', '831', '044', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (235, 'heard-island-mcdonald-islands', 'HM', 'HMD', '334', '061', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (236, 'isle-of-man', 'IM', 'IMN', '833', '044', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (237, 'jersey', 'JE', 'JEY', '832', '044', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (238, 'northern-mariana-islands', 'MP', 'MNP', '580', '670', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (239, 'pitcairn', 'PN', 'PCN', '612', '649', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (240, 'south-georgia-south-sandwich-islands', 'GS', 'SGS', '239', '044', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (241, 'south-sudan', 'SS', 'SSD', '728', '211', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (242, 'sint-maarten', 'SX', 'SXM', '534', '721', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (243, 'st-barthelemy', 'BL', 'BLM', '652', '590', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (244, 'st-martin', 'MF', 'MAF', '663', '590', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (245, 'tokelau', 'TK', 'TKL', '772', '690', 'F', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (246, 'timor-leste', 'TL', 'TLS', '626', '670', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (247, 'united-states-minor-outlying-islands', 'UM', 'UMI', '581', '699', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (248, 'united-states-virgin-islands', 'VI', 'VIR', '850', '340', 'T', 'T');
insert into Country (countryId, name, a2, a3, number_, idd_, zipRequired, active_) values (249, 'western-sahara', 'EH', 'ESH', '732', '212', 'T', 'T');

insert into Region (regionId, countryId, regionCode, name, active_) values (1001, 1, 'AB', 'Alberta', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1002, 1, 'BC', 'British Columbia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1003, 1, 'MB', 'Manitoba', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1004, 1, 'NB', 'New Brunswick', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1005, 1, 'NL', 'Newfoundland and Labrador', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1006, 1, 'NT', 'Northwest Territories', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1007, 1, 'NS', 'Nova Scotia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1008, 1, 'NU', 'Nunavut', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1009, 1, 'ON', 'Ontario', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1010, 1, 'PE', 'Prince Edward Island', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1011, 1, 'QC', 'Quebec', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1012, 1, 'SK', 'Saskatchewan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (1013, 1, 'YT', 'Yukon', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2001, 2, 'CN-34', 'Anhui', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2002, 2, 'CN-92', 'Aomen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2003, 2, 'CN-11', 'Beijing', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2004, 2, 'CN-50', 'Chongqing', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2005, 2, 'CN-35', 'Fujian', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2006, 2, 'CN-62', 'Gansu', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2007, 2, 'CN-44', 'Guangdong', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2008, 2, 'CN-45', 'Guangxi', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2009, 2, 'CN-52', 'Guizhou', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2010, 2, 'CN-46', 'Hainan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2011, 2, 'CN-13', 'Hebei', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2012, 2, 'CN-23', 'Heilongjiang', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2013, 2, 'CN-41', 'Henan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2014, 2, 'CN-42', 'Hubei', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2015, 2, 'CN-43', 'Hunan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2016, 2, 'CN-32', 'Jiangsu', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2017, 2, 'CN-36', 'Jiangxi', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2018, 2, 'CN-22', 'Jilin', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2019, 2, 'CN-21', 'Liaoning', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2020, 2, 'CN-15', 'Nei Mongol', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2021, 2, 'CN-64', 'Ningxia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2022, 2, 'CN-63', 'Qinghai', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2023, 2, 'CN-61', 'Shaanxi', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2024, 2, 'CN-37', 'Shandong', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2025, 2, 'CN-31', 'Shanghai', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2026, 2, 'CN-14', 'Shanxi', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2027, 2, 'CN-51', 'Sichuan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2028, 2, 'CN-71', 'Taiwan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2029, 2, 'CN-12', 'Tianjin', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2030, 2, 'CN-91', 'Xianggang', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2031, 2, 'CN-65', 'Xinjiang', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2032, 2, 'CN-54', 'Xizang', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2033, 2, 'CN-53', 'Yunnan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (2034, 2, 'CN-33', 'Zhejiang', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3001, 3, 'A', 'Alsace', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3002, 3, 'B', 'Aquitaine', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3003, 3, 'C', 'Auvergne', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3004, 3, 'P', 'Basse-Normandie', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3005, 3, 'D', 'Bourgogne', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3006, 3, 'E', 'Bretagne', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3007, 3, 'F', 'Centre', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3008, 3, 'G', 'Champagne-Ardenne', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3009, 3, 'H', 'Corse', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3010, 3, 'GF', 'Guyane', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3011, 3, 'I', 'Franche Comté', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3012, 3, 'GP', 'Guadeloupe', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3013, 3, 'Q', 'Haute-Normandie', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3014, 3, 'J', 'Île-de-France', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3015, 3, 'K', 'Languedoc-Roussillon', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3016, 3, 'L', 'Limousin', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3017, 3, 'M', 'Lorraine', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3018, 3, 'MQ', 'Martinique', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3019, 3, 'N', 'Midi-Pyrénées', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3020, 3, 'O', 'Nord Pas de Calais', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3021, 3, 'R', 'Pays de la Loire', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3022, 3, 'S', 'Picardie', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3023, 3, 'T', 'Poitou-Charentes', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3024, 3, 'U', 'Provence-Alpes-Côte-d''Azur', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3025, 3, 'RE', 'Réunion', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (3026, 3, 'V', 'Rhône-Alpes', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4001, 4, 'BW', 'Baden-Württemberg', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4002, 4, 'BY', 'Bayern', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4003, 4, 'BE', 'Berlin', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4004, 4, 'BR', 'Brandenburg', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4005, 4, 'HB', 'Bremen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4006, 4, 'HH', 'Hamburg', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4007, 4, 'HE', 'Hessen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4008, 4, 'MV', 'Mecklenburg-Vorpommern', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4009, 4, 'NI', 'Niedersachsen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4010, 4, 'NW', 'Nordrhein-Westfalen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4011, 4, 'RP', 'Rheinland-Pfalz', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4012, 4, 'SL', 'Saarland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4013, 4, 'SN', 'Sachsen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4014, 4, 'ST', 'Sachsen-Anhalt', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4015, 4, 'SH', 'Schleswig-Holstein', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (4016, 4, 'TH', 'Thüringen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8001, 8, 'AG', 'Agrigento', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8002, 8, 'AL', 'Alessandria', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8003, 8, 'AN', 'Ancona', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8004, 8, 'AO', 'Aosta', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8005, 8, 'AR', 'Arezzo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8006, 8, 'AP', 'Ascoli Piceno', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8007, 8, 'AT', 'Asti', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8008, 8, 'AV', 'Avellino', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8009, 8, 'BA', 'Bari', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8010, 8, 'BT', 'Barletta-Andria-Trani', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8011, 8, 'BL', 'Belluno', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8012, 8, 'BN', 'Benevento', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8013, 8, 'BG', 'Bergamo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8014, 8, 'BI', 'Biella', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8015, 8, 'BO', 'Bologna', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8016, 8, 'BZ', 'Bolzano', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8017, 8, 'BS', 'Brescia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8018, 8, 'BR', 'Brindisi', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8019, 8, 'CA', 'Cagliari', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8020, 8, 'CL', 'Caltanissetta', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8021, 8, 'CB', 'Campobasso', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8022, 8, 'CI', 'Carbonia-Iglesias', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8023, 8, 'CE', 'Caserta', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8024, 8, 'CT', 'Catania', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8025, 8, 'CZ', 'Catanzaro', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8026, 8, 'CH', 'Chieti', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8027, 8, 'CO', 'Como', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8028, 8, 'CS', 'Cosenza', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8029, 8, 'CR', 'Cremona', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8030, 8, 'KR', 'Crotone', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8031, 8, 'CN', 'Cuneo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8032, 8, 'EN', 'Enna', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8033, 8, 'FM', 'Fermo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8034, 8, 'FE', 'Ferrara', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8035, 8, 'FI', 'Firenze', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8036, 8, 'FG', 'Foggia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8037, 8, 'FC', 'Forli-Cesena', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8038, 8, 'FR', 'Frosinone', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8039, 8, 'GE', 'Genova', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8040, 8, 'GO', 'Gorizia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8041, 8, 'GR', 'Grosseto', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8042, 8, 'IM', 'Imperia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8043, 8, 'IS', 'Isernia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8044, 8, 'AQ', 'L''Aquila', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8045, 8, 'SP', 'La Spezia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8046, 8, 'LT', 'Latina', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8047, 8, 'LE', 'Lecce', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8048, 8, 'LC', 'Lecco', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8049, 8, 'LI', 'Livorno', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8050, 8, 'LO', 'Lodi', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8051, 8, 'LU', 'Lucca', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8052, 8, 'MC', 'Macerata', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8053, 8, 'MN', 'Mantova', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8054, 8, 'MS', 'Massa-Carrara', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8055, 8, 'MT', 'Matera', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8056, 8, 'MA', 'Medio Campidano', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8057, 8, 'ME', 'Messina', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8058, 8, 'MI', 'Milano', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8059, 8, 'MO', 'Modena', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8060, 8, 'MZ', 'Monza', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8061, 8, 'NA', 'Napoli', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8062, 8, 'NO', 'Novara', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8063, 8, 'NU', 'Nuoro', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8064, 8, 'OG', 'Ogliastra', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8065, 8, 'OT', 'Olbia-Tempio', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8066, 8, 'OR', 'Oristano', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8067, 8, 'PD', 'Padova', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8068, 8, 'PA', 'Palermo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8069, 8, 'PR', 'Parma', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8070, 8, 'PV', 'Pavia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8071, 8, 'PG', 'Perugia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8072, 8, 'PU', 'Pesaro e Urbino', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8073, 8, 'PE', 'Pescara', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8074, 8, 'PC', 'Piacenza', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8075, 8, 'PI', 'Pisa', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8076, 8, 'PT', 'Pistoia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8077, 8, 'PN', 'Pordenone', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8078, 8, 'PZ', 'Potenza', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8079, 8, 'PO', 'Prato', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8080, 8, 'RG', 'Ragusa', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8081, 8, 'RA', 'Ravenna', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8082, 8, 'RC', 'Reggio Calabria', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8083, 8, 'RE', 'Reggio Emilia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8084, 8, 'RI', 'Rieti', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8085, 8, 'RN', 'Rimini', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8086, 8, 'RM', 'Roma', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8087, 8, 'RO', 'Rovigo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8088, 8, 'SA', 'Salerno', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8089, 8, 'SS', 'Sassari', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8090, 8, 'SV', 'Savona', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8091, 8, 'SI', 'Siena', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8092, 8, 'SR', 'Siracusa', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8093, 8, 'SO', 'Sondrio', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8094, 8, 'TA', 'Taranto', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8095, 8, 'TE', 'Teramo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8096, 8, 'TR', 'Terni', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8097, 8, 'TO', 'Torino', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8098, 8, 'TP', 'Trapani', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8099, 8, 'TN', 'Trento', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8100, 8, 'TV', 'Treviso', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8101, 8, 'TS', 'Trieste', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8102, 8, 'UD', 'Udine', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8103, 8, 'VA', 'Varese', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8104, 8, 'VE', 'Venezia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8105, 8, 'VB', 'Verbano-Cusio-Ossola', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8106, 8, 'VC', 'Vercelli', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8107, 8, 'VR', 'Verona', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8108, 8, 'VV', 'Vibo Valentia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8109, 8, 'VI', 'Vicenza', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (8110, 8, 'VT', 'Viterbo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11001, 11, 'DR', 'Drenthe', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11002, 11, 'FL', 'Flevoland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11003, 11, 'FR', 'Friesland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11004, 11, 'GE', 'Gelderland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11005, 11, 'GR', 'Groningen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11006, 11, 'LI', 'Limburg', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11007, 11, 'NB', 'Noord-Brabant', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11008, 11, 'NH', 'Noord-Holland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11009, 11, 'OV', 'Overijssel', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11010, 11, 'UT', 'Utrecht', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11011, 11, 'ZE', 'Zeeland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (11012, 11, 'ZH', 'Zuid-Holland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15001, 15, 'AN', 'Andalusia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15002, 15, 'AR', 'Aragon', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15003, 15, 'AS', 'Asturias', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15004, 15, 'IB', 'Balearic Islands', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15005, 15, 'PV', 'Basque Country', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15006, 15, 'CN', 'Canary Islands', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15007, 15, 'CB', 'Cantabria', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15008, 15, 'CL', 'Castile and Leon', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15009, 15, 'CM', 'Castile-La Mancha', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15010, 15, 'CT', 'Catalonia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15011, 15, 'CE', 'Ceuta', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15012, 15, 'EX', 'Extremadura', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15013, 15, 'GA', 'Galicia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15014, 15, 'LO', 'La Rioja', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15015, 15, 'M', 'Madrid', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15016, 15, 'ML', 'Melilla', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15017, 15, 'MU', 'Murcia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15018, 15, 'NA', 'Navarra', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (15019, 15, 'VC', 'Valencia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19001, 19, 'AL', 'Alabama', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19002, 19, 'AK', 'Alaska', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19003, 19, 'AZ', 'Arizona', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19004, 19, 'AR', 'Arkansas', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19005, 19, 'CA', 'California', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19006, 19, 'CO', 'Colorado', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19007, 19, 'CT', 'Connecticut', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19008, 19, 'DC', 'District of Columbia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19009, 19, 'DE', 'Delaware', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19010, 19, 'FL', 'Florida', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19011, 19, 'GA', 'Georgia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19012, 19, 'HI', 'Hawaii', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19013, 19, 'ID', 'Idaho', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19014, 19, 'IL', 'Illinois', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19015, 19, 'IN', 'Indiana', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19016, 19, 'IA', 'Iowa', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19017, 19, 'KS', 'Kansas', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19018, 19, 'KY', 'Kentucky ', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19019, 19, 'LA', 'Louisiana ', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19020, 19, 'ME', 'Maine', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19021, 19, 'MD', 'Maryland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19022, 19, 'MA', 'Massachusetts', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19023, 19, 'MI', 'Michigan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19024, 19, 'MN', 'Minnesota', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19025, 19, 'MS', 'Mississippi', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19026, 19, 'MO', 'Missouri', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19027, 19, 'MT', 'Montana', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19028, 19, 'NE', 'Nebraska', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19029, 19, 'NV', 'Nevada', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19030, 19, 'NH', 'New Hampshire', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19031, 19, 'NJ', 'New Jersey', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19032, 19, 'NM', 'New Mexico', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19033, 19, 'NY', 'New York', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19034, 19, 'NC', 'North Carolina', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19035, 19, 'ND', 'North Dakota', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19036, 19, 'OH', 'Ohio', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19037, 19, 'OK', 'Oklahoma ', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19038, 19, 'OR', 'Oregon', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19039, 19, 'PA', 'Pennsylvania', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19040, 19, 'PR', 'Puerto Rico', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19041, 19, 'RI', 'Rhode Island', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19042, 19, 'SC', 'South Carolina', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19043, 19, 'SD', 'South Dakota', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19044, 19, 'TN', 'Tennessee', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19045, 19, 'TX', 'Texas', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19046, 19, 'UT', 'Utah', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19047, 19, 'VT', 'Vermont', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19048, 19, 'VA', 'Virginia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19049, 19, 'WA', 'Washington', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19050, 19, 'WV', 'West Virginia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19051, 19, 'WI', 'Wisconsin', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (19052, 19, 'WY', 'Wyoming', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (32001, 32, 'ACT', 'Australian Capital Territory', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (32002, 32, 'NSW', 'New South Wales', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (32003, 32, 'NT', 'Northern Territory', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (32004, 32, 'QLD', 'Queensland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (32005, 32, 'SA', 'South Australia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (32006, 32, 'TAS', 'Tasmania', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (32007, 32, 'VIC', 'Victoria', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (32008, 32, 'WA', 'Western Australia', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144001, 144, 'MX-AGS', 'Aguascalientes', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144002, 144, 'MX-BCN', 'Baja California', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144003, 144, 'MX-BCS', 'Baja California Sur', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144004, 144, 'MX-CAM', 'Campeche', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144005, 144, 'MX-CHP', 'Chiapas', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144006, 144, 'MX-CHI', 'Chihuahua', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144007, 144, 'MX-COA', 'Coahuila', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144008, 144, 'MX-COL', 'Colima', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144009, 144, 'MX-DUR', 'Durango', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144010, 144, 'MX-GTO', 'Guanajuato', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144011, 144, 'MX-GRO', 'Guerrero', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144012, 144, 'MX-HGO', 'Hidalgo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144013, 144, 'MX-JAL', 'Jalisco', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144014, 144, 'MX-MEX', 'Mexico', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144015, 144, 'MX-MIC', 'Michoacan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144016, 144, 'MX-MOR', 'Morelos', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144017, 144, 'MX-NAY', 'Nayarit', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144018, 144, 'MX-NLE', 'Nuevo Leon', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144019, 144, 'MX-OAX', 'Oaxaca', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144020, 144, 'MX-PUE', 'Puebla', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144021, 144, 'MX-QRO', 'Queretaro', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144023, 144, 'MX-ROO', 'Quintana Roo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144024, 144, 'MX-SLP', 'San Luis Potosí', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144025, 144, 'MX-SIN', 'Sinaloa', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144026, 144, 'MX-SON', 'Sonora', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144027, 144, 'MX-TAB', 'Tabasco', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144028, 144, 'MX-TAM', 'Tamaulipas', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144029, 144, 'MX-TLX', 'Tlaxcala', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144030, 144, 'MX-VER', 'Veracruz', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144031, 144, 'MX-YUC', 'Yucatan', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (144032, 144, 'MX-ZAC', 'Zacatecas', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164001, 164, '01', 'Østfold', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164002, 164, '02', 'Akershus', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164003, 164, '03', 'Oslo', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164004, 164, '04', 'Hedmark', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164005, 164, '05', 'Oppland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164006, 164, '06', 'Buskerud', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164007, 164, '07', 'Vestfold', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164008, 164, '08', 'Telemark', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164009, 164, '09', 'Aust-Agder', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164010, 164, '10', 'Vest-Agder', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164011, 164, '11', 'Rogaland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164012, 164, '12', 'Hordaland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164013, 164, '14', 'Sogn og Fjordane', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164014, 164, '15', 'Møre of Romsdal', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164015, 164, '16', 'Sør-Trøndelag', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164016, 164, '17', 'Nord-Trøndelag', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164017, 164, '18', 'Nordland', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164018, 164, '19', 'Troms', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (164019, 164, '20', 'Finnmark', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202001, 202, 'AG', 'Aargau', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202002, 202, 'AR', 'Appenzell Ausserrhoden', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202003, 202, 'AI', 'Appenzell Innerrhoden', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202004, 202, 'BL', 'Basel-Landschaft', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202005, 202, 'BS', 'Basel-Stadt', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202006, 202, 'BE', 'Bern', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202007, 202, 'FR', 'Fribourg', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202008, 202, 'GE', 'Geneva', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202009, 202, 'GL', 'Glarus', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202010, 202, 'GR', 'Graubünden', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202011, 202, 'JU', 'Jura', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202012, 202, 'LU', 'Lucerne', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202013, 202, 'NE', 'Neuchâtel', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202014, 202, 'NW', 'Nidwalden', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202015, 202, 'OW', 'Obwalden', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202016, 202, 'SH', 'Schaffhausen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202017, 202, 'SZ', 'Schwyz', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202018, 202, 'SO', 'Solothurn', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202019, 202, 'SG', 'St. Gallen', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202020, 202, 'TG', 'Thurgau', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202021, 202, 'TI', 'Ticino', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202022, 202, 'UR', 'Uri', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202023, 202, 'VS', 'Valais', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202024, 202, 'VD', 'Vaud', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202025, 202, 'ZG', 'Zug', 'T');
insert into Region (regionId, countryId, regionCode, name, active_) values (202026, 202, 'ZH', 'Zürich', 'T');

--
-- List types for accounts
--

insert into ListType (listTypeId, name, type_) values (10000, 'billing', 'com.liferay.portal.model.Account.address');
insert into ListType (listTypeId, name, type_) values (10001, 'other', 'com.liferay.portal.model.Account.address');
insert into ListType (listTypeId, name, type_) values (10002, 'p-o-box', 'com.liferay.portal.model.Account.address');
insert into ListType (listTypeId, name, type_) values (10003, 'shipping', 'com.liferay.portal.model.Account.address');

insert into ListType (listTypeId, name, type_) values (10004, 'email-address', 'com.liferay.portal.model.Account.emailAddress');
insert into ListType (listTypeId, name, type_) values (10005, 'email-address-2', 'com.liferay.portal.model.Account.emailAddress');
insert into ListType (listTypeId, name, type_) values (10006, 'email-address-3', 'com.liferay.portal.model.Account.emailAddress');

insert into ListType (listTypeId, name, type_) values (10007, 'fax', 'com.liferay.portal.model.Account.phone');
insert into ListType (listTypeId, name, type_) values (10008, 'local', 'com.liferay.portal.model.Account.phone');
insert into ListType (listTypeId, name, type_) values (10009, 'other', 'com.liferay.portal.model.Account.phone');
insert into ListType (listTypeId, name, type_) values (10010, 'toll-free', 'com.liferay.portal.model.Account.phone');
insert into ListType (listTypeId, name, type_) values (10011, 'tty', 'com.liferay.portal.model.Account.phone');

insert into ListType (listTypeId, name, type_) values (10012, 'intranet', 'com.liferay.portal.model.Account.website');
insert into ListType (listTypeId, name, type_) values (10013, 'public', 'com.liferay.portal.model.Account.website');

--
-- List types for contacts
--

insert into ListType (listTypeId, name, type_) values (11000, 'business', 'com.liferay.portal.model.Contact.address');
insert into ListType (listTypeId, name, type_) values (11001, 'other', 'com.liferay.portal.model.Contact.address');
insert into ListType (listTypeId, name, type_) values (11002, 'personal', 'com.liferay.portal.model.Contact.address');

insert into ListType (listTypeId, name, type_) values (11003, 'email-address', 'com.liferay.portal.model.Contact.emailAddress');
insert into ListType (listTypeId, name, type_) values (11004, 'email-address-2', 'com.liferay.portal.model.Contact.emailAddress');
insert into ListType (listTypeId, name, type_) values (11005, 'email-address-3', 'com.liferay.portal.model.Contact.emailAddress');

insert into ListType (listTypeId, name, type_) values (11006, 'business', 'com.liferay.portal.model.Contact.phone');
insert into ListType (listTypeId, name, type_) values (11007, 'business-fax', 'com.liferay.portal.model.Contact.phone');
insert into ListType (listTypeId, name, type_) values (11008, 'mobile-phone', 'com.liferay.portal.model.Contact.phone');
insert into ListType (listTypeId, name, type_) values (11009, 'other', 'com.liferay.portal.model.Contact.phone');
insert into ListType (listTypeId, name, type_) values (11010, 'pager', 'com.liferay.portal.model.Contact.phone');
insert into ListType (listTypeId, name, type_) values (11011, 'personal', 'com.liferay.portal.model.Contact.phone');
insert into ListType (listTypeId, name, type_) values (11012, 'personal-fax', 'com.liferay.portal.model.Contact.phone');
insert into ListType (listTypeId, name, type_) values (11013, 'tty', 'com.liferay.portal.model.Contact.phone');

insert into ListType (listTypeId, name, type_) values (11014, 'dr', 'com.liferay.portal.model.Contact.prefix');
insert into ListType (listTypeId, name, type_) values (11015, 'mr', 'com.liferay.portal.model.Contact.prefix');
insert into ListType (listTypeId, name, type_) values (11016, 'mrs', 'com.liferay.portal.model.Contact.prefix');
insert into ListType (listTypeId, name, type_) values (11017, 'ms', 'com.liferay.portal.model.Contact.prefix');

insert into ListType (listTypeId, name, type_) values (11020, 'ii', 'com.liferay.portal.model.Contact.suffix');
insert into ListType (listTypeId, name, type_) values (11021, 'iii', 'com.liferay.portal.model.Contact.suffix');
insert into ListType (listTypeId, name, type_) values (11022, 'iv', 'com.liferay.portal.model.Contact.suffix');
insert into ListType (listTypeId, name, type_) values (11023, 'jr', 'com.liferay.portal.model.Contact.suffix');
insert into ListType (listTypeId, name, type_) values (11024, 'phd', 'com.liferay.portal.model.Contact.suffix');
insert into ListType (listTypeId, name, type_) values (11025, 'sr', 'com.liferay.portal.model.Contact.suffix');

insert into ListType (listTypeId, name, type_) values (11026, 'blog', 'com.liferay.portal.model.Contact.website');
insert into ListType (listTypeId, name, type_) values (11027, 'business', 'com.liferay.portal.model.Contact.website');
insert into ListType (listTypeId, name, type_) values (11028, 'other', 'com.liferay.portal.model.Contact.website');
insert into ListType (listTypeId, name, type_) values (11029, 'personal', 'com.liferay.portal.model.Contact.website');

--
-- List types for organizations
--

insert into ListType (listTypeId, name, type_) values (12000, 'billing', 'com.liferay.portal.model.Organization.address');
insert into ListType (listTypeId, name, type_) values (12001, 'other', 'com.liferay.portal.model.Organization.address');
insert into ListType (listTypeId, name, type_) values (12002, 'p-o-box', 'com.liferay.portal.model.Organization.address');
insert into ListType (listTypeId, name, type_) values (12003, 'shipping', 'com.liferay.portal.model.Organization.address');

insert into ListType (listTypeId, name, type_) values (12004, 'email-address', 'com.liferay.portal.model.Organization.emailAddress');
insert into ListType (listTypeId, name, type_) values (12005, 'email-address-2', 'com.liferay.portal.model.Organization.emailAddress');
insert into ListType (listTypeId, name, type_) values (12006, 'email-address-3', 'com.liferay.portal.model.Organization.emailAddress');

insert into ListType (listTypeId, name, type_) values (12007, 'fax', 'com.liferay.portal.model.Organization.phone');
insert into ListType (listTypeId, name, type_) values (12008, 'local', 'com.liferay.portal.model.Organization.phone');
insert into ListType (listTypeId, name, type_) values (12009, 'other', 'com.liferay.portal.model.Organization.phone');
insert into ListType (listTypeId, name, type_) values (12010, 'toll-free', 'com.liferay.portal.model.Organization.phone');
insert into ListType (listTypeId, name, type_) values (12011, 'tty', 'com.liferay.portal.model.Organization.phone');

insert into ListType (listTypeId, name, type_) values (12012, 'administrative', 'com.liferay.portal.model.Organization.service');
insert into ListType (listTypeId, name, type_) values (12013, 'contracts', 'com.liferay.portal.model.Organization.service');
insert into ListType (listTypeId, name, type_) values (12014, 'donation', 'com.liferay.portal.model.Organization.service');
insert into ListType (listTypeId, name, type_) values (12015, 'retail', 'com.liferay.portal.model.Organization.service');
insert into ListType (listTypeId, name, type_) values (12016, 'training', 'com.liferay.portal.model.Organization.service');

insert into ListType (listTypeId, name, type_) values (12017, 'full-member', 'com.liferay.portal.model.Organization.status');
insert into ListType (listTypeId, name, type_) values (12018, 'provisional-member', 'com.liferay.portal.model.Organization.status');

insert into ListType (listTypeId, name, type_) values (12019, 'intranet', 'com.liferay.portal.model.Organization.website');
insert into ListType (listTypeId, name, type_) values (12020, 'public', 'com.liferay.portal.model.Organization.website');


insert into Counter (name, currentId) values ('com.liferay.counter.model.Counter', 10000);






insert into Company (companyId, accountId, webId, mx, system, active_) values (1, 7, 'liferay.com', 'liferay.com', 'F', 'T');

insert into Account_ (accountId, companyId, userId, userName, createDate, modifiedDate, parentAccountId, name, legalName, legalId, legalType, sicCode, tickerSymbol, industry, type_, size_) values (7, 1, 5, '', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 0, 'Liferay', 'Liferay, Inc.', '', '', '', '', '', '', '');

insert into VirtualHost (virtualHostId, companyId, layoutSetId, hostname) values (8, 1, 0, 'localhost');


insert into ClassName_ (classNameId, value) values (9, 'com.liferay.portal.model.Company');
insert into ClassName_ (classNameId, value) values (10, 'com.liferay.portal.model.Group');
insert into ClassName_ (classNameId, value) values (11, 'com.liferay.portal.model.Organization');
insert into ClassName_ (classNameId, value) values (12, 'com.liferay.portal.model.Role');
insert into ClassName_ (classNameId, value) values (13, 'com.liferay.portal.model.User');

insert into Shard (shardId, classNameId, classPK, name) values (14, 9, 1, 'default');


insert into Role_ (roleId, companyId, classNameId, classPK, name, description, type_) values (15, 1, 12, 15, 'Administrator', '', 1);
insert into Role_ (roleId, companyId, classNameId, classPK, name, description, type_) values (16, 1, 12, 16, 'Guest', '', 1);
insert into Role_ (roleId, companyId, classNameId, classPK, name, description, type_) values (17, 1, 12, 17, 'Power User', '', 1);
insert into Role_ (roleId, companyId, classNameId, classPK, name, description, type_) values (18, 1, 12, 18, 'User', '', 1);


insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, site, active_) values (19, 1, 5, 10, 19, 0, 0, 'Guest', 1, '/guest', 'T', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (20, 1, 19, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (21, 1, 19, 'F', 'F', 'classic', '01', 0);



insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (22, 1, 0, 'Liferay, Inc.', 'regular-organization', 'T', 19005, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, site, active_) values (23, 1, 5, 11, 22, 0, 0, '23', 0, '/23', 'T', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (26, 1, 23, 'T', 'F', 'classic', '01', 1);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (27, 1, 23, 'F', 'F', 'classic', '01', 1);

insert into Layout (uuid_, plid, groupId, companyId, privateLayout, layoutId, parentLayoutId, name, type_, typeSettings, hidden_, friendlyURL, priority) values ('03359c24-e83c-46ce-b85d-dc215e4e457a', 24, 23, 1, 'F', 1, 0, '<?xml version="1.0"?>\n\n<root>\n  <name>Liferay, Inc. Extranet</name>\n</root>', 'portlet', 'layout-template-id=2_columns_ii\ncolumn-1=3,\ncolumn-2=19,', 'F', '/23', 0);
insert into Layout (uuid_, plid, groupId, companyId, privateLayout, layoutId, parentLayoutId, name, type_, typeSettings, hidden_, friendlyURL, priority) values ('fd657d80-2f26-4577-b6f6-c0f0da3c0db4', 25, 23, 1, 'T', 1, 0, '<?xml version="1.0"?>\n\n<root>\n  <name>Liferay, Inc. Intranet</name>\n</root>', 'portlet', 'layout-template-id=2_columns_ii\ncolumn-1=3,\ncolumn-2=19,', 'F', '/23', 0);

insert into LayoutFriendlyURL (uuid_, layoutFriendlyURLId, groupId, companyId, userId, userName, createDate, modifiedDate, plid, privateLayout, friendlyURL, languageId) values ('51625d81-8fd0-4bd9-812f-1a894c593b6d', 28, 23, 1, 5, '', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 24, 'F', '/23', 'en_US');
insert into LayoutFriendlyURL (uuid_, layoutFriendlyURLId, groupId, companyId, userId, userName, createDate, modifiedDate, plid, privateLayout, friendlyURL, languageId) values ('4f218194-3b47-4e02-b1fa-d54c1958ffb8', 29, 23, 1, 5, '', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 25, 'T', '/23', 'en_US');

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (30, 1, 22, 'Liferay Engineering', 'regular-organization', 'T', 19005, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (31, 1, 5, 11, 30, 0, 0, '31', 0, '/31', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (32, 1, 31, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (33, 1, 31, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (34, 1, 22, 'Liferay Consulting', 'regular-organization', 'T', 19005, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (35, 1, 5, 11, 34, 0, 0, '35', 0, '/35', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (36, 1, 35, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (37, 1, 35, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (38, 1, 22, 'Liferay Support', 'regular-organization', 'T', 19005, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (39, 1, 5, 11, 38, 0, 0, '39', 0, '/39', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (40, 1, 39, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (41, 1, 39, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (42, 1, 22, 'Liferay Sales', 'regular-organization', 'T', 19005, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (43, 1, 5, 11, 42, 0, 0, '43', 0, '/43', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (44, 1, 43, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (45, 1, 43, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (46, 1, 22, 'Liferay Marketing', 'regular-organization', 'T', 19005, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (47, 1, 5, 11, 46, 0, 0, '47', 0, '/47', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (48, 1, 47, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (49, 1, 47, 'F', 'F', 'classic', '01', 0);


insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (50, 1, 22, 'Liferay Los Angeles', 'location', 'F', 19005, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (51, 1, 5, 11, 50, 0, 0, '51', 0, '/51', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (52, 1, 51, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (53, 1, 51, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (54, 1, 22, 'Liferay San Francisco', 'location', 'F', 19005, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (55, 1, 5, 11, 54, 0, 0, '55', 0, '/55', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (56, 1, 55, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (57, 1, 55, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (58, 1, 22, 'Liferay Chicago', 'location', 'F', 19014, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (59, 1, 5, 11, 58, 0, 0, '59', 0, '/59', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (60, 1, 59, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (61, 1, 59, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (62, 1, 22, 'Liferay New York', 'location', 'F', 19033, 19, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (63, 1, 5, 11, 62, 0, 0, '63', 0, '/63', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (64, 1, 63, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (65, 1, 63, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (66, 1, 22, 'Liferay Sao Paulo', 'location', 'F', 0, 48, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (67, 1, 5, 11, 66, 0, 0, '67', 0, '/67', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (68, 1, 67, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (69, 1, 67, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (70, 1, 22, 'Liferay Frankfurt', 'location', 'F', 0, 4, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (71, 1, 5, 11, 70, 0, 0, '71', 0, '/71', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (72, 1, 71, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (73, 1, 71, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (74, 1, 22, 'Liferay Madrid', 'location', 'F', 0, 15, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (75, 1, 5, 11, 74, 0, 0, '75', 0, '/75', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (76, 1, 75, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (77, 1, 75, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (78, 1, 22, 'Liferay Dalian', 'location', 'F', 0, 2, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (79, 1, 5, 11, 78, 0, 0, '79', 0, '/79', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (80, 1, 79, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (81, 1, 79, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (82, 1, 22, 'Liferay Hong Kong', 'location', 'F', 0, 2, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (83, 1, 5, 11, 82, 0, 0, '83', 0, '/83', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (84, 1, 83, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (85, 1, 83, 'F', 'F', 'classic', '01', 0);

insert into Organization_ (organizationId, companyId, parentOrganizationId, name, type_, recursable, regionId, countryId, statusId, comments) values (86, 1, 22, 'Liferay Kuala Lumpur', 'location', 'F', 0, 135, 12017, '');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (87, 1, 5, 11, 86, 0, 0, '87', 0, '/87', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (88, 1, 87, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (89, 1, 87, 'F', 'F', 'classic', '01', 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3b8459f3-10b1-491f-be77-0ad0a5f33c71', 5, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'T', 6, 'password', 'F', 'F', '5', 'default@liferay.com', 'Welcome!', '', '', '', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (6, 1, 5, '', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 5, 7, 0, 'default@liferay.com', '', '', '', 'T', '1970-01-01 00:00:00.0');

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, lastLoginDate, failedLoginAttempts, agreedToTermsOfUse, emailAddressVerified, status) values ('011cbbd8-8490-46ba-9c28-de49c6c5697c', 2, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 3, 'test', 'F', 'F', 'joebloggs', 'test@liferay.com', 'Welcome Joe Bloggs!', 'Joe', '', 'Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 0, 'F', 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (3, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 2, 7, 0, 'test@liferay.com', 'Joe', '', 'Bloggs', 'T', '1970-01-01 00:00:00.0');


insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (90, 1, 2, 13, 2, 0, 0, '90', 0, '/joebloggs', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (93, 1, 90, 'T', 'F', 'classic', '01', 2);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (94, 1, 90, 'F', 'F', 'classic', '01', 0);

insert into Layout (uuid_, plid, groupId, companyId, privateLayout, layoutId, parentLayoutId, name, type_, typeSettings, hidden_, friendlyURL, priority) values ('d23726f0-9cd2-414f-80ea-6ef1900d8316', 91, 90, 1, 'T', 1, 0, '<?xml version="1.0"?>\n\n<root>\n  <name>Home</name>\n</root>', 'portlet', 'column-1=71_INSTANCE_OY0d,82,23,61,\ncolumn-2=29,19,\nlayout-template-id=2_columns_ii\n', 'F', '/home', 0);
insert into Layout (uuid_, plid, groupId, companyId, privateLayout, layoutId, parentLayoutId, name, type_, typeSettings, hidden_, friendlyURL, priority) values ('85bfc1a3-6fdc-4525-9ccb-6ed4a99887f0', 92, 90, 1, 'T', 2, 0, '<?xml version="1.0"?>\n\n<root>\n  <name>Plugins</name>\n</root>', 'portlet', 'column-1=\ncolumn-2=111,\nlayout-template-id=2_columns_ii\n', 'F', '/plugins', 1);

insert into LayoutFriendlyURL (uuid_, layoutFriendlyURLId, groupId, companyId, userId, userName, createDate, modifiedDate, plid, privateLayout, friendlyURL, languageId) values ('13315718-cfff-4eb1-8ab7-a848228a25e6', 95, 90, 1, 5, '', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 91, 'T', '/home', 'en_US');
insert into LayoutFriendlyURL (uuid_, layoutFriendlyURLId, groupId, companyId, userId, userName, createDate, modifiedDate, plid, privateLayout, friendlyURL, languageId) values ('aed333f0-3bc0-4938-b85e-173a5cd8e57e', 96, 90, 1, 5, '', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 92, 'T', '/plugins', 'en_US');

insert into Users_Groups (groupId, userId) values (19, 2);

insert into Users_Orgs (organizationId, userId) values (22, 2);
insert into Users_Orgs (organizationId, userId) values (50, 2);

insert into Users_Roles (roleId, userId) values (15, 2);
insert into Users_Roles (roleId, userId) values (17, 2);
insert into Users_Roles (roleId, userId) values (18, 2);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (97, 90, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 2, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Joe Bloggs', '', '', '', 0, 0, 0, 0, 0);


insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('4f4e16c0-4c03-46cc-b993-f645d0c19c8a', 98, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 99, 'test', 'F', 'F', 'lax1', 'test.lax.1@liferay.com', 'Welcome Test LAX 1!', 'Test', '', 'LAX 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (99, 1, 2, 'Test LAX 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 98, 7, 0, 'test.lax.1@liferay.com', 'Test', '', 'LAX 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (100, 1, 98, 13, 98, 0, 0, '100', 0, '/lax1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (101, 1, 100, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (102, 1, 100, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 98);

insert into Users_Orgs (organizationId, userId) values (22, 98);
insert into Users_Orgs (organizationId, userId) values (50, 98);

insert into Users_Roles (roleId, userId) values (18, 98);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (103, 100, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 98, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('d3e556a6-5858-4432-abd1-151eacb13d18', 104, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 105, 'test', 'F', 'F', 'lax2', 'test.lax.2@liferay.com', 'Welcome Test LAX 2!', 'Test', '', 'LAX 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (105, 1, 2, 'Test LAX 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 104, 7, 0, 'test.lax.2@liferay.com', 'Test', '', 'LAX 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (106, 1, 104, 13, 104, 0, 0, '106', 0, '/lax2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (107, 1, 106, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (108, 1, 106, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 104);

insert into Users_Orgs (organizationId, userId) values (22, 104);
insert into Users_Orgs (organizationId, userId) values (50, 104);

insert into Users_Roles (roleId, userId) values (18, 104);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (109, 106, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 104, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3c9f61ed-68d1-4cae-b7e6-45e519353f95', 110, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 111, 'test', 'F', 'F', 'lax3', 'test.lax.3@liferay.com', 'Welcome Test LAX 3!', 'Test', '', 'LAX 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (111, 1, 2, 'Test LAX 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 110, 7, 0, 'test.lax.3@liferay.com', 'Test', '', 'LAX 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (112, 1, 110, 13, 110, 0, 0, '112', 0, '/lax3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (113, 1, 112, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (114, 1, 112, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 110);

insert into Users_Orgs (organizationId, userId) values (22, 110);
insert into Users_Orgs (organizationId, userId) values (50, 110);

insert into Users_Roles (roleId, userId) values (18, 110);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (115, 112, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 110, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('08c6070b-3106-4869-b454-ff2132b13373', 116, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 117, 'test', 'F', 'F', 'lax4', 'test.lax.4@liferay.com', 'Welcome Test LAX 4!', 'Test', '', 'LAX 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (117, 1, 2, 'Test LAX 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 116, 7, 0, 'test.lax.4@liferay.com', 'Test', '', 'LAX 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (118, 1, 116, 13, 116, 0, 0, '118', 0, '/lax4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (119, 1, 118, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (120, 1, 118, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 116);

insert into Users_Orgs (organizationId, userId) values (22, 116);
insert into Users_Orgs (organizationId, userId) values (50, 116);

insert into Users_Roles (roleId, userId) values (18, 116);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (121, 118, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 116, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('d030eb65-0eb6-438b-8a8f-064bf92c284f', 122, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 123, 'test', 'F', 'F', 'lax5', 'test.lax.5@liferay.com', 'Welcome Test LAX 5!', 'Test', '', 'LAX 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (123, 1, 2, 'Test LAX 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 122, 7, 0, 'test.lax.5@liferay.com', 'Test', '', 'LAX 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (124, 1, 122, 13, 122, 0, 0, '124', 0, '/lax5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (125, 1, 124, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (126, 1, 124, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 122);

insert into Users_Orgs (organizationId, userId) values (22, 122);
insert into Users_Orgs (organizationId, userId) values (50, 122);

insert into Users_Roles (roleId, userId) values (18, 122);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (127, 124, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 122, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ae398a35-5af2-4645-b51f-20ddf5f4aa06', 128, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 129, 'test', 'F', 'F', 'lax6', 'test.lax.6@liferay.com', 'Welcome Test LAX 6!', 'Test', '', 'LAX 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (129, 1, 2, 'Test LAX 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 128, 7, 0, 'test.lax.6@liferay.com', 'Test', '', 'LAX 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (130, 1, 128, 13, 128, 0, 0, '130', 0, '/lax6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (131, 1, 130, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (132, 1, 130, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 128);

insert into Users_Orgs (organizationId, userId) values (22, 128);
insert into Users_Orgs (organizationId, userId) values (50, 128);

insert into Users_Roles (roleId, userId) values (18, 128);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (133, 130, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 128, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('82cb6d80-a5eb-4463-bc7d-8f82cc2d6e97', 134, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 135, 'test', 'F', 'F', 'lax7', 'test.lax.7@liferay.com', 'Welcome Test LAX 7!', 'Test', '', 'LAX 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (135, 1, 2, 'Test LAX 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 134, 7, 0, 'test.lax.7@liferay.com', 'Test', '', 'LAX 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (136, 1, 134, 13, 134, 0, 0, '136', 0, '/lax7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (137, 1, 136, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (138, 1, 136, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 134);

insert into Users_Orgs (organizationId, userId) values (22, 134);
insert into Users_Orgs (organizationId, userId) values (50, 134);

insert into Users_Roles (roleId, userId) values (18, 134);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (139, 136, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 134, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('184c97d3-8e29-4ef1-a4a9-d0787ff6d3ab', 140, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 141, 'test', 'F', 'F', 'lax8', 'test.lax.8@liferay.com', 'Welcome Test LAX 8!', 'Test', '', 'LAX 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (141, 1, 2, 'Test LAX 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 140, 7, 0, 'test.lax.8@liferay.com', 'Test', '', 'LAX 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (142, 1, 140, 13, 140, 0, 0, '142', 0, '/lax8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (143, 1, 142, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (144, 1, 142, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 140);

insert into Users_Orgs (organizationId, userId) values (22, 140);
insert into Users_Orgs (organizationId, userId) values (50, 140);

insert into Users_Roles (roleId, userId) values (18, 140);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (145, 142, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 140, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('23889338-1115-4923-8ea5-11e89e0202d5', 146, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 147, 'test', 'F', 'F', 'lax9', 'test.lax.9@liferay.com', 'Welcome Test LAX 9!', 'Test', '', 'LAX 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (147, 1, 2, 'Test LAX 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 146, 7, 0, 'test.lax.9@liferay.com', 'Test', '', 'LAX 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (148, 1, 146, 13, 146, 0, 0, '148', 0, '/lax9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (149, 1, 148, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (150, 1, 148, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 146);

insert into Users_Orgs (organizationId, userId) values (22, 146);
insert into Users_Orgs (organizationId, userId) values (50, 146);

insert into Users_Roles (roleId, userId) values (18, 146);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (151, 148, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 146, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('80a0c405-d684-401e-9050-9b609ecaaf01', 152, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 153, 'test', 'F', 'F', 'lax10', 'test.lax.10@liferay.com', 'Welcome Test LAX 10!', 'Test', '', 'LAX 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (153, 1, 2, 'Test LAX 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 152, 7, 0, 'test.lax.10@liferay.com', 'Test', '', 'LAX 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (154, 1, 152, 13, 152, 0, 0, '154', 0, '/lax10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (155, 1, 154, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (156, 1, 154, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 152);

insert into Users_Orgs (organizationId, userId) values (22, 152);
insert into Users_Orgs (organizationId, userId) values (50, 152);

insert into Users_Roles (roleId, userId) values (18, 152);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (157, 154, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 152, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ee5f3384-93da-4541-8855-2c6800e18957', 158, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 159, 'test', 'F', 'F', 'lax11', 'test.lax.11@liferay.com', 'Welcome Test LAX 11!', 'Test', '', 'LAX 11', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (159, 1, 2, 'Test LAX 11', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 158, 7, 0, 'test.lax.11@liferay.com', 'Test', '', 'LAX 11', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (160, 1, 158, 13, 158, 0, 0, '160', 0, '/lax11', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (161, 1, 160, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (162, 1, 160, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 158);

insert into Users_Orgs (organizationId, userId) values (22, 158);
insert into Users_Orgs (organizationId, userId) values (50, 158);

insert into Users_Roles (roleId, userId) values (18, 158);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (163, 160, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 158, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 11', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('dc03c9fb-d02d-4d40-aaa6-6d7f875816a0', 164, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 165, 'test', 'F', 'F', 'lax12', 'test.lax.12@liferay.com', 'Welcome Test LAX 12!', 'Test', '', 'LAX 12', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (165, 1, 2, 'Test LAX 12', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 164, 7, 0, 'test.lax.12@liferay.com', 'Test', '', 'LAX 12', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (166, 1, 164, 13, 164, 0, 0, '166', 0, '/lax12', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (167, 1, 166, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (168, 1, 166, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 164);

insert into Users_Orgs (organizationId, userId) values (22, 164);
insert into Users_Orgs (organizationId, userId) values (50, 164);

insert into Users_Roles (roleId, userId) values (18, 164);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (169, 166, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 164, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 12', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('66af92de-5e76-46d9-81fd-458b517fe39e', 170, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 171, 'test', 'F', 'F', 'lax13', 'test.lax.13@liferay.com', 'Welcome Test LAX 13!', 'Test', '', 'LAX 13', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (171, 1, 2, 'Test LAX 13', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 170, 7, 0, 'test.lax.13@liferay.com', 'Test', '', 'LAX 13', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (172, 1, 170, 13, 170, 0, 0, '172', 0, '/lax13', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (173, 1, 172, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (174, 1, 172, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 170);

insert into Users_Orgs (organizationId, userId) values (22, 170);
insert into Users_Orgs (organizationId, userId) values (50, 170);

insert into Users_Roles (roleId, userId) values (18, 170);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (175, 172, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 170, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 13', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('434d9cb3-fae2-4ddf-ab6a-d31f7cea0374', 176, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 177, 'test', 'F', 'F', 'lax14', 'test.lax.14@liferay.com', 'Welcome Test LAX 14!', 'Test', '', 'LAX 14', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (177, 1, 2, 'Test LAX 14', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 176, 7, 0, 'test.lax.14@liferay.com', 'Test', '', 'LAX 14', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (178, 1, 176, 13, 176, 0, 0, '178', 0, '/lax14', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (179, 1, 178, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (180, 1, 178, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 176);

insert into Users_Orgs (organizationId, userId) values (22, 176);
insert into Users_Orgs (organizationId, userId) values (50, 176);

insert into Users_Roles (roleId, userId) values (18, 176);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (181, 178, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 176, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 14', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('4f28f10b-3c52-428a-bb1e-b5dbcd3587e0', 182, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 183, 'test', 'F', 'F', 'lax15', 'test.lax.15@liferay.com', 'Welcome Test LAX 15!', 'Test', '', 'LAX 15', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (183, 1, 2, 'Test LAX 15', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 182, 7, 0, 'test.lax.15@liferay.com', 'Test', '', 'LAX 15', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (184, 1, 182, 13, 182, 0, 0, '184', 0, '/lax15', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (185, 1, 184, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (186, 1, 184, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 182);

insert into Users_Orgs (organizationId, userId) values (22, 182);
insert into Users_Orgs (organizationId, userId) values (50, 182);

insert into Users_Roles (roleId, userId) values (18, 182);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (187, 184, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 182, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 15', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ddf16946-e4a5-4a0b-ba07-16e92475dc9d', 188, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 189, 'test', 'F', 'F', 'lax16', 'test.lax.16@liferay.com', 'Welcome Test LAX 16!', 'Test', '', 'LAX 16', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (189, 1, 2, 'Test LAX 16', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 188, 7, 0, 'test.lax.16@liferay.com', 'Test', '', 'LAX 16', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (190, 1, 188, 13, 188, 0, 0, '190', 0, '/lax16', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (191, 1, 190, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (192, 1, 190, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 188);

insert into Users_Orgs (organizationId, userId) values (22, 188);
insert into Users_Orgs (organizationId, userId) values (50, 188);

insert into Users_Roles (roleId, userId) values (18, 188);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (193, 190, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 188, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 16', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3c17f99c-63ac-4b41-80d0-a55d49354cd3', 194, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 195, 'test', 'F', 'F', 'lax17', 'test.lax.17@liferay.com', 'Welcome Test LAX 17!', 'Test', '', 'LAX 17', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (195, 1, 2, 'Test LAX 17', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 194, 7, 0, 'test.lax.17@liferay.com', 'Test', '', 'LAX 17', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (196, 1, 194, 13, 194, 0, 0, '196', 0, '/lax17', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (197, 1, 196, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (198, 1, 196, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 194);

insert into Users_Orgs (organizationId, userId) values (22, 194);
insert into Users_Orgs (organizationId, userId) values (50, 194);

insert into Users_Roles (roleId, userId) values (18, 194);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (199, 196, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 194, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 17', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e5fdce74-1883-455a-acbf-eaf50e8a5aff', 200, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 201, 'test', 'F', 'F', 'lax18', 'test.lax.18@liferay.com', 'Welcome Test LAX 18!', 'Test', '', 'LAX 18', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (201, 1, 2, 'Test LAX 18', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 200, 7, 0, 'test.lax.18@liferay.com', 'Test', '', 'LAX 18', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (202, 1, 200, 13, 200, 0, 0, '202', 0, '/lax18', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (203, 1, 202, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (204, 1, 202, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 200);

insert into Users_Orgs (organizationId, userId) values (22, 200);
insert into Users_Orgs (organizationId, userId) values (50, 200);

insert into Users_Roles (roleId, userId) values (18, 200);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (205, 202, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 200, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 18', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('0d6ac2ad-5f36-448a-8aa8-7513790a5067', 206, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 207, 'test', 'F', 'F', 'lax19', 'test.lax.19@liferay.com', 'Welcome Test LAX 19!', 'Test', '', 'LAX 19', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (207, 1, 2, 'Test LAX 19', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 206, 7, 0, 'test.lax.19@liferay.com', 'Test', '', 'LAX 19', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (208, 1, 206, 13, 206, 0, 0, '208', 0, '/lax19', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (209, 1, 208, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (210, 1, 208, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 206);

insert into Users_Orgs (organizationId, userId) values (22, 206);
insert into Users_Orgs (organizationId, userId) values (50, 206);

insert into Users_Roles (roleId, userId) values (18, 206);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (211, 208, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 206, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 19', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('7229eba2-347e-4f61-a104-b35adac2ddba', 212, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 213, 'test', 'F', 'F', 'lax20', 'test.lax.20@liferay.com', 'Welcome Test LAX 20!', 'Test', '', 'LAX 20', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (213, 1, 2, 'Test LAX 20', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 212, 7, 0, 'test.lax.20@liferay.com', 'Test', '', 'LAX 20', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (214, 1, 212, 13, 212, 0, 0, '214', 0, '/lax20', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (215, 1, 214, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (216, 1, 214, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 212);

insert into Users_Orgs (organizationId, userId) values (22, 212);
insert into Users_Orgs (organizationId, userId) values (50, 212);

insert into Users_Roles (roleId, userId) values (18, 212);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (217, 214, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 212, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 20', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('f1aba5a9-dad6-44ec-a012-e40097b3f0ba', 218, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 219, 'test', 'F', 'F', 'lax21', 'test.lax.21@liferay.com', 'Welcome Test LAX 21!', 'Test', '', 'LAX 21', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (219, 1, 2, 'Test LAX 21', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 218, 7, 0, 'test.lax.21@liferay.com', 'Test', '', 'LAX 21', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (220, 1, 218, 13, 218, 0, 0, '220', 0, '/lax21', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (221, 1, 220, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (222, 1, 220, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 218);

insert into Users_Orgs (organizationId, userId) values (22, 218);
insert into Users_Orgs (organizationId, userId) values (50, 218);

insert into Users_Roles (roleId, userId) values (18, 218);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (223, 220, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 218, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 21', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('043592ff-54d5-4c9e-b589-651aec429e0c', 224, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 225, 'test', 'F', 'F', 'lax22', 'test.lax.22@liferay.com', 'Welcome Test LAX 22!', 'Test', '', 'LAX 22', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (225, 1, 2, 'Test LAX 22', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 224, 7, 0, 'test.lax.22@liferay.com', 'Test', '', 'LAX 22', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (226, 1, 224, 13, 224, 0, 0, '226', 0, '/lax22', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (227, 1, 226, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (228, 1, 226, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 224);

insert into Users_Orgs (organizationId, userId) values (22, 224);
insert into Users_Orgs (organizationId, userId) values (50, 224);

insert into Users_Roles (roleId, userId) values (18, 224);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (229, 226, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 224, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 22', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('7371f02d-aaf1-442d-828d-220ea9818ac0', 230, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 231, 'test', 'F', 'F', 'lax23', 'test.lax.23@liferay.com', 'Welcome Test LAX 23!', 'Test', '', 'LAX 23', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (231, 1, 2, 'Test LAX 23', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 230, 7, 0, 'test.lax.23@liferay.com', 'Test', '', 'LAX 23', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (232, 1, 230, 13, 230, 0, 0, '232', 0, '/lax23', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (233, 1, 232, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (234, 1, 232, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 230);

insert into Users_Orgs (organizationId, userId) values (22, 230);
insert into Users_Orgs (organizationId, userId) values (50, 230);

insert into Users_Roles (roleId, userId) values (18, 230);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (235, 232, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 230, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 23', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('23e4c056-8adb-4a7e-8ed4-bdb3bd1135a9', 236, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 237, 'test', 'F', 'F', 'lax24', 'test.lax.24@liferay.com', 'Welcome Test LAX 24!', 'Test', '', 'LAX 24', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (237, 1, 2, 'Test LAX 24', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 236, 7, 0, 'test.lax.24@liferay.com', 'Test', '', 'LAX 24', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (238, 1, 236, 13, 236, 0, 0, '238', 0, '/lax24', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (239, 1, 238, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (240, 1, 238, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 236);

insert into Users_Orgs (organizationId, userId) values (22, 236);
insert into Users_Orgs (organizationId, userId) values (50, 236);

insert into Users_Roles (roleId, userId) values (18, 236);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (241, 238, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 236, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 24', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('5022619b-7170-403c-a837-58a8f912376c', 242, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 243, 'test', 'F', 'F', 'lax25', 'test.lax.25@liferay.com', 'Welcome Test LAX 25!', 'Test', '', 'LAX 25', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (243, 1, 2, 'Test LAX 25', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 242, 7, 0, 'test.lax.25@liferay.com', 'Test', '', 'LAX 25', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (244, 1, 242, 13, 242, 0, 0, '244', 0, '/lax25', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (245, 1, 244, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (246, 1, 244, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 242);

insert into Users_Orgs (organizationId, userId) values (22, 242);
insert into Users_Orgs (organizationId, userId) values (50, 242);

insert into Users_Roles (roleId, userId) values (18, 242);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (247, 244, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 242, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 25', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('f0376146-1894-4d73-984f-1480ed0e7b48', 248, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 249, 'test', 'F', 'F', 'lax26', 'test.lax.26@liferay.com', 'Welcome Test LAX 26!', 'Test', '', 'LAX 26', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (249, 1, 2, 'Test LAX 26', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 248, 7, 0, 'test.lax.26@liferay.com', 'Test', '', 'LAX 26', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (250, 1, 248, 13, 248, 0, 0, '250', 0, '/lax26', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (251, 1, 250, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (252, 1, 250, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 248);

insert into Users_Orgs (organizationId, userId) values (22, 248);
insert into Users_Orgs (organizationId, userId) values (50, 248);

insert into Users_Roles (roleId, userId) values (18, 248);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (253, 250, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 248, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 26', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('56c0fd9f-1a72-49fa-936e-f74201ec6707', 254, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 255, 'test', 'F', 'F', 'lax27', 'test.lax.27@liferay.com', 'Welcome Test LAX 27!', 'Test', '', 'LAX 27', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (255, 1, 2, 'Test LAX 27', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 254, 7, 0, 'test.lax.27@liferay.com', 'Test', '', 'LAX 27', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (256, 1, 254, 13, 254, 0, 0, '256', 0, '/lax27', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (257, 1, 256, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (258, 1, 256, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 254);

insert into Users_Orgs (organizationId, userId) values (22, 254);
insert into Users_Orgs (organizationId, userId) values (50, 254);

insert into Users_Roles (roleId, userId) values (18, 254);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (259, 256, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 254, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 27', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('1acdec76-d966-4069-a31c-4d82ffa35e10', 260, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 261, 'test', 'F', 'F', 'lax28', 'test.lax.28@liferay.com', 'Welcome Test LAX 28!', 'Test', '', 'LAX 28', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (261, 1, 2, 'Test LAX 28', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 260, 7, 0, 'test.lax.28@liferay.com', 'Test', '', 'LAX 28', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (262, 1, 260, 13, 260, 0, 0, '262', 0, '/lax28', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (263, 1, 262, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (264, 1, 262, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 260);

insert into Users_Orgs (organizationId, userId) values (22, 260);
insert into Users_Orgs (organizationId, userId) values (50, 260);

insert into Users_Roles (roleId, userId) values (18, 260);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (265, 262, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 260, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 28', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('5cedd7cf-b981-4d03-9109-861cef53ddb8', 266, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 267, 'test', 'F', 'F', 'lax29', 'test.lax.29@liferay.com', 'Welcome Test LAX 29!', 'Test', '', 'LAX 29', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (267, 1, 2, 'Test LAX 29', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 266, 7, 0, 'test.lax.29@liferay.com', 'Test', '', 'LAX 29', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (268, 1, 266, 13, 266, 0, 0, '268', 0, '/lax29', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (269, 1, 268, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (270, 1, 268, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 266);

insert into Users_Orgs (organizationId, userId) values (22, 266);
insert into Users_Orgs (organizationId, userId) values (50, 266);

insert into Users_Roles (roleId, userId) values (18, 266);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (271, 268, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 266, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 29', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('08ca5095-8484-41c4-ab82-929e99c6e831', 272, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 273, 'test', 'F', 'F', 'lax30', 'test.lax.30@liferay.com', 'Welcome Test LAX 30!', 'Test', '', 'LAX 30', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (273, 1, 2, 'Test LAX 30', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 272, 7, 0, 'test.lax.30@liferay.com', 'Test', '', 'LAX 30', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (274, 1, 272, 13, 272, 0, 0, '274', 0, '/lax30', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (275, 1, 274, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (276, 1, 274, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 272);

insert into Users_Orgs (organizationId, userId) values (22, 272);
insert into Users_Orgs (organizationId, userId) values (50, 272);

insert into Users_Roles (roleId, userId) values (18, 272);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (277, 274, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 272, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 30', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('0f4a6654-db66-47dc-be6c-55c84bb32514', 278, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 279, 'test', 'F', 'F', 'lax31', 'test.lax.31@liferay.com', 'Welcome Test LAX 31!', 'Test', '', 'LAX 31', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (279, 1, 2, 'Test LAX 31', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 278, 7, 0, 'test.lax.31@liferay.com', 'Test', '', 'LAX 31', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (280, 1, 278, 13, 278, 0, 0, '280', 0, '/lax31', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (281, 1, 280, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (282, 1, 280, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 278);

insert into Users_Orgs (organizationId, userId) values (22, 278);
insert into Users_Orgs (organizationId, userId) values (50, 278);

insert into Users_Roles (roleId, userId) values (18, 278);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (283, 280, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 278, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 31', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('d57a533a-179d-471e-bbd5-382a590379e5', 284, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 285, 'test', 'F', 'F', 'lax32', 'test.lax.32@liferay.com', 'Welcome Test LAX 32!', 'Test', '', 'LAX 32', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (285, 1, 2, 'Test LAX 32', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 284, 7, 0, 'test.lax.32@liferay.com', 'Test', '', 'LAX 32', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (286, 1, 284, 13, 284, 0, 0, '286', 0, '/lax32', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (287, 1, 286, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (288, 1, 286, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 284);

insert into Users_Orgs (organizationId, userId) values (22, 284);
insert into Users_Orgs (organizationId, userId) values (50, 284);

insert into Users_Roles (roleId, userId) values (18, 284);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (289, 286, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 284, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 32', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('a22f2ec0-d192-4029-a769-351372a164fd', 290, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 291, 'test', 'F', 'F', 'lax33', 'test.lax.33@liferay.com', 'Welcome Test LAX 33!', 'Test', '', 'LAX 33', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (291, 1, 2, 'Test LAX 33', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 290, 7, 0, 'test.lax.33@liferay.com', 'Test', '', 'LAX 33', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (292, 1, 290, 13, 290, 0, 0, '292', 0, '/lax33', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (293, 1, 292, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (294, 1, 292, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 290);

insert into Users_Orgs (organizationId, userId) values (22, 290);
insert into Users_Orgs (organizationId, userId) values (50, 290);

insert into Users_Roles (roleId, userId) values (18, 290);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (295, 292, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 290, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 33', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('6be318d6-e504-44fe-8e83-25fc5e263336', 296, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 297, 'test', 'F', 'F', 'lax34', 'test.lax.34@liferay.com', 'Welcome Test LAX 34!', 'Test', '', 'LAX 34', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (297, 1, 2, 'Test LAX 34', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 296, 7, 0, 'test.lax.34@liferay.com', 'Test', '', 'LAX 34', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (298, 1, 296, 13, 296, 0, 0, '298', 0, '/lax34', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (299, 1, 298, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (300, 1, 298, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 296);

insert into Users_Orgs (organizationId, userId) values (22, 296);
insert into Users_Orgs (organizationId, userId) values (50, 296);

insert into Users_Roles (roleId, userId) values (18, 296);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (301, 298, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 296, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 34', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('c3e193e6-9536-4d1d-a7d6-726b99b83548', 302, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 303, 'test', 'F', 'F', 'lax35', 'test.lax.35@liferay.com', 'Welcome Test LAX 35!', 'Test', '', 'LAX 35', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (303, 1, 2, 'Test LAX 35', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 302, 7, 0, 'test.lax.35@liferay.com', 'Test', '', 'LAX 35', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (304, 1, 302, 13, 302, 0, 0, '304', 0, '/lax35', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (305, 1, 304, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (306, 1, 304, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 302);

insert into Users_Orgs (organizationId, userId) values (22, 302);
insert into Users_Orgs (organizationId, userId) values (50, 302);

insert into Users_Roles (roleId, userId) values (18, 302);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (307, 304, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 302, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 35', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3f0faacc-b8d7-4e00-aba8-b55a5cc1abd3', 308, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 309, 'test', 'F', 'F', 'lax36', 'test.lax.36@liferay.com', 'Welcome Test LAX 36!', 'Test', '', 'LAX 36', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (309, 1, 2, 'Test LAX 36', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 308, 7, 0, 'test.lax.36@liferay.com', 'Test', '', 'LAX 36', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (310, 1, 308, 13, 308, 0, 0, '310', 0, '/lax36', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (311, 1, 310, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (312, 1, 310, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 308);

insert into Users_Orgs (organizationId, userId) values (22, 308);
insert into Users_Orgs (organizationId, userId) values (50, 308);

insert into Users_Roles (roleId, userId) values (18, 308);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (313, 310, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 308, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 36', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('0d37f2f4-fbc8-4cb7-947e-b86aa65c495d', 314, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 315, 'test', 'F', 'F', 'lax37', 'test.lax.37@liferay.com', 'Welcome Test LAX 37!', 'Test', '', 'LAX 37', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (315, 1, 2, 'Test LAX 37', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 314, 7, 0, 'test.lax.37@liferay.com', 'Test', '', 'LAX 37', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (316, 1, 314, 13, 314, 0, 0, '316', 0, '/lax37', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (317, 1, 316, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (318, 1, 316, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 314);

insert into Users_Orgs (organizationId, userId) values (22, 314);
insert into Users_Orgs (organizationId, userId) values (50, 314);

insert into Users_Roles (roleId, userId) values (18, 314);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (319, 316, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 314, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 37', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('560291fc-e0bb-40eb-8c2c-c1e6d77699b6', 320, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 321, 'test', 'F', 'F', 'lax38', 'test.lax.38@liferay.com', 'Welcome Test LAX 38!', 'Test', '', 'LAX 38', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (321, 1, 2, 'Test LAX 38', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 320, 7, 0, 'test.lax.38@liferay.com', 'Test', '', 'LAX 38', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (322, 1, 320, 13, 320, 0, 0, '322', 0, '/lax38', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (323, 1, 322, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (324, 1, 322, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 320);

insert into Users_Orgs (organizationId, userId) values (22, 320);
insert into Users_Orgs (organizationId, userId) values (50, 320);

insert into Users_Roles (roleId, userId) values (18, 320);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (325, 322, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 320, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 38', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('22f18309-4595-475d-b169-3b020ef1de71', 326, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 327, 'test', 'F', 'F', 'lax39', 'test.lax.39@liferay.com', 'Welcome Test LAX 39!', 'Test', '', 'LAX 39', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (327, 1, 2, 'Test LAX 39', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 326, 7, 0, 'test.lax.39@liferay.com', 'Test', '', 'LAX 39', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (328, 1, 326, 13, 326, 0, 0, '328', 0, '/lax39', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (329, 1, 328, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (330, 1, 328, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 326);

insert into Users_Orgs (organizationId, userId) values (22, 326);
insert into Users_Orgs (organizationId, userId) values (50, 326);

insert into Users_Roles (roleId, userId) values (18, 326);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (331, 328, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 326, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 39', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('4a33863a-e2b3-47fb-9387-39001918f730', 332, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 333, 'test', 'F', 'F', 'lax40', 'test.lax.40@liferay.com', 'Welcome Test LAX 40!', 'Test', '', 'LAX 40', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (333, 1, 2, 'Test LAX 40', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 332, 7, 0, 'test.lax.40@liferay.com', 'Test', '', 'LAX 40', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (334, 1, 332, 13, 332, 0, 0, '334', 0, '/lax40', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (335, 1, 334, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (336, 1, 334, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 332);

insert into Users_Orgs (organizationId, userId) values (22, 332);
insert into Users_Orgs (organizationId, userId) values (50, 332);

insert into Users_Roles (roleId, userId) values (18, 332);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (337, 334, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 332, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 40', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3764d5aa-170f-4603-851b-2962079f0144', 338, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 339, 'test', 'F', 'F', 'lax41', 'test.lax.41@liferay.com', 'Welcome Test LAX 41!', 'Test', '', 'LAX 41', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (339, 1, 2, 'Test LAX 41', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 338, 7, 0, 'test.lax.41@liferay.com', 'Test', '', 'LAX 41', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (340, 1, 338, 13, 338, 0, 0, '340', 0, '/lax41', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (341, 1, 340, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (342, 1, 340, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 338);

insert into Users_Orgs (organizationId, userId) values (22, 338);
insert into Users_Orgs (organizationId, userId) values (50, 338);

insert into Users_Roles (roleId, userId) values (18, 338);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (343, 340, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 338, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 41', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('0101ed01-c3f4-4491-8299-660994272c36', 344, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 345, 'test', 'F', 'F', 'lax42', 'test.lax.42@liferay.com', 'Welcome Test LAX 42!', 'Test', '', 'LAX 42', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (345, 1, 2, 'Test LAX 42', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 344, 7, 0, 'test.lax.42@liferay.com', 'Test', '', 'LAX 42', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (346, 1, 344, 13, 344, 0, 0, '346', 0, '/lax42', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (347, 1, 346, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (348, 1, 346, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 344);

insert into Users_Orgs (organizationId, userId) values (22, 344);
insert into Users_Orgs (organizationId, userId) values (50, 344);

insert into Users_Roles (roleId, userId) values (18, 344);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (349, 346, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 344, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 42', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('00cfb52a-bb6e-4178-9198-ab97e8ebf133', 350, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 351, 'test', 'F', 'F', 'lax43', 'test.lax.43@liferay.com', 'Welcome Test LAX 43!', 'Test', '', 'LAX 43', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (351, 1, 2, 'Test LAX 43', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 350, 7, 0, 'test.lax.43@liferay.com', 'Test', '', 'LAX 43', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (352, 1, 350, 13, 350, 0, 0, '352', 0, '/lax43', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (353, 1, 352, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (354, 1, 352, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 350);

insert into Users_Orgs (organizationId, userId) values (22, 350);
insert into Users_Orgs (organizationId, userId) values (50, 350);

insert into Users_Roles (roleId, userId) values (18, 350);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (355, 352, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 350, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 43', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('97901cca-8ac0-45c6-9ac3-cae446f5e01f', 356, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 357, 'test', 'F', 'F', 'lax44', 'test.lax.44@liferay.com', 'Welcome Test LAX 44!', 'Test', '', 'LAX 44', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (357, 1, 2, 'Test LAX 44', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 356, 7, 0, 'test.lax.44@liferay.com', 'Test', '', 'LAX 44', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (358, 1, 356, 13, 356, 0, 0, '358', 0, '/lax44', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (359, 1, 358, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (360, 1, 358, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 356);

insert into Users_Orgs (organizationId, userId) values (22, 356);
insert into Users_Orgs (organizationId, userId) values (50, 356);

insert into Users_Roles (roleId, userId) values (18, 356);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (361, 358, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 356, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 44', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('bd166d36-df46-4f90-8162-ede2a1ab681c', 362, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 363, 'test', 'F', 'F', 'lax45', 'test.lax.45@liferay.com', 'Welcome Test LAX 45!', 'Test', '', 'LAX 45', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (363, 1, 2, 'Test LAX 45', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 362, 7, 0, 'test.lax.45@liferay.com', 'Test', '', 'LAX 45', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (364, 1, 362, 13, 362, 0, 0, '364', 0, '/lax45', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (365, 1, 364, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (366, 1, 364, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 362);

insert into Users_Orgs (organizationId, userId) values (22, 362);
insert into Users_Orgs (organizationId, userId) values (50, 362);

insert into Users_Roles (roleId, userId) values (18, 362);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (367, 364, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 362, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 45', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('dac2a868-c39e-401f-a0c4-4fafdab57a37', 368, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 369, 'test', 'F', 'F', 'lax46', 'test.lax.46@liferay.com', 'Welcome Test LAX 46!', 'Test', '', 'LAX 46', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (369, 1, 2, 'Test LAX 46', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 368, 7, 0, 'test.lax.46@liferay.com', 'Test', '', 'LAX 46', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (370, 1, 368, 13, 368, 0, 0, '370', 0, '/lax46', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (371, 1, 370, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (372, 1, 370, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 368);

insert into Users_Orgs (organizationId, userId) values (22, 368);
insert into Users_Orgs (organizationId, userId) values (50, 368);

insert into Users_Roles (roleId, userId) values (18, 368);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (373, 370, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 368, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 46', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('25fe0cc4-f4db-4710-8f56-488cf8156422', 374, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 375, 'test', 'F', 'F', 'lax47', 'test.lax.47@liferay.com', 'Welcome Test LAX 47!', 'Test', '', 'LAX 47', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (375, 1, 2, 'Test LAX 47', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 374, 7, 0, 'test.lax.47@liferay.com', 'Test', '', 'LAX 47', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (376, 1, 374, 13, 374, 0, 0, '376', 0, '/lax47', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (377, 1, 376, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (378, 1, 376, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 374);

insert into Users_Orgs (organizationId, userId) values (22, 374);
insert into Users_Orgs (organizationId, userId) values (50, 374);

insert into Users_Roles (roleId, userId) values (18, 374);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (379, 376, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 374, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 47', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('2a49689b-a2f5-429a-86ba-9bd7324f5877', 380, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 381, 'test', 'F', 'F', 'lax48', 'test.lax.48@liferay.com', 'Welcome Test LAX 48!', 'Test', '', 'LAX 48', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (381, 1, 2, 'Test LAX 48', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 380, 7, 0, 'test.lax.48@liferay.com', 'Test', '', 'LAX 48', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (382, 1, 380, 13, 380, 0, 0, '382', 0, '/lax48', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (383, 1, 382, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (384, 1, 382, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 380);

insert into Users_Orgs (organizationId, userId) values (22, 380);
insert into Users_Orgs (organizationId, userId) values (50, 380);

insert into Users_Roles (roleId, userId) values (18, 380);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (385, 382, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 380, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 48', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('711e8888-8672-432d-8786-bcac9d63ad9d', 386, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 387, 'test', 'F', 'F', 'lax49', 'test.lax.49@liferay.com', 'Welcome Test LAX 49!', 'Test', '', 'LAX 49', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (387, 1, 2, 'Test LAX 49', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 386, 7, 0, 'test.lax.49@liferay.com', 'Test', '', 'LAX 49', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (388, 1, 386, 13, 386, 0, 0, '388', 0, '/lax49', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (389, 1, 388, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (390, 1, 388, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 386);

insert into Users_Orgs (organizationId, userId) values (22, 386);
insert into Users_Orgs (organizationId, userId) values (50, 386);

insert into Users_Roles (roleId, userId) values (18, 386);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (391, 388, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 386, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 49', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e0f555f4-2e87-4695-84f0-6c195b2c83f7', 392, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 393, 'test', 'F', 'F', 'lax50', 'test.lax.50@liferay.com', 'Welcome Test LAX 50!', 'Test', '', 'LAX 50', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (393, 1, 2, 'Test LAX 50', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 392, 7, 0, 'test.lax.50@liferay.com', 'Test', '', 'LAX 50', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (394, 1, 392, 13, 392, 0, 0, '394', 0, '/lax50', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (395, 1, 394, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (396, 1, 394, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 392);

insert into Users_Orgs (organizationId, userId) values (22, 392);
insert into Users_Orgs (organizationId, userId) values (50, 392);

insert into Users_Roles (roleId, userId) values (18, 392);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (397, 394, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 392, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 50', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('64b44eea-e949-4f28-92a7-9cbec2c92d14', 398, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 399, 'test', 'F', 'F', 'lax51', 'test.lax.51@liferay.com', 'Welcome Test LAX 51!', 'Test', '', 'LAX 51', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (399, 1, 2, 'Test LAX 51', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 398, 7, 0, 'test.lax.51@liferay.com', 'Test', '', 'LAX 51', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (400, 1, 398, 13, 398, 0, 0, '400', 0, '/lax51', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (401, 1, 400, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (402, 1, 400, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 398);

insert into Users_Orgs (organizationId, userId) values (22, 398);
insert into Users_Orgs (organizationId, userId) values (50, 398);

insert into Users_Roles (roleId, userId) values (18, 398);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (403, 400, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 398, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 51', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3ac2b846-a044-437c-a59c-cb8c55f611f3', 404, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 405, 'test', 'F', 'F', 'lax52', 'test.lax.52@liferay.com', 'Welcome Test LAX 52!', 'Test', '', 'LAX 52', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (405, 1, 2, 'Test LAX 52', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 404, 7, 0, 'test.lax.52@liferay.com', 'Test', '', 'LAX 52', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (406, 1, 404, 13, 404, 0, 0, '406', 0, '/lax52', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (407, 1, 406, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (408, 1, 406, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 404);

insert into Users_Orgs (organizationId, userId) values (22, 404);
insert into Users_Orgs (organizationId, userId) values (50, 404);

insert into Users_Roles (roleId, userId) values (18, 404);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (409, 406, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 404, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 52', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('305239e7-45d0-4888-b5d9-70e8f04af731', 410, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 411, 'test', 'F', 'F', 'lax53', 'test.lax.53@liferay.com', 'Welcome Test LAX 53!', 'Test', '', 'LAX 53', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (411, 1, 2, 'Test LAX 53', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 410, 7, 0, 'test.lax.53@liferay.com', 'Test', '', 'LAX 53', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (412, 1, 410, 13, 410, 0, 0, '412', 0, '/lax53', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (413, 1, 412, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (414, 1, 412, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 410);

insert into Users_Orgs (organizationId, userId) values (22, 410);
insert into Users_Orgs (organizationId, userId) values (50, 410);

insert into Users_Roles (roleId, userId) values (18, 410);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (415, 412, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 410, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 53', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('2064196e-190e-4d7e-978c-c4d26bd49a12', 416, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 417, 'test', 'F', 'F', 'lax54', 'test.lax.54@liferay.com', 'Welcome Test LAX 54!', 'Test', '', 'LAX 54', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (417, 1, 2, 'Test LAX 54', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 416, 7, 0, 'test.lax.54@liferay.com', 'Test', '', 'LAX 54', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (418, 1, 416, 13, 416, 0, 0, '418', 0, '/lax54', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (419, 1, 418, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (420, 1, 418, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 416);

insert into Users_Orgs (organizationId, userId) values (22, 416);
insert into Users_Orgs (organizationId, userId) values (50, 416);

insert into Users_Roles (roleId, userId) values (18, 416);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (421, 418, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 416, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 54', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('14baa733-5446-402c-bbca-3f7b12fc3e4b', 422, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 423, 'test', 'F', 'F', 'lax55', 'test.lax.55@liferay.com', 'Welcome Test LAX 55!', 'Test', '', 'LAX 55', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (423, 1, 2, 'Test LAX 55', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 422, 7, 0, 'test.lax.55@liferay.com', 'Test', '', 'LAX 55', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (424, 1, 422, 13, 422, 0, 0, '424', 0, '/lax55', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (425, 1, 424, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (426, 1, 424, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 422);

insert into Users_Orgs (organizationId, userId) values (22, 422);
insert into Users_Orgs (organizationId, userId) values (50, 422);

insert into Users_Roles (roleId, userId) values (18, 422);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (427, 424, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 422, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 55', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('f38e0d02-7094-4b7d-b192-ad567e8ee273', 428, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 429, 'test', 'F', 'F', 'lax56', 'test.lax.56@liferay.com', 'Welcome Test LAX 56!', 'Test', '', 'LAX 56', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (429, 1, 2, 'Test LAX 56', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 428, 7, 0, 'test.lax.56@liferay.com', 'Test', '', 'LAX 56', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (430, 1, 428, 13, 428, 0, 0, '430', 0, '/lax56', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (431, 1, 430, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (432, 1, 430, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 428);

insert into Users_Orgs (organizationId, userId) values (22, 428);
insert into Users_Orgs (organizationId, userId) values (50, 428);

insert into Users_Roles (roleId, userId) values (18, 428);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (433, 430, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 428, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 56', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ca1dbc66-6fd7-4e13-81fe-b9abaeac2847', 434, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 435, 'test', 'F', 'F', 'lax57', 'test.lax.57@liferay.com', 'Welcome Test LAX 57!', 'Test', '', 'LAX 57', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (435, 1, 2, 'Test LAX 57', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 434, 7, 0, 'test.lax.57@liferay.com', 'Test', '', 'LAX 57', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (436, 1, 434, 13, 434, 0, 0, '436', 0, '/lax57', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (437, 1, 436, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (438, 1, 436, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 434);

insert into Users_Orgs (organizationId, userId) values (22, 434);
insert into Users_Orgs (organizationId, userId) values (50, 434);

insert into Users_Roles (roleId, userId) values (18, 434);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (439, 436, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 434, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 57', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e6733c10-f53d-4939-9446-1b9ac017020c', 440, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 441, 'test', 'F', 'F', 'lax58', 'test.lax.58@liferay.com', 'Welcome Test LAX 58!', 'Test', '', 'LAX 58', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (441, 1, 2, 'Test LAX 58', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 440, 7, 0, 'test.lax.58@liferay.com', 'Test', '', 'LAX 58', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (442, 1, 440, 13, 440, 0, 0, '442', 0, '/lax58', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (443, 1, 442, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (444, 1, 442, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 440);

insert into Users_Orgs (organizationId, userId) values (22, 440);
insert into Users_Orgs (organizationId, userId) values (50, 440);

insert into Users_Roles (roleId, userId) values (18, 440);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (445, 442, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 440, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 58', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('cf2d966b-3ba7-48b6-867d-8cc469800c6e', 446, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 447, 'test', 'F', 'F', 'lax59', 'test.lax.59@liferay.com', 'Welcome Test LAX 59!', 'Test', '', 'LAX 59', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (447, 1, 2, 'Test LAX 59', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 446, 7, 0, 'test.lax.59@liferay.com', 'Test', '', 'LAX 59', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (448, 1, 446, 13, 446, 0, 0, '448', 0, '/lax59', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (449, 1, 448, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (450, 1, 448, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 446);

insert into Users_Orgs (organizationId, userId) values (22, 446);
insert into Users_Orgs (organizationId, userId) values (50, 446);

insert into Users_Roles (roleId, userId) values (18, 446);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (451, 448, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 446, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 59', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('c0c2a83a-fff6-4226-9410-1b7b5076a877', 452, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 453, 'test', 'F', 'F', 'lax60', 'test.lax.60@liferay.com', 'Welcome Test LAX 60!', 'Test', '', 'LAX 60', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (453, 1, 2, 'Test LAX 60', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 452, 7, 0, 'test.lax.60@liferay.com', 'Test', '', 'LAX 60', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (454, 1, 452, 13, 452, 0, 0, '454', 0, '/lax60', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (455, 1, 454, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (456, 1, 454, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 452);

insert into Users_Orgs (organizationId, userId) values (22, 452);
insert into Users_Orgs (organizationId, userId) values (50, 452);

insert into Users_Roles (roleId, userId) values (18, 452);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (457, 454, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 452, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 60', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('bb2cc24a-c4a5-4dc7-9cc9-3e46d99c6593', 458, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 459, 'test', 'F', 'F', 'lax61', 'test.lax.61@liferay.com', 'Welcome Test LAX 61!', 'Test', '', 'LAX 61', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (459, 1, 2, 'Test LAX 61', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 458, 7, 0, 'test.lax.61@liferay.com', 'Test', '', 'LAX 61', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (460, 1, 458, 13, 458, 0, 0, '460', 0, '/lax61', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (461, 1, 460, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (462, 1, 460, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 458);

insert into Users_Orgs (organizationId, userId) values (22, 458);
insert into Users_Orgs (organizationId, userId) values (50, 458);

insert into Users_Roles (roleId, userId) values (18, 458);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (463, 460, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 458, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 61', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('9e62323f-8f29-4d40-9e24-9e614f2b0595', 464, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 465, 'test', 'F', 'F', 'lax62', 'test.lax.62@liferay.com', 'Welcome Test LAX 62!', 'Test', '', 'LAX 62', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (465, 1, 2, 'Test LAX 62', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 464, 7, 0, 'test.lax.62@liferay.com', 'Test', '', 'LAX 62', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (466, 1, 464, 13, 464, 0, 0, '466', 0, '/lax62', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (467, 1, 466, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (468, 1, 466, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 464);

insert into Users_Orgs (organizationId, userId) values (22, 464);
insert into Users_Orgs (organizationId, userId) values (50, 464);

insert into Users_Roles (roleId, userId) values (18, 464);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (469, 466, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 464, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 62', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('24886ca4-ea0b-4bcf-817b-dec049a85f4b', 470, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 471, 'test', 'F', 'F', 'lax63', 'test.lax.63@liferay.com', 'Welcome Test LAX 63!', 'Test', '', 'LAX 63', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (471, 1, 2, 'Test LAX 63', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 470, 7, 0, 'test.lax.63@liferay.com', 'Test', '', 'LAX 63', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (472, 1, 470, 13, 470, 0, 0, '472', 0, '/lax63', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (473, 1, 472, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (474, 1, 472, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 470);

insert into Users_Orgs (organizationId, userId) values (22, 470);
insert into Users_Orgs (organizationId, userId) values (50, 470);

insert into Users_Roles (roleId, userId) values (18, 470);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (475, 472, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 470, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 63', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('a2e1a668-5588-4c3c-bf23-f5cfd7765875', 476, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 477, 'test', 'F', 'F', 'lax64', 'test.lax.64@liferay.com', 'Welcome Test LAX 64!', 'Test', '', 'LAX 64', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (477, 1, 2, 'Test LAX 64', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 476, 7, 0, 'test.lax.64@liferay.com', 'Test', '', 'LAX 64', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (478, 1, 476, 13, 476, 0, 0, '478', 0, '/lax64', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (479, 1, 478, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (480, 1, 478, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 476);

insert into Users_Orgs (organizationId, userId) values (22, 476);
insert into Users_Orgs (organizationId, userId) values (50, 476);

insert into Users_Roles (roleId, userId) values (18, 476);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (481, 478, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 476, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 64', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('87ec6768-bdb4-46a0-87b3-8901271b3eb2', 482, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 483, 'test', 'F', 'F', 'lax65', 'test.lax.65@liferay.com', 'Welcome Test LAX 65!', 'Test', '', 'LAX 65', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (483, 1, 2, 'Test LAX 65', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 482, 7, 0, 'test.lax.65@liferay.com', 'Test', '', 'LAX 65', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (484, 1, 482, 13, 482, 0, 0, '484', 0, '/lax65', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (485, 1, 484, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (486, 1, 484, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 482);

insert into Users_Orgs (organizationId, userId) values (22, 482);
insert into Users_Orgs (organizationId, userId) values (50, 482);

insert into Users_Roles (roleId, userId) values (18, 482);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (487, 484, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 482, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 65', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e482b720-827a-4c1c-98fe-44fbcc662073', 488, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 489, 'test', 'F', 'F', 'lax66', 'test.lax.66@liferay.com', 'Welcome Test LAX 66!', 'Test', '', 'LAX 66', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (489, 1, 2, 'Test LAX 66', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 488, 7, 0, 'test.lax.66@liferay.com', 'Test', '', 'LAX 66', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (490, 1, 488, 13, 488, 0, 0, '490', 0, '/lax66', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (491, 1, 490, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (492, 1, 490, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 488);

insert into Users_Orgs (organizationId, userId) values (22, 488);
insert into Users_Orgs (organizationId, userId) values (50, 488);

insert into Users_Roles (roleId, userId) values (18, 488);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (493, 490, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 488, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 66', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('7c24c0bd-6326-4a0c-925b-f379fdd5600c', 494, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 495, 'test', 'F', 'F', 'lax67', 'test.lax.67@liferay.com', 'Welcome Test LAX 67!', 'Test', '', 'LAX 67', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (495, 1, 2, 'Test LAX 67', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 494, 7, 0, 'test.lax.67@liferay.com', 'Test', '', 'LAX 67', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (496, 1, 494, 13, 494, 0, 0, '496', 0, '/lax67', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (497, 1, 496, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (498, 1, 496, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 494);

insert into Users_Orgs (organizationId, userId) values (22, 494);
insert into Users_Orgs (organizationId, userId) values (50, 494);

insert into Users_Roles (roleId, userId) values (18, 494);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (499, 496, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 494, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 67', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('43e1b4fb-5431-4eff-8b6c-a5881510e587', 500, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 501, 'test', 'F', 'F', 'lax68', 'test.lax.68@liferay.com', 'Welcome Test LAX 68!', 'Test', '', 'LAX 68', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (501, 1, 2, 'Test LAX 68', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 500, 7, 0, 'test.lax.68@liferay.com', 'Test', '', 'LAX 68', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (502, 1, 500, 13, 500, 0, 0, '502', 0, '/lax68', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (503, 1, 502, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (504, 1, 502, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 500);

insert into Users_Orgs (organizationId, userId) values (22, 500);
insert into Users_Orgs (organizationId, userId) values (50, 500);

insert into Users_Roles (roleId, userId) values (18, 500);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (505, 502, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 500, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 68', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('5351e43c-935b-451e-83c9-ac1cf09f08f8', 506, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 507, 'test', 'F', 'F', 'lax69', 'test.lax.69@liferay.com', 'Welcome Test LAX 69!', 'Test', '', 'LAX 69', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (507, 1, 2, 'Test LAX 69', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 506, 7, 0, 'test.lax.69@liferay.com', 'Test', '', 'LAX 69', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (508, 1, 506, 13, 506, 0, 0, '508', 0, '/lax69', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (509, 1, 508, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (510, 1, 508, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 506);

insert into Users_Orgs (organizationId, userId) values (22, 506);
insert into Users_Orgs (organizationId, userId) values (50, 506);

insert into Users_Roles (roleId, userId) values (18, 506);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (511, 508, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 506, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 69', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('26cbbd6b-d690-46d1-84cc-13f0809d7d15', 512, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 513, 'test', 'F', 'F', 'lax70', 'test.lax.70@liferay.com', 'Welcome Test LAX 70!', 'Test', '', 'LAX 70', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (513, 1, 2, 'Test LAX 70', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 512, 7, 0, 'test.lax.70@liferay.com', 'Test', '', 'LAX 70', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (514, 1, 512, 13, 512, 0, 0, '514', 0, '/lax70', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (515, 1, 514, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (516, 1, 514, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 512);

insert into Users_Orgs (organizationId, userId) values (22, 512);
insert into Users_Orgs (organizationId, userId) values (50, 512);

insert into Users_Roles (roleId, userId) values (18, 512);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (517, 514, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 512, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 70', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('806a025d-8d57-4b67-9c05-a5dfe19ae114', 518, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 519, 'test', 'F', 'F', 'lax71', 'test.lax.71@liferay.com', 'Welcome Test LAX 71!', 'Test', '', 'LAX 71', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (519, 1, 2, 'Test LAX 71', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 518, 7, 0, 'test.lax.71@liferay.com', 'Test', '', 'LAX 71', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (520, 1, 518, 13, 518, 0, 0, '520', 0, '/lax71', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (521, 1, 520, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (522, 1, 520, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 518);

insert into Users_Orgs (organizationId, userId) values (22, 518);
insert into Users_Orgs (organizationId, userId) values (50, 518);

insert into Users_Roles (roleId, userId) values (18, 518);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (523, 520, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 518, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 71', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('d62673f3-6448-4c59-b9c8-de1824dc97d4', 524, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 525, 'test', 'F', 'F', 'lax72', 'test.lax.72@liferay.com', 'Welcome Test LAX 72!', 'Test', '', 'LAX 72', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (525, 1, 2, 'Test LAX 72', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 524, 7, 0, 'test.lax.72@liferay.com', 'Test', '', 'LAX 72', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (526, 1, 524, 13, 524, 0, 0, '526', 0, '/lax72', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (527, 1, 526, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (528, 1, 526, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 524);

insert into Users_Orgs (organizationId, userId) values (22, 524);
insert into Users_Orgs (organizationId, userId) values (50, 524);

insert into Users_Roles (roleId, userId) values (18, 524);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (529, 526, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 524, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 72', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('b1d9eb95-1f6b-4974-af2b-ec975fb0822e', 530, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 531, 'test', 'F', 'F', 'lax73', 'test.lax.73@liferay.com', 'Welcome Test LAX 73!', 'Test', '', 'LAX 73', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (531, 1, 2, 'Test LAX 73', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 530, 7, 0, 'test.lax.73@liferay.com', 'Test', '', 'LAX 73', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (532, 1, 530, 13, 530, 0, 0, '532', 0, '/lax73', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (533, 1, 532, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (534, 1, 532, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 530);

insert into Users_Orgs (organizationId, userId) values (22, 530);
insert into Users_Orgs (organizationId, userId) values (50, 530);

insert into Users_Roles (roleId, userId) values (18, 530);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (535, 532, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 530, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 73', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('38a44a86-e8b9-44c6-b34c-3ab523fcb428', 536, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 537, 'test', 'F', 'F', 'lax74', 'test.lax.74@liferay.com', 'Welcome Test LAX 74!', 'Test', '', 'LAX 74', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (537, 1, 2, 'Test LAX 74', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 536, 7, 0, 'test.lax.74@liferay.com', 'Test', '', 'LAX 74', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (538, 1, 536, 13, 536, 0, 0, '538', 0, '/lax74', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (539, 1, 538, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (540, 1, 538, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 536);

insert into Users_Orgs (organizationId, userId) values (22, 536);
insert into Users_Orgs (organizationId, userId) values (50, 536);

insert into Users_Roles (roleId, userId) values (18, 536);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (541, 538, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 536, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 74', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ffd589f2-1976-47b4-a2e5-6fba7a75fd3a', 542, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 543, 'test', 'F', 'F', 'lax75', 'test.lax.75@liferay.com', 'Welcome Test LAX 75!', 'Test', '', 'LAX 75', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (543, 1, 2, 'Test LAX 75', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 542, 7, 0, 'test.lax.75@liferay.com', 'Test', '', 'LAX 75', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (544, 1, 542, 13, 542, 0, 0, '544', 0, '/lax75', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (545, 1, 544, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (546, 1, 544, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 542);

insert into Users_Orgs (organizationId, userId) values (22, 542);
insert into Users_Orgs (organizationId, userId) values (50, 542);

insert into Users_Roles (roleId, userId) values (18, 542);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (547, 544, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 542, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 75', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('8b16e89e-7b07-494f-9489-2a31299cb30d', 548, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 549, 'test', 'F', 'F', 'lax76', 'test.lax.76@liferay.com', 'Welcome Test LAX 76!', 'Test', '', 'LAX 76', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (549, 1, 2, 'Test LAX 76', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 548, 7, 0, 'test.lax.76@liferay.com', 'Test', '', 'LAX 76', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (550, 1, 548, 13, 548, 0, 0, '550', 0, '/lax76', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (551, 1, 550, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (552, 1, 550, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 548);

insert into Users_Orgs (organizationId, userId) values (22, 548);
insert into Users_Orgs (organizationId, userId) values (50, 548);

insert into Users_Roles (roleId, userId) values (18, 548);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (553, 550, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 548, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 76', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('1ed6e14c-e504-4f3f-b714-e180998175b6', 554, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 555, 'test', 'F', 'F', 'lax77', 'test.lax.77@liferay.com', 'Welcome Test LAX 77!', 'Test', '', 'LAX 77', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (555, 1, 2, 'Test LAX 77', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 554, 7, 0, 'test.lax.77@liferay.com', 'Test', '', 'LAX 77', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (556, 1, 554, 13, 554, 0, 0, '556', 0, '/lax77', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (557, 1, 556, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (558, 1, 556, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 554);

insert into Users_Orgs (organizationId, userId) values (22, 554);
insert into Users_Orgs (organizationId, userId) values (50, 554);

insert into Users_Roles (roleId, userId) values (18, 554);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (559, 556, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 554, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 77', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('9e09802c-bdc9-4f8f-9bc7-4fe1f180a85a', 560, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 561, 'test', 'F', 'F', 'lax78', 'test.lax.78@liferay.com', 'Welcome Test LAX 78!', 'Test', '', 'LAX 78', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (561, 1, 2, 'Test LAX 78', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 560, 7, 0, 'test.lax.78@liferay.com', 'Test', '', 'LAX 78', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (562, 1, 560, 13, 560, 0, 0, '562', 0, '/lax78', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (563, 1, 562, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (564, 1, 562, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 560);

insert into Users_Orgs (organizationId, userId) values (22, 560);
insert into Users_Orgs (organizationId, userId) values (50, 560);

insert into Users_Roles (roleId, userId) values (18, 560);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (565, 562, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 560, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 78', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('67155937-f434-48de-a35a-c5173b1d77f0', 566, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 567, 'test', 'F', 'F', 'lax79', 'test.lax.79@liferay.com', 'Welcome Test LAX 79!', 'Test', '', 'LAX 79', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (567, 1, 2, 'Test LAX 79', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 566, 7, 0, 'test.lax.79@liferay.com', 'Test', '', 'LAX 79', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (568, 1, 566, 13, 566, 0, 0, '568', 0, '/lax79', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (569, 1, 568, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (570, 1, 568, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 566);

insert into Users_Orgs (organizationId, userId) values (22, 566);
insert into Users_Orgs (organizationId, userId) values (50, 566);

insert into Users_Roles (roleId, userId) values (18, 566);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (571, 568, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 566, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 79', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('a7b0e978-152b-4c43-8733-f53f0b5ac976', 572, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 573, 'test', 'F', 'F', 'lax80', 'test.lax.80@liferay.com', 'Welcome Test LAX 80!', 'Test', '', 'LAX 80', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (573, 1, 2, 'Test LAX 80', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 572, 7, 0, 'test.lax.80@liferay.com', 'Test', '', 'LAX 80', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (574, 1, 572, 13, 572, 0, 0, '574', 0, '/lax80', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (575, 1, 574, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (576, 1, 574, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 572);

insert into Users_Orgs (organizationId, userId) values (22, 572);
insert into Users_Orgs (organizationId, userId) values (50, 572);

insert into Users_Roles (roleId, userId) values (18, 572);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (577, 574, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 572, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 80', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('d4aed692-32b5-4de7-a9f8-19164336fb2a', 578, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 579, 'test', 'F', 'F', 'lax81', 'test.lax.81@liferay.com', 'Welcome Test LAX 81!', 'Test', '', 'LAX 81', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (579, 1, 2, 'Test LAX 81', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 578, 7, 0, 'test.lax.81@liferay.com', 'Test', '', 'LAX 81', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (580, 1, 578, 13, 578, 0, 0, '580', 0, '/lax81', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (581, 1, 580, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (582, 1, 580, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 578);

insert into Users_Orgs (organizationId, userId) values (22, 578);
insert into Users_Orgs (organizationId, userId) values (50, 578);

insert into Users_Roles (roleId, userId) values (18, 578);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (583, 580, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 578, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 81', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('93d24147-ee0b-4202-8610-61129ffe7b24', 584, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 585, 'test', 'F', 'F', 'lax82', 'test.lax.82@liferay.com', 'Welcome Test LAX 82!', 'Test', '', 'LAX 82', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (585, 1, 2, 'Test LAX 82', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 584, 7, 0, 'test.lax.82@liferay.com', 'Test', '', 'LAX 82', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (586, 1, 584, 13, 584, 0, 0, '586', 0, '/lax82', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (587, 1, 586, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (588, 1, 586, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 584);

insert into Users_Orgs (organizationId, userId) values (22, 584);
insert into Users_Orgs (organizationId, userId) values (50, 584);

insert into Users_Roles (roleId, userId) values (18, 584);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (589, 586, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 584, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 82', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('60922b39-65ac-443c-ac14-94f3112dbab1', 590, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 591, 'test', 'F', 'F', 'lax83', 'test.lax.83@liferay.com', 'Welcome Test LAX 83!', 'Test', '', 'LAX 83', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (591, 1, 2, 'Test LAX 83', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 590, 7, 0, 'test.lax.83@liferay.com', 'Test', '', 'LAX 83', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (592, 1, 590, 13, 590, 0, 0, '592', 0, '/lax83', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (593, 1, 592, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (594, 1, 592, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 590);

insert into Users_Orgs (organizationId, userId) values (22, 590);
insert into Users_Orgs (organizationId, userId) values (50, 590);

insert into Users_Roles (roleId, userId) values (18, 590);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (595, 592, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 590, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 83', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('a343a297-66e0-4757-8e78-c62d3a005f87', 596, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 597, 'test', 'F', 'F', 'lax84', 'test.lax.84@liferay.com', 'Welcome Test LAX 84!', 'Test', '', 'LAX 84', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (597, 1, 2, 'Test LAX 84', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 596, 7, 0, 'test.lax.84@liferay.com', 'Test', '', 'LAX 84', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (598, 1, 596, 13, 596, 0, 0, '598', 0, '/lax84', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (599, 1, 598, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (600, 1, 598, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 596);

insert into Users_Orgs (organizationId, userId) values (22, 596);
insert into Users_Orgs (organizationId, userId) values (50, 596);

insert into Users_Roles (roleId, userId) values (18, 596);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (601, 598, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 596, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 84', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ef065468-411c-4df4-b155-d6ff9e415afa', 602, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 603, 'test', 'F', 'F', 'lax85', 'test.lax.85@liferay.com', 'Welcome Test LAX 85!', 'Test', '', 'LAX 85', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (603, 1, 2, 'Test LAX 85', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 602, 7, 0, 'test.lax.85@liferay.com', 'Test', '', 'LAX 85', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (604, 1, 602, 13, 602, 0, 0, '604', 0, '/lax85', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (605, 1, 604, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (606, 1, 604, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 602);

insert into Users_Orgs (organizationId, userId) values (22, 602);
insert into Users_Orgs (organizationId, userId) values (50, 602);

insert into Users_Roles (roleId, userId) values (18, 602);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (607, 604, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 602, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 85', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('1fc1e0e6-9086-463c-80a0-1be981b74ff3', 608, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 609, 'test', 'F', 'F', 'lax86', 'test.lax.86@liferay.com', 'Welcome Test LAX 86!', 'Test', '', 'LAX 86', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (609, 1, 2, 'Test LAX 86', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 608, 7, 0, 'test.lax.86@liferay.com', 'Test', '', 'LAX 86', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (610, 1, 608, 13, 608, 0, 0, '610', 0, '/lax86', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (611, 1, 610, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (612, 1, 610, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 608);

insert into Users_Orgs (organizationId, userId) values (22, 608);
insert into Users_Orgs (organizationId, userId) values (50, 608);

insert into Users_Roles (roleId, userId) values (18, 608);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (613, 610, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 608, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 86', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('6a49ee5f-478a-47da-a0ed-0c324d98b533', 614, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 615, 'test', 'F', 'F', 'lax87', 'test.lax.87@liferay.com', 'Welcome Test LAX 87!', 'Test', '', 'LAX 87', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (615, 1, 2, 'Test LAX 87', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 614, 7, 0, 'test.lax.87@liferay.com', 'Test', '', 'LAX 87', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (616, 1, 614, 13, 614, 0, 0, '616', 0, '/lax87', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (617, 1, 616, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (618, 1, 616, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 614);

insert into Users_Orgs (organizationId, userId) values (22, 614);
insert into Users_Orgs (organizationId, userId) values (50, 614);

insert into Users_Roles (roleId, userId) values (18, 614);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (619, 616, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 614, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 87', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('118aa906-af80-4055-92c5-69af1a203a24', 620, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 621, 'test', 'F', 'F', 'lax88', 'test.lax.88@liferay.com', 'Welcome Test LAX 88!', 'Test', '', 'LAX 88', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (621, 1, 2, 'Test LAX 88', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 620, 7, 0, 'test.lax.88@liferay.com', 'Test', '', 'LAX 88', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (622, 1, 620, 13, 620, 0, 0, '622', 0, '/lax88', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (623, 1, 622, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (624, 1, 622, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 620);

insert into Users_Orgs (organizationId, userId) values (22, 620);
insert into Users_Orgs (organizationId, userId) values (50, 620);

insert into Users_Roles (roleId, userId) values (18, 620);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (625, 622, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 620, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 88', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('fa4e45c5-0d68-4df4-af1e-3ec4f8144f5f', 626, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 627, 'test', 'F', 'F', 'lax89', 'test.lax.89@liferay.com', 'Welcome Test LAX 89!', 'Test', '', 'LAX 89', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (627, 1, 2, 'Test LAX 89', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 626, 7, 0, 'test.lax.89@liferay.com', 'Test', '', 'LAX 89', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (628, 1, 626, 13, 626, 0, 0, '628', 0, '/lax89', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (629, 1, 628, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (630, 1, 628, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 626);

insert into Users_Orgs (organizationId, userId) values (22, 626);
insert into Users_Orgs (organizationId, userId) values (50, 626);

insert into Users_Roles (roleId, userId) values (18, 626);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (631, 628, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 626, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 89', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('499e9d63-3c1c-4261-a7c1-30bcecc522e0', 632, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 633, 'test', 'F', 'F', 'lax90', 'test.lax.90@liferay.com', 'Welcome Test LAX 90!', 'Test', '', 'LAX 90', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (633, 1, 2, 'Test LAX 90', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 632, 7, 0, 'test.lax.90@liferay.com', 'Test', '', 'LAX 90', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (634, 1, 632, 13, 632, 0, 0, '634', 0, '/lax90', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (635, 1, 634, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (636, 1, 634, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 632);

insert into Users_Orgs (organizationId, userId) values (22, 632);
insert into Users_Orgs (organizationId, userId) values (50, 632);

insert into Users_Roles (roleId, userId) values (18, 632);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (637, 634, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 632, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 90', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('9fa5a856-a913-46d4-bdcc-1ec30337f06a', 638, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 639, 'test', 'F', 'F', 'lax91', 'test.lax.91@liferay.com', 'Welcome Test LAX 91!', 'Test', '', 'LAX 91', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (639, 1, 2, 'Test LAX 91', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 638, 7, 0, 'test.lax.91@liferay.com', 'Test', '', 'LAX 91', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (640, 1, 638, 13, 638, 0, 0, '640', 0, '/lax91', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (641, 1, 640, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (642, 1, 640, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 638);

insert into Users_Orgs (organizationId, userId) values (22, 638);
insert into Users_Orgs (organizationId, userId) values (50, 638);

insert into Users_Roles (roleId, userId) values (18, 638);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (643, 640, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 638, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 91', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ef929d8b-aa69-4273-bfe7-dbe4a61a799a', 644, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 645, 'test', 'F', 'F', 'lax92', 'test.lax.92@liferay.com', 'Welcome Test LAX 92!', 'Test', '', 'LAX 92', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (645, 1, 2, 'Test LAX 92', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 644, 7, 0, 'test.lax.92@liferay.com', 'Test', '', 'LAX 92', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (646, 1, 644, 13, 644, 0, 0, '646', 0, '/lax92', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (647, 1, 646, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (648, 1, 646, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 644);

insert into Users_Orgs (organizationId, userId) values (22, 644);
insert into Users_Orgs (organizationId, userId) values (50, 644);

insert into Users_Roles (roleId, userId) values (18, 644);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (649, 646, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 644, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 92', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('37128842-cd5c-4fa0-8e08-03069ebcacc4', 650, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 651, 'test', 'F', 'F', 'lax93', 'test.lax.93@liferay.com', 'Welcome Test LAX 93!', 'Test', '', 'LAX 93', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (651, 1, 2, 'Test LAX 93', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 650, 7, 0, 'test.lax.93@liferay.com', 'Test', '', 'LAX 93', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (652, 1, 650, 13, 650, 0, 0, '652', 0, '/lax93', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (653, 1, 652, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (654, 1, 652, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 650);

insert into Users_Orgs (organizationId, userId) values (22, 650);
insert into Users_Orgs (organizationId, userId) values (50, 650);

insert into Users_Roles (roleId, userId) values (18, 650);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (655, 652, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 650, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 93', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e19e06ab-373e-4675-a3bd-7aa7eb013ff1', 656, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 657, 'test', 'F', 'F', 'lax94', 'test.lax.94@liferay.com', 'Welcome Test LAX 94!', 'Test', '', 'LAX 94', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (657, 1, 2, 'Test LAX 94', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 656, 7, 0, 'test.lax.94@liferay.com', 'Test', '', 'LAX 94', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (658, 1, 656, 13, 656, 0, 0, '658', 0, '/lax94', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (659, 1, 658, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (660, 1, 658, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 656);

insert into Users_Orgs (organizationId, userId) values (22, 656);
insert into Users_Orgs (organizationId, userId) values (50, 656);

insert into Users_Roles (roleId, userId) values (18, 656);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (661, 658, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 656, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 94', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('36b700b5-41b9-48cd-bf6a-738f5920eed8', 662, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 663, 'test', 'F', 'F', 'lax95', 'test.lax.95@liferay.com', 'Welcome Test LAX 95!', 'Test', '', 'LAX 95', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (663, 1, 2, 'Test LAX 95', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 662, 7, 0, 'test.lax.95@liferay.com', 'Test', '', 'LAX 95', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (664, 1, 662, 13, 662, 0, 0, '664', 0, '/lax95', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (665, 1, 664, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (666, 1, 664, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 662);

insert into Users_Orgs (organizationId, userId) values (22, 662);
insert into Users_Orgs (organizationId, userId) values (50, 662);

insert into Users_Roles (roleId, userId) values (18, 662);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (667, 664, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 662, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 95', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('65523a75-29a7-4e61-92aa-7ed3611f44ca', 668, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 669, 'test', 'F', 'F', 'lax96', 'test.lax.96@liferay.com', 'Welcome Test LAX 96!', 'Test', '', 'LAX 96', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (669, 1, 2, 'Test LAX 96', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 668, 7, 0, 'test.lax.96@liferay.com', 'Test', '', 'LAX 96', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (670, 1, 668, 13, 668, 0, 0, '670', 0, '/lax96', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (671, 1, 670, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (672, 1, 670, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 668);

insert into Users_Orgs (organizationId, userId) values (22, 668);
insert into Users_Orgs (organizationId, userId) values (50, 668);

insert into Users_Roles (roleId, userId) values (18, 668);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (673, 670, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 668, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 96', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e55ac089-1889-4ecc-a732-f4c0b3a74dae', 674, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 675, 'test', 'F', 'F', 'lax97', 'test.lax.97@liferay.com', 'Welcome Test LAX 97!', 'Test', '', 'LAX 97', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (675, 1, 2, 'Test LAX 97', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 674, 7, 0, 'test.lax.97@liferay.com', 'Test', '', 'LAX 97', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (676, 1, 674, 13, 674, 0, 0, '676', 0, '/lax97', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (677, 1, 676, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (678, 1, 676, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 674);

insert into Users_Orgs (organizationId, userId) values (22, 674);
insert into Users_Orgs (organizationId, userId) values (50, 674);

insert into Users_Roles (roleId, userId) values (18, 674);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (679, 676, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 674, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 97', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('4d98b417-877e-43ff-8f20-619518b69b46', 680, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 681, 'test', 'F', 'F', 'lax98', 'test.lax.98@liferay.com', 'Welcome Test LAX 98!', 'Test', '', 'LAX 98', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (681, 1, 2, 'Test LAX 98', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 680, 7, 0, 'test.lax.98@liferay.com', 'Test', '', 'LAX 98', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (682, 1, 680, 13, 680, 0, 0, '682', 0, '/lax98', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (683, 1, 682, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (684, 1, 682, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 680);

insert into Users_Orgs (organizationId, userId) values (22, 680);
insert into Users_Orgs (organizationId, userId) values (50, 680);

insert into Users_Roles (roleId, userId) values (18, 680);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (685, 682, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 680, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 98', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('35a3cd50-bbbd-45d9-af39-ef67499d630d', 686, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 687, 'test', 'F', 'F', 'lax99', 'test.lax.99@liferay.com', 'Welcome Test LAX 99!', 'Test', '', 'LAX 99', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (687, 1, 2, 'Test LAX 99', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 686, 7, 0, 'test.lax.99@liferay.com', 'Test', '', 'LAX 99', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (688, 1, 686, 13, 686, 0, 0, '688', 0, '/lax99', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (689, 1, 688, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (690, 1, 688, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 686);

insert into Users_Orgs (organizationId, userId) values (22, 686);
insert into Users_Orgs (organizationId, userId) values (50, 686);

insert into Users_Roles (roleId, userId) values (18, 686);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (691, 688, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 686, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 99', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('7576b9a6-ce59-46d2-adc2-96aea3fb5f49', 692, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 693, 'test', 'F', 'F', 'lax100', 'test.lax.100@liferay.com', 'Welcome Test LAX 100!', 'Test', '', 'LAX 100', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (693, 1, 2, 'Test LAX 100', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 692, 7, 0, 'test.lax.100@liferay.com', 'Test', '', 'LAX 100', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (694, 1, 692, 13, 692, 0, 0, '694', 0, '/lax100', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (695, 1, 694, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (696, 1, 694, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 692);

insert into Users_Orgs (organizationId, userId) values (22, 692);
insert into Users_Orgs (organizationId, userId) values (50, 692);

insert into Users_Roles (roleId, userId) values (18, 692);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (697, 694, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 692, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test LAX 100', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('11ba4720-08a9-457a-84fe-bdba14f83747', 698, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 699, 'test', 'F', 'F', 'sfo1', 'test.sfo.1@liferay.com', 'Welcome Test SFO 1!', 'Test', '', 'SFO 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (699, 1, 2, 'Test SFO 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 698, 7, 0, 'test.sfo.1@liferay.com', 'Test', '', 'SFO 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (700, 1, 698, 13, 698, 0, 0, '700', 0, '/sfo1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (701, 1, 700, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (702, 1, 700, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 698);

insert into Users_Orgs (organizationId, userId) values (22, 698);
insert into Users_Orgs (organizationId, userId) values (54, 698);

insert into Users_Roles (roleId, userId) values (18, 698);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (703, 700, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 698, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('c2b42519-d3d5-4659-aae8-a2ade635b6e2', 704, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 705, 'test', 'F', 'F', 'sfo2', 'test.sfo.2@liferay.com', 'Welcome Test SFO 2!', 'Test', '', 'SFO 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (705, 1, 2, 'Test SFO 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 704, 7, 0, 'test.sfo.2@liferay.com', 'Test', '', 'SFO 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (706, 1, 704, 13, 704, 0, 0, '706', 0, '/sfo2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (707, 1, 706, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (708, 1, 706, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 704);

insert into Users_Orgs (organizationId, userId) values (22, 704);
insert into Users_Orgs (organizationId, userId) values (54, 704);

insert into Users_Roles (roleId, userId) values (18, 704);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (709, 706, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 704, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e9090c9c-78ac-4974-b06e-08b4f82d2c2d', 710, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 711, 'test', 'F', 'F', 'sfo3', 'test.sfo.3@liferay.com', 'Welcome Test SFO 3!', 'Test', '', 'SFO 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (711, 1, 2, 'Test SFO 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 710, 7, 0, 'test.sfo.3@liferay.com', 'Test', '', 'SFO 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (712, 1, 710, 13, 710, 0, 0, '712', 0, '/sfo3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (713, 1, 712, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (714, 1, 712, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 710);

insert into Users_Orgs (organizationId, userId) values (22, 710);
insert into Users_Orgs (organizationId, userId) values (54, 710);

insert into Users_Roles (roleId, userId) values (18, 710);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (715, 712, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 710, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('4aa64fa5-0bae-4c34-a905-3f759e4b7a73', 716, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 717, 'test', 'F', 'F', 'sfo4', 'test.sfo.4@liferay.com', 'Welcome Test SFO 4!', 'Test', '', 'SFO 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (717, 1, 2, 'Test SFO 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 716, 7, 0, 'test.sfo.4@liferay.com', 'Test', '', 'SFO 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (718, 1, 716, 13, 716, 0, 0, '718', 0, '/sfo4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (719, 1, 718, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (720, 1, 718, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 716);

insert into Users_Orgs (organizationId, userId) values (22, 716);
insert into Users_Orgs (organizationId, userId) values (54, 716);

insert into Users_Roles (roleId, userId) values (18, 716);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (721, 718, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 716, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('dac35fa2-be17-4034-b000-70fbc41c9415', 722, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 723, 'test', 'F', 'F', 'sfo5', 'test.sfo.5@liferay.com', 'Welcome Test SFO 5!', 'Test', '', 'SFO 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (723, 1, 2, 'Test SFO 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 722, 7, 0, 'test.sfo.5@liferay.com', 'Test', '', 'SFO 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (724, 1, 722, 13, 722, 0, 0, '724', 0, '/sfo5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (725, 1, 724, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (726, 1, 724, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 722);

insert into Users_Orgs (organizationId, userId) values (22, 722);
insert into Users_Orgs (organizationId, userId) values (54, 722);

insert into Users_Roles (roleId, userId) values (18, 722);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (727, 724, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 722, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('6ced696b-87a2-4fbb-88ab-c8c0bd8feb1b', 728, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 729, 'test', 'F', 'F', 'sfo6', 'test.sfo.6@liferay.com', 'Welcome Test SFO 6!', 'Test', '', 'SFO 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (729, 1, 2, 'Test SFO 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 728, 7, 0, 'test.sfo.6@liferay.com', 'Test', '', 'SFO 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (730, 1, 728, 13, 728, 0, 0, '730', 0, '/sfo6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (731, 1, 730, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (732, 1, 730, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 728);

insert into Users_Orgs (organizationId, userId) values (22, 728);
insert into Users_Orgs (organizationId, userId) values (54, 728);

insert into Users_Roles (roleId, userId) values (18, 728);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (733, 730, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 728, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('b53d7967-b942-4496-85c9-f77ef5c93112', 734, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 735, 'test', 'F', 'F', 'sfo7', 'test.sfo.7@liferay.com', 'Welcome Test SFO 7!', 'Test', '', 'SFO 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (735, 1, 2, 'Test SFO 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 734, 7, 0, 'test.sfo.7@liferay.com', 'Test', '', 'SFO 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (736, 1, 734, 13, 734, 0, 0, '736', 0, '/sfo7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (737, 1, 736, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (738, 1, 736, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 734);

insert into Users_Orgs (organizationId, userId) values (22, 734);
insert into Users_Orgs (organizationId, userId) values (54, 734);

insert into Users_Roles (roleId, userId) values (18, 734);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (739, 736, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 734, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('7b4953a8-35e0-48b5-8bbf-44d080c68c58', 740, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 741, 'test', 'F', 'F', 'sfo8', 'test.sfo.8@liferay.com', 'Welcome Test SFO 8!', 'Test', '', 'SFO 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (741, 1, 2, 'Test SFO 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 740, 7, 0, 'test.sfo.8@liferay.com', 'Test', '', 'SFO 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (742, 1, 740, 13, 740, 0, 0, '742', 0, '/sfo8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (743, 1, 742, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (744, 1, 742, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 740);

insert into Users_Orgs (organizationId, userId) values (22, 740);
insert into Users_Orgs (organizationId, userId) values (54, 740);

insert into Users_Roles (roleId, userId) values (18, 740);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (745, 742, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 740, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('704e25dc-58e3-4fc3-875e-460ea9c1d951', 746, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 747, 'test', 'F', 'F', 'sfo9', 'test.sfo.9@liferay.com', 'Welcome Test SFO 9!', 'Test', '', 'SFO 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (747, 1, 2, 'Test SFO 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 746, 7, 0, 'test.sfo.9@liferay.com', 'Test', '', 'SFO 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (748, 1, 746, 13, 746, 0, 0, '748', 0, '/sfo9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (749, 1, 748, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (750, 1, 748, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 746);

insert into Users_Orgs (organizationId, userId) values (22, 746);
insert into Users_Orgs (organizationId, userId) values (54, 746);

insert into Users_Roles (roleId, userId) values (18, 746);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (751, 748, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 746, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('b30df978-df99-4d8e-911f-887f0552603c', 752, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 753, 'test', 'F', 'F', 'sfo10', 'test.sfo.10@liferay.com', 'Welcome Test SFO 10!', 'Test', '', 'SFO 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (753, 1, 2, 'Test SFO 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 752, 7, 0, 'test.sfo.10@liferay.com', 'Test', '', 'SFO 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (754, 1, 752, 13, 752, 0, 0, '754', 0, '/sfo10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (755, 1, 754, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (756, 1, 754, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 752);

insert into Users_Orgs (organizationId, userId) values (22, 752);
insert into Users_Orgs (organizationId, userId) values (54, 752);

insert into Users_Roles (roleId, userId) values (18, 752);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (757, 754, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 752, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test SFO 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('a2bda1bb-0b2e-40af-829d-1a210f756f51', 758, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 759, 'test', 'F', 'F', 'ord1', 'test.ord.1@liferay.com', 'Welcome Test ORD 1!', 'Test', '', 'ORD 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (759, 1, 2, 'Test ORD 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 758, 7, 0, 'test.ord.1@liferay.com', 'Test', '', 'ORD 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (760, 1, 758, 13, 758, 0, 0, '760', 0, '/ord1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (761, 1, 760, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (762, 1, 760, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 758);

insert into Users_Orgs (organizationId, userId) values (22, 758);
insert into Users_Orgs (organizationId, userId) values (58, 758);

insert into Users_Roles (roleId, userId) values (18, 758);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (763, 760, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 758, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ccf8b9e0-6c61-45a1-a126-8a1cce82ee66', 764, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 765, 'test', 'F', 'F', 'ord2', 'test.ord.2@liferay.com', 'Welcome Test ORD 2!', 'Test', '', 'ORD 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (765, 1, 2, 'Test ORD 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 764, 7, 0, 'test.ord.2@liferay.com', 'Test', '', 'ORD 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (766, 1, 764, 13, 764, 0, 0, '766', 0, '/ord2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (767, 1, 766, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (768, 1, 766, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 764);

insert into Users_Orgs (organizationId, userId) values (22, 764);
insert into Users_Orgs (organizationId, userId) values (58, 764);

insert into Users_Roles (roleId, userId) values (18, 764);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (769, 766, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 764, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('5e5de7f0-a861-4274-b33e-deb1dea8d023', 770, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 771, 'test', 'F', 'F', 'ord3', 'test.ord.3@liferay.com', 'Welcome Test ORD 3!', 'Test', '', 'ORD 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (771, 1, 2, 'Test ORD 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 770, 7, 0, 'test.ord.3@liferay.com', 'Test', '', 'ORD 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (772, 1, 770, 13, 770, 0, 0, '772', 0, '/ord3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (773, 1, 772, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (774, 1, 772, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 770);

insert into Users_Orgs (organizationId, userId) values (22, 770);
insert into Users_Orgs (organizationId, userId) values (58, 770);

insert into Users_Roles (roleId, userId) values (18, 770);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (775, 772, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 770, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('fb2813a7-eb9b-4ff5-a504-2b9a3a61db03', 776, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 777, 'test', 'F', 'F', 'ord4', 'test.ord.4@liferay.com', 'Welcome Test ORD 4!', 'Test', '', 'ORD 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (777, 1, 2, 'Test ORD 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 776, 7, 0, 'test.ord.4@liferay.com', 'Test', '', 'ORD 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (778, 1, 776, 13, 776, 0, 0, '778', 0, '/ord4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (779, 1, 778, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (780, 1, 778, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 776);

insert into Users_Orgs (organizationId, userId) values (22, 776);
insert into Users_Orgs (organizationId, userId) values (58, 776);

insert into Users_Roles (roleId, userId) values (18, 776);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (781, 778, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 776, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('06570072-9a68-4b3c-8d46-e45e20ae41cb', 782, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 783, 'test', 'F', 'F', 'ord5', 'test.ord.5@liferay.com', 'Welcome Test ORD 5!', 'Test', '', 'ORD 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (783, 1, 2, 'Test ORD 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 782, 7, 0, 'test.ord.5@liferay.com', 'Test', '', 'ORD 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (784, 1, 782, 13, 782, 0, 0, '784', 0, '/ord5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (785, 1, 784, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (786, 1, 784, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 782);

insert into Users_Orgs (organizationId, userId) values (22, 782);
insert into Users_Orgs (organizationId, userId) values (58, 782);

insert into Users_Roles (roleId, userId) values (18, 782);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (787, 784, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 782, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('4dfc6859-f3ac-4208-bfda-e360e8eb4939', 788, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 789, 'test', 'F', 'F', 'ord6', 'test.ord.6@liferay.com', 'Welcome Test ORD 6!', 'Test', '', 'ORD 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (789, 1, 2, 'Test ORD 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 788, 7, 0, 'test.ord.6@liferay.com', 'Test', '', 'ORD 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (790, 1, 788, 13, 788, 0, 0, '790', 0, '/ord6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (791, 1, 790, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (792, 1, 790, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 788);

insert into Users_Orgs (organizationId, userId) values (22, 788);
insert into Users_Orgs (organizationId, userId) values (58, 788);

insert into Users_Roles (roleId, userId) values (18, 788);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (793, 790, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 788, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('b3512423-6098-4f09-95f5-3bd02a22dfca', 794, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 795, 'test', 'F', 'F', 'ord7', 'test.ord.7@liferay.com', 'Welcome Test ORD 7!', 'Test', '', 'ORD 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (795, 1, 2, 'Test ORD 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 794, 7, 0, 'test.ord.7@liferay.com', 'Test', '', 'ORD 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (796, 1, 794, 13, 794, 0, 0, '796', 0, '/ord7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (797, 1, 796, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (798, 1, 796, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 794);

insert into Users_Orgs (organizationId, userId) values (22, 794);
insert into Users_Orgs (organizationId, userId) values (58, 794);

insert into Users_Roles (roleId, userId) values (18, 794);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (799, 796, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 794, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('f1bf0eec-64ac-4fb1-9ad0-e43778efde6f', 800, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 801, 'test', 'F', 'F', 'ord8', 'test.ord.8@liferay.com', 'Welcome Test ORD 8!', 'Test', '', 'ORD 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (801, 1, 2, 'Test ORD 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 800, 7, 0, 'test.ord.8@liferay.com', 'Test', '', 'ORD 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (802, 1, 800, 13, 800, 0, 0, '802', 0, '/ord8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (803, 1, 802, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (804, 1, 802, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 800);

insert into Users_Orgs (organizationId, userId) values (22, 800);
insert into Users_Orgs (organizationId, userId) values (58, 800);

insert into Users_Roles (roleId, userId) values (18, 800);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (805, 802, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 800, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e45b2931-f70a-4144-8306-05ed387b6c20', 806, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 807, 'test', 'F', 'F', 'ord9', 'test.ord.9@liferay.com', 'Welcome Test ORD 9!', 'Test', '', 'ORD 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (807, 1, 2, 'Test ORD 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 806, 7, 0, 'test.ord.9@liferay.com', 'Test', '', 'ORD 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (808, 1, 806, 13, 806, 0, 0, '808', 0, '/ord9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (809, 1, 808, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (810, 1, 808, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 806);

insert into Users_Orgs (organizationId, userId) values (22, 806);
insert into Users_Orgs (organizationId, userId) values (58, 806);

insert into Users_Roles (roleId, userId) values (18, 806);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (811, 808, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 806, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('81983cac-a7ba-44d2-bc4f-b293e98b42a5', 812, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 813, 'test', 'F', 'F', 'ord10', 'test.ord.10@liferay.com', 'Welcome Test ORD 10!', 'Test', '', 'ORD 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (813, 1, 2, 'Test ORD 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 812, 7, 0, 'test.ord.10@liferay.com', 'Test', '', 'ORD 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (814, 1, 812, 13, 812, 0, 0, '814', 0, '/ord10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (815, 1, 814, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (816, 1, 814, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 812);

insert into Users_Orgs (organizationId, userId) values (22, 812);
insert into Users_Orgs (organizationId, userId) values (58, 812);

insert into Users_Roles (roleId, userId) values (18, 812);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (817, 814, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 812, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test ORD 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('a3912b4f-c4c5-4645-a47f-58d1a6e54bf6', 818, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 819, 'test', 'F', 'F', 'nyc1', 'test.nyc.1@liferay.com', 'Welcome Test NYC 1!', 'Test', '', 'NYC 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (819, 1, 2, 'Test NYC 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 818, 7, 0, 'test.nyc.1@liferay.com', 'Test', '', 'NYC 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (820, 1, 818, 13, 818, 0, 0, '820', 0, '/nyc1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (821, 1, 820, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (822, 1, 820, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 818);

insert into Users_Orgs (organizationId, userId) values (22, 818);
insert into Users_Orgs (organizationId, userId) values (62, 818);

insert into Users_Roles (roleId, userId) values (18, 818);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (823, 820, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 818, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('131606f3-4158-4e2e-95ee-59f440d57a0a', 824, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 825, 'test', 'F', 'F', 'nyc2', 'test.nyc.2@liferay.com', 'Welcome Test NYC 2!', 'Test', '', 'NYC 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (825, 1, 2, 'Test NYC 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 824, 7, 0, 'test.nyc.2@liferay.com', 'Test', '', 'NYC 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (826, 1, 824, 13, 824, 0, 0, '826', 0, '/nyc2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (827, 1, 826, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (828, 1, 826, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 824);

insert into Users_Orgs (organizationId, userId) values (22, 824);
insert into Users_Orgs (organizationId, userId) values (62, 824);

insert into Users_Roles (roleId, userId) values (18, 824);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (829, 826, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 824, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('1520c0c4-44da-4c58-84b1-e5864bdbcc6b', 830, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 831, 'test', 'F', 'F', 'nyc3', 'test.nyc.3@liferay.com', 'Welcome Test NYC 3!', 'Test', '', 'NYC 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (831, 1, 2, 'Test NYC 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 830, 7, 0, 'test.nyc.3@liferay.com', 'Test', '', 'NYC 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (832, 1, 830, 13, 830, 0, 0, '832', 0, '/nyc3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (833, 1, 832, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (834, 1, 832, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 830);

insert into Users_Orgs (organizationId, userId) values (22, 830);
insert into Users_Orgs (organizationId, userId) values (62, 830);

insert into Users_Roles (roleId, userId) values (18, 830);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (835, 832, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 830, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('01bad1a7-fa7a-4c67-86ac-9feeba578ef1', 836, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 837, 'test', 'F', 'F', 'nyc4', 'test.nyc.4@liferay.com', 'Welcome Test NYC 4!', 'Test', '', 'NYC 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (837, 1, 2, 'Test NYC 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 836, 7, 0, 'test.nyc.4@liferay.com', 'Test', '', 'NYC 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (838, 1, 836, 13, 836, 0, 0, '838', 0, '/nyc4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (839, 1, 838, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (840, 1, 838, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 836);

insert into Users_Orgs (organizationId, userId) values (22, 836);
insert into Users_Orgs (organizationId, userId) values (62, 836);

insert into Users_Roles (roleId, userId) values (18, 836);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (841, 838, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 836, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('c22ed869-3740-49b8-8146-bbbca6acc9f2', 842, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 843, 'test', 'F', 'F', 'nyc5', 'test.nyc.5@liferay.com', 'Welcome Test NYC 5!', 'Test', '', 'NYC 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (843, 1, 2, 'Test NYC 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 842, 7, 0, 'test.nyc.5@liferay.com', 'Test', '', 'NYC 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (844, 1, 842, 13, 842, 0, 0, '844', 0, '/nyc5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (845, 1, 844, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (846, 1, 844, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 842);

insert into Users_Orgs (organizationId, userId) values (22, 842);
insert into Users_Orgs (organizationId, userId) values (62, 842);

insert into Users_Roles (roleId, userId) values (18, 842);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (847, 844, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 842, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('17f4aaa3-a9d6-43bc-a5f5-8db32939931c', 848, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 849, 'test', 'F', 'F', 'nyc6', 'test.nyc.6@liferay.com', 'Welcome Test NYC 6!', 'Test', '', 'NYC 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (849, 1, 2, 'Test NYC 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 848, 7, 0, 'test.nyc.6@liferay.com', 'Test', '', 'NYC 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (850, 1, 848, 13, 848, 0, 0, '850', 0, '/nyc6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (851, 1, 850, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (852, 1, 850, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 848);

insert into Users_Orgs (organizationId, userId) values (22, 848);
insert into Users_Orgs (organizationId, userId) values (62, 848);

insert into Users_Roles (roleId, userId) values (18, 848);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (853, 850, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 848, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('abe3d7e1-70c3-4d68-ad82-57946cee20c4', 854, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 855, 'test', 'F', 'F', 'nyc7', 'test.nyc.7@liferay.com', 'Welcome Test NYC 7!', 'Test', '', 'NYC 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (855, 1, 2, 'Test NYC 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 854, 7, 0, 'test.nyc.7@liferay.com', 'Test', '', 'NYC 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (856, 1, 854, 13, 854, 0, 0, '856', 0, '/nyc7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (857, 1, 856, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (858, 1, 856, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 854);

insert into Users_Orgs (organizationId, userId) values (22, 854);
insert into Users_Orgs (organizationId, userId) values (62, 854);

insert into Users_Roles (roleId, userId) values (18, 854);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (859, 856, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 854, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('4852fb22-e027-4db1-ae7e-3257d806a6ed', 860, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 861, 'test', 'F', 'F', 'nyc8', 'test.nyc.8@liferay.com', 'Welcome Test NYC 8!', 'Test', '', 'NYC 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (861, 1, 2, 'Test NYC 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 860, 7, 0, 'test.nyc.8@liferay.com', 'Test', '', 'NYC 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (862, 1, 860, 13, 860, 0, 0, '862', 0, '/nyc8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (863, 1, 862, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (864, 1, 862, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 860);

insert into Users_Orgs (organizationId, userId) values (22, 860);
insert into Users_Orgs (organizationId, userId) values (62, 860);

insert into Users_Roles (roleId, userId) values (18, 860);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (865, 862, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 860, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('66a1c357-a32f-4aa1-abb4-b84b18fb366b', 866, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 867, 'test', 'F', 'F', 'nyc9', 'test.nyc.9@liferay.com', 'Welcome Test NYC 9!', 'Test', '', 'NYC 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (867, 1, 2, 'Test NYC 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 866, 7, 0, 'test.nyc.9@liferay.com', 'Test', '', 'NYC 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (868, 1, 866, 13, 866, 0, 0, '868', 0, '/nyc9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (869, 1, 868, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (870, 1, 868, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 866);

insert into Users_Orgs (organizationId, userId) values (22, 866);
insert into Users_Orgs (organizationId, userId) values (62, 866);

insert into Users_Roles (roleId, userId) values (18, 866);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (871, 868, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 866, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('cf4342c1-c0bb-4f49-b458-942812bebaaf', 872, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 873, 'test', 'F', 'F', 'nyc10', 'test.nyc.10@liferay.com', 'Welcome Test NYC 10!', 'Test', '', 'NYC 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (873, 1, 2, 'Test NYC 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 872, 7, 0, 'test.nyc.10@liferay.com', 'Test', '', 'NYC 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (874, 1, 872, 13, 872, 0, 0, '874', 0, '/nyc10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (875, 1, 874, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (876, 1, 874, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 872);

insert into Users_Orgs (organizationId, userId) values (22, 872);
insert into Users_Orgs (organizationId, userId) values (62, 872);

insert into Users_Roles (roleId, userId) values (18, 872);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (877, 874, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 872, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test NYC 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3fef9c0e-bf17-4777-a414-395ecc067204', 878, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 879, 'test', 'F', 'F', 'gru1', 'test.gru.1@liferay.com', 'Welcome Test GRU 1!', 'Test', '', 'GRU 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (879, 1, 2, 'Test GRU 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 878, 7, 0, 'test.gru.1@liferay.com', 'Test', '', 'GRU 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (880, 1, 878, 13, 878, 0, 0, '880', 0, '/gru1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (881, 1, 880, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (882, 1, 880, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 878);

insert into Users_Orgs (organizationId, userId) values (22, 878);
insert into Users_Orgs (organizationId, userId) values (66, 878);

insert into Users_Roles (roleId, userId) values (18, 878);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (883, 880, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 878, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ebc39809-e4dc-417b-9091-e5c876f35658', 884, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 885, 'test', 'F', 'F', 'gru2', 'test.gru.2@liferay.com', 'Welcome Test GRU 2!', 'Test', '', 'GRU 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (885, 1, 2, 'Test GRU 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 884, 7, 0, 'test.gru.2@liferay.com', 'Test', '', 'GRU 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (886, 1, 884, 13, 884, 0, 0, '886', 0, '/gru2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (887, 1, 886, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (888, 1, 886, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 884);

insert into Users_Orgs (organizationId, userId) values (22, 884);
insert into Users_Orgs (organizationId, userId) values (66, 884);

insert into Users_Roles (roleId, userId) values (18, 884);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (889, 886, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 884, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('57f85106-34fc-4d02-85a4-bf629fe32204', 890, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 891, 'test', 'F', 'F', 'gru3', 'test.gru.3@liferay.com', 'Welcome Test GRU 3!', 'Test', '', 'GRU 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (891, 1, 2, 'Test GRU 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 890, 7, 0, 'test.gru.3@liferay.com', 'Test', '', 'GRU 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (892, 1, 890, 13, 890, 0, 0, '892', 0, '/gru3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (893, 1, 892, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (894, 1, 892, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 890);

insert into Users_Orgs (organizationId, userId) values (22, 890);
insert into Users_Orgs (organizationId, userId) values (66, 890);

insert into Users_Roles (roleId, userId) values (18, 890);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (895, 892, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 890, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('98dfb62c-a675-4756-8903-f2be71400513', 896, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 897, 'test', 'F', 'F', 'gru4', 'test.gru.4@liferay.com', 'Welcome Test GRU 4!', 'Test', '', 'GRU 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (897, 1, 2, 'Test GRU 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 896, 7, 0, 'test.gru.4@liferay.com', 'Test', '', 'GRU 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (898, 1, 896, 13, 896, 0, 0, '898', 0, '/gru4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (899, 1, 898, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (900, 1, 898, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 896);

insert into Users_Orgs (organizationId, userId) values (22, 896);
insert into Users_Orgs (organizationId, userId) values (66, 896);

insert into Users_Roles (roleId, userId) values (18, 896);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (901, 898, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 896, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('4f2cad4f-759c-4311-a030-efab378d41ba', 902, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 903, 'test', 'F', 'F', 'gru5', 'test.gru.5@liferay.com', 'Welcome Test GRU 5!', 'Test', '', 'GRU 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (903, 1, 2, 'Test GRU 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 902, 7, 0, 'test.gru.5@liferay.com', 'Test', '', 'GRU 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (904, 1, 902, 13, 902, 0, 0, '904', 0, '/gru5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (905, 1, 904, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (906, 1, 904, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 902);

insert into Users_Orgs (organizationId, userId) values (22, 902);
insert into Users_Orgs (organizationId, userId) values (66, 902);

insert into Users_Roles (roleId, userId) values (18, 902);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (907, 904, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 902, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3fd3c55a-acf8-4670-bd09-dd1b433e5bc5', 908, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 909, 'test', 'F', 'F', 'gru6', 'test.gru.6@liferay.com', 'Welcome Test GRU 6!', 'Test', '', 'GRU 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (909, 1, 2, 'Test GRU 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 908, 7, 0, 'test.gru.6@liferay.com', 'Test', '', 'GRU 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (910, 1, 908, 13, 908, 0, 0, '910', 0, '/gru6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (911, 1, 910, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (912, 1, 910, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 908);

insert into Users_Orgs (organizationId, userId) values (22, 908);
insert into Users_Orgs (organizationId, userId) values (66, 908);

insert into Users_Roles (roleId, userId) values (18, 908);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (913, 910, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 908, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('0caeb2bd-dda3-4f3e-a370-75e7846e04bc', 914, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 915, 'test', 'F', 'F', 'gru7', 'test.gru.7@liferay.com', 'Welcome Test GRU 7!', 'Test', '', 'GRU 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (915, 1, 2, 'Test GRU 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 914, 7, 0, 'test.gru.7@liferay.com', 'Test', '', 'GRU 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (916, 1, 914, 13, 914, 0, 0, '916', 0, '/gru7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (917, 1, 916, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (918, 1, 916, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 914);

insert into Users_Orgs (organizationId, userId) values (22, 914);
insert into Users_Orgs (organizationId, userId) values (66, 914);

insert into Users_Roles (roleId, userId) values (18, 914);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (919, 916, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 914, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('f99b5062-215a-4236-b935-1546b5b87006', 920, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 921, 'test', 'F', 'F', 'gru8', 'test.gru.8@liferay.com', 'Welcome Test GRU 8!', 'Test', '', 'GRU 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (921, 1, 2, 'Test GRU 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 920, 7, 0, 'test.gru.8@liferay.com', 'Test', '', 'GRU 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (922, 1, 920, 13, 920, 0, 0, '922', 0, '/gru8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (923, 1, 922, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (924, 1, 922, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 920);

insert into Users_Orgs (organizationId, userId) values (22, 920);
insert into Users_Orgs (organizationId, userId) values (66, 920);

insert into Users_Roles (roleId, userId) values (18, 920);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (925, 922, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 920, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('0e35486e-9b4d-4f1e-8c96-2b13d3002574', 926, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 927, 'test', 'F', 'F', 'gru9', 'test.gru.9@liferay.com', 'Welcome Test GRU 9!', 'Test', '', 'GRU 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (927, 1, 2, 'Test GRU 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 926, 7, 0, 'test.gru.9@liferay.com', 'Test', '', 'GRU 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (928, 1, 926, 13, 926, 0, 0, '928', 0, '/gru9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (929, 1, 928, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (930, 1, 928, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 926);

insert into Users_Orgs (organizationId, userId) values (22, 926);
insert into Users_Orgs (organizationId, userId) values (66, 926);

insert into Users_Roles (roleId, userId) values (18, 926);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (931, 928, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 926, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e5e90b02-e96f-4dcd-9bc3-b6f7f4b20963', 932, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 933, 'test', 'F', 'F', 'gru10', 'test.gru.10@liferay.com', 'Welcome Test GRU 10!', 'Test', '', 'GRU 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (933, 1, 2, 'Test GRU 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 932, 7, 0, 'test.gru.10@liferay.com', 'Test', '', 'GRU 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (934, 1, 932, 13, 932, 0, 0, '934', 0, '/gru10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (935, 1, 934, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (936, 1, 934, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 932);

insert into Users_Orgs (organizationId, userId) values (22, 932);
insert into Users_Orgs (organizationId, userId) values (66, 932);

insert into Users_Roles (roleId, userId) values (18, 932);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (937, 934, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 932, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test GRU 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('666ce65b-2ef1-43ae-9d0e-00eaeb766301', 938, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 939, 'test', 'F', 'F', 'fra1', 'test.fra.1@liferay.com', 'Welcome Test FRA 1!', 'Test', '', 'FRA 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (939, 1, 2, 'Test FRA 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 938, 7, 0, 'test.fra.1@liferay.com', 'Test', '', 'FRA 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (940, 1, 938, 13, 938, 0, 0, '940', 0, '/fra1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (941, 1, 940, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (942, 1, 940, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 938);

insert into Users_Orgs (organizationId, userId) values (22, 938);
insert into Users_Orgs (organizationId, userId) values (70, 938);

insert into Users_Roles (roleId, userId) values (18, 938);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (943, 940, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 938, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('928261f0-677c-4673-b31e-248915705271', 944, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 945, 'test', 'F', 'F', 'fra2', 'test.fra.2@liferay.com', 'Welcome Test FRA 2!', 'Test', '', 'FRA 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (945, 1, 2, 'Test FRA 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 944, 7, 0, 'test.fra.2@liferay.com', 'Test', '', 'FRA 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (946, 1, 944, 13, 944, 0, 0, '946', 0, '/fra2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (947, 1, 946, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (948, 1, 946, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 944);

insert into Users_Orgs (organizationId, userId) values (22, 944);
insert into Users_Orgs (organizationId, userId) values (70, 944);

insert into Users_Roles (roleId, userId) values (18, 944);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (949, 946, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 944, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('b41d4bac-a0a6-48a3-9996-b0c5b61a7a8c', 950, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 951, 'test', 'F', 'F', 'fra3', 'test.fra.3@liferay.com', 'Welcome Test FRA 3!', 'Test', '', 'FRA 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (951, 1, 2, 'Test FRA 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 950, 7, 0, 'test.fra.3@liferay.com', 'Test', '', 'FRA 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (952, 1, 950, 13, 950, 0, 0, '952', 0, '/fra3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (953, 1, 952, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (954, 1, 952, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 950);

insert into Users_Orgs (organizationId, userId) values (22, 950);
insert into Users_Orgs (organizationId, userId) values (70, 950);

insert into Users_Roles (roleId, userId) values (18, 950);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (955, 952, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 950, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ba75a7a0-7ea2-43d1-b2c8-a02d1ce763d8', 956, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 957, 'test', 'F', 'F', 'fra4', 'test.fra.4@liferay.com', 'Welcome Test FRA 4!', 'Test', '', 'FRA 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (957, 1, 2, 'Test FRA 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 956, 7, 0, 'test.fra.4@liferay.com', 'Test', '', 'FRA 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (958, 1, 956, 13, 956, 0, 0, '958', 0, '/fra4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (959, 1, 958, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (960, 1, 958, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 956);

insert into Users_Orgs (organizationId, userId) values (22, 956);
insert into Users_Orgs (organizationId, userId) values (70, 956);

insert into Users_Roles (roleId, userId) values (18, 956);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (961, 958, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 956, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('42989ed3-cde6-43ec-9cc5-bd63e7d03167', 962, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 963, 'test', 'F', 'F', 'fra5', 'test.fra.5@liferay.com', 'Welcome Test FRA 5!', 'Test', '', 'FRA 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (963, 1, 2, 'Test FRA 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 962, 7, 0, 'test.fra.5@liferay.com', 'Test', '', 'FRA 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (964, 1, 962, 13, 962, 0, 0, '964', 0, '/fra5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (965, 1, 964, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (966, 1, 964, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 962);

insert into Users_Orgs (organizationId, userId) values (22, 962);
insert into Users_Orgs (organizationId, userId) values (70, 962);

insert into Users_Roles (roleId, userId) values (18, 962);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (967, 964, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 962, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('a02b3a71-c9c0-429b-8230-6061d2266693', 968, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 969, 'test', 'F', 'F', 'fra6', 'test.fra.6@liferay.com', 'Welcome Test FRA 6!', 'Test', '', 'FRA 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (969, 1, 2, 'Test FRA 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 968, 7, 0, 'test.fra.6@liferay.com', 'Test', '', 'FRA 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (970, 1, 968, 13, 968, 0, 0, '970', 0, '/fra6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (971, 1, 970, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (972, 1, 970, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 968);

insert into Users_Orgs (organizationId, userId) values (22, 968);
insert into Users_Orgs (organizationId, userId) values (70, 968);

insert into Users_Roles (roleId, userId) values (18, 968);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (973, 970, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 968, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('d58df1d5-432a-408e-8e92-0ce8e65a852b', 974, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 975, 'test', 'F', 'F', 'fra7', 'test.fra.7@liferay.com', 'Welcome Test FRA 7!', 'Test', '', 'FRA 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (975, 1, 2, 'Test FRA 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 974, 7, 0, 'test.fra.7@liferay.com', 'Test', '', 'FRA 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (976, 1, 974, 13, 974, 0, 0, '976', 0, '/fra7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (977, 1, 976, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (978, 1, 976, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 974);

insert into Users_Orgs (organizationId, userId) values (22, 974);
insert into Users_Orgs (organizationId, userId) values (70, 974);

insert into Users_Roles (roleId, userId) values (18, 974);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (979, 976, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 974, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('b1e3fea5-0b30-4d3b-a364-36bc86338c1c', 980, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 981, 'test', 'F', 'F', 'fra8', 'test.fra.8@liferay.com', 'Welcome Test FRA 8!', 'Test', '', 'FRA 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (981, 1, 2, 'Test FRA 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 980, 7, 0, 'test.fra.8@liferay.com', 'Test', '', 'FRA 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (982, 1, 980, 13, 980, 0, 0, '982', 0, '/fra8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (983, 1, 982, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (984, 1, 982, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 980);

insert into Users_Orgs (organizationId, userId) values (22, 980);
insert into Users_Orgs (organizationId, userId) values (70, 980);

insert into Users_Roles (roleId, userId) values (18, 980);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (985, 982, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 980, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('2a8a17d6-def1-4d65-9b9c-bb01183ee098', 986, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 987, 'test', 'F', 'F', 'fra9', 'test.fra.9@liferay.com', 'Welcome Test FRA 9!', 'Test', '', 'FRA 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (987, 1, 2, 'Test FRA 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 986, 7, 0, 'test.fra.9@liferay.com', 'Test', '', 'FRA 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (988, 1, 986, 13, 986, 0, 0, '988', 0, '/fra9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (989, 1, 988, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (990, 1, 988, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 986);

insert into Users_Orgs (organizationId, userId) values (22, 986);
insert into Users_Orgs (organizationId, userId) values (70, 986);

insert into Users_Roles (roleId, userId) values (18, 986);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (991, 988, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 986, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('6620c883-9095-4698-8f7d-e26d4921aac3', 992, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 993, 'test', 'F', 'F', 'fra10', 'test.fra.10@liferay.com', 'Welcome Test FRA 10!', 'Test', '', 'FRA 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (993, 1, 2, 'Test FRA 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 992, 7, 0, 'test.fra.10@liferay.com', 'Test', '', 'FRA 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (994, 1, 992, 13, 992, 0, 0, '994', 0, '/fra10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (995, 1, 994, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (996, 1, 994, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 992);

insert into Users_Orgs (organizationId, userId) values (22, 992);
insert into Users_Orgs (organizationId, userId) values (70, 992);

insert into Users_Roles (roleId, userId) values (18, 992);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (997, 994, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 992, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test FRA 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('c743eaf8-6555-413e-9746-d52de12663b5', 998, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 999, 'test', 'F', 'F', 'mad1', 'test.mad.1@liferay.com', 'Welcome Test MAD 1!', 'Test', '', 'MAD 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (999, 1, 2, 'Test MAD 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 998, 7, 0, 'test.mad.1@liferay.com', 'Test', '', 'MAD 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1000, 1, 998, 13, 998, 0, 0, '1000', 0, '/mad1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1001, 1, 1000, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1002, 1, 1000, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 998);

insert into Users_Orgs (organizationId, userId) values (22, 998);
insert into Users_Orgs (organizationId, userId) values (74, 998);

insert into Users_Roles (roleId, userId) values (18, 998);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1003, 1000, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 998, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('3f2a6e57-dabf-4bb8-8f37-ce8ae48b7375', 1004, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1005, 'test', 'F', 'F', 'mad2', 'test.mad.2@liferay.com', 'Welcome Test MAD 2!', 'Test', '', 'MAD 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1005, 1, 2, 'Test MAD 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1004, 7, 0, 'test.mad.2@liferay.com', 'Test', '', 'MAD 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1006, 1, 1004, 13, 1004, 0, 0, '1006', 0, '/mad2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1007, 1, 1006, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1008, 1, 1006, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1004);

insert into Users_Orgs (organizationId, userId) values (22, 1004);
insert into Users_Orgs (organizationId, userId) values (74, 1004);

insert into Users_Roles (roleId, userId) values (18, 1004);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1009, 1006, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1004, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('5ab5883a-ee4a-47ee-89f1-d8f6817d4d04', 1010, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1011, 'test', 'F', 'F', 'mad3', 'test.mad.3@liferay.com', 'Welcome Test MAD 3!', 'Test', '', 'MAD 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1011, 1, 2, 'Test MAD 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1010, 7, 0, 'test.mad.3@liferay.com', 'Test', '', 'MAD 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1012, 1, 1010, 13, 1010, 0, 0, '1012', 0, '/mad3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1013, 1, 1012, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1014, 1, 1012, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1010);

insert into Users_Orgs (organizationId, userId) values (22, 1010);
insert into Users_Orgs (organizationId, userId) values (74, 1010);

insert into Users_Roles (roleId, userId) values (18, 1010);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1015, 1012, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1010, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('0137048c-813c-49c9-9322-321497e01736', 1016, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1017, 'test', 'F', 'F', 'mad4', 'test.mad.4@liferay.com', 'Welcome Test MAD 4!', 'Test', '', 'MAD 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1017, 1, 2, 'Test MAD 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1016, 7, 0, 'test.mad.4@liferay.com', 'Test', '', 'MAD 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1018, 1, 1016, 13, 1016, 0, 0, '1018', 0, '/mad4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1019, 1, 1018, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1020, 1, 1018, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1016);

insert into Users_Orgs (organizationId, userId) values (22, 1016);
insert into Users_Orgs (organizationId, userId) values (74, 1016);

insert into Users_Roles (roleId, userId) values (18, 1016);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1021, 1018, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1016, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('c0397d8f-f14d-49af-ab55-bd39847323c3', 1022, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1023, 'test', 'F', 'F', 'mad5', 'test.mad.5@liferay.com', 'Welcome Test MAD 5!', 'Test', '', 'MAD 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1023, 1, 2, 'Test MAD 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1022, 7, 0, 'test.mad.5@liferay.com', 'Test', '', 'MAD 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1024, 1, 1022, 13, 1022, 0, 0, '1024', 0, '/mad5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1025, 1, 1024, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1026, 1, 1024, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1022);

insert into Users_Orgs (organizationId, userId) values (22, 1022);
insert into Users_Orgs (organizationId, userId) values (74, 1022);

insert into Users_Roles (roleId, userId) values (18, 1022);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1027, 1024, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1022, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('7b22d3f7-96e5-48e2-ad1a-9b1c35a8707d', 1028, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1029, 'test', 'F', 'F', 'mad6', 'test.mad.6@liferay.com', 'Welcome Test MAD 6!', 'Test', '', 'MAD 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1029, 1, 2, 'Test MAD 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1028, 7, 0, 'test.mad.6@liferay.com', 'Test', '', 'MAD 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1030, 1, 1028, 13, 1028, 0, 0, '1030', 0, '/mad6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1031, 1, 1030, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1032, 1, 1030, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1028);

insert into Users_Orgs (organizationId, userId) values (22, 1028);
insert into Users_Orgs (organizationId, userId) values (74, 1028);

insert into Users_Roles (roleId, userId) values (18, 1028);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1033, 1030, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1028, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('8c4e9bcc-caba-42b0-ad26-9e411dea525b', 1034, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1035, 'test', 'F', 'F', 'mad7', 'test.mad.7@liferay.com', 'Welcome Test MAD 7!', 'Test', '', 'MAD 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1035, 1, 2, 'Test MAD 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1034, 7, 0, 'test.mad.7@liferay.com', 'Test', '', 'MAD 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1036, 1, 1034, 13, 1034, 0, 0, '1036', 0, '/mad7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1037, 1, 1036, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1038, 1, 1036, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1034);

insert into Users_Orgs (organizationId, userId) values (22, 1034);
insert into Users_Orgs (organizationId, userId) values (74, 1034);

insert into Users_Roles (roleId, userId) values (18, 1034);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1039, 1036, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1034, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('cbba7200-7287-4dcc-a4f4-680ce92fad21', 1040, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1041, 'test', 'F', 'F', 'mad8', 'test.mad.8@liferay.com', 'Welcome Test MAD 8!', 'Test', '', 'MAD 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1041, 1, 2, 'Test MAD 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1040, 7, 0, 'test.mad.8@liferay.com', 'Test', '', 'MAD 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1042, 1, 1040, 13, 1040, 0, 0, '1042', 0, '/mad8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1043, 1, 1042, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1044, 1, 1042, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1040);

insert into Users_Orgs (organizationId, userId) values (22, 1040);
insert into Users_Orgs (organizationId, userId) values (74, 1040);

insert into Users_Roles (roleId, userId) values (18, 1040);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1045, 1042, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1040, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('1848c6d4-5668-43e2-95c5-a2524443ee26', 1046, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1047, 'test', 'F', 'F', 'mad9', 'test.mad.9@liferay.com', 'Welcome Test MAD 9!', 'Test', '', 'MAD 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1047, 1, 2, 'Test MAD 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1046, 7, 0, 'test.mad.9@liferay.com', 'Test', '', 'MAD 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1048, 1, 1046, 13, 1046, 0, 0, '1048', 0, '/mad9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1049, 1, 1048, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1050, 1, 1048, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1046);

insert into Users_Orgs (organizationId, userId) values (22, 1046);
insert into Users_Orgs (organizationId, userId) values (74, 1046);

insert into Users_Roles (roleId, userId) values (18, 1046);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1051, 1048, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1046, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('501cf323-6c08-49a3-893e-9149cbd6b61a', 1052, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1053, 'test', 'F', 'F', 'mad10', 'test.mad.10@liferay.com', 'Welcome Test MAD 10!', 'Test', '', 'MAD 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1053, 1, 2, 'Test MAD 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1052, 7, 0, 'test.mad.10@liferay.com', 'Test', '', 'MAD 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1054, 1, 1052, 13, 1052, 0, 0, '1054', 0, '/mad10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1055, 1, 1054, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1056, 1, 1054, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1052);

insert into Users_Orgs (organizationId, userId) values (22, 1052);
insert into Users_Orgs (organizationId, userId) values (74, 1052);

insert into Users_Roles (roleId, userId) values (18, 1052);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1057, 1054, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1052, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test MAD 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('211a698a-639b-4a83-ac6c-e114d7dbc806', 1058, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1059, 'test', 'F', 'F', 'dlc1', 'test.dlc.1@liferay.com', 'Welcome Test DLC 1!', 'Test', '', 'DLC 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1059, 1, 2, 'Test DLC 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1058, 7, 0, 'test.dlc.1@liferay.com', 'Test', '', 'DLC 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1060, 1, 1058, 13, 1058, 0, 0, '1060', 0, '/dlc1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1061, 1, 1060, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1062, 1, 1060, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1058);

insert into Users_Orgs (organizationId, userId) values (22, 1058);
insert into Users_Orgs (organizationId, userId) values (78, 1058);

insert into Users_Roles (roleId, userId) values (18, 1058);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1063, 1060, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1058, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('8de1efaf-b16a-46cc-85f8-50e6bc8b3ac7', 1064, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1065, 'test', 'F', 'F', 'dlc2', 'test.dlc.2@liferay.com', 'Welcome Test DLC 2!', 'Test', '', 'DLC 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1065, 1, 2, 'Test DLC 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1064, 7, 0, 'test.dlc.2@liferay.com', 'Test', '', 'DLC 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1066, 1, 1064, 13, 1064, 0, 0, '1066', 0, '/dlc2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1067, 1, 1066, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1068, 1, 1066, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1064);

insert into Users_Orgs (organizationId, userId) values (22, 1064);
insert into Users_Orgs (organizationId, userId) values (78, 1064);

insert into Users_Roles (roleId, userId) values (18, 1064);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1069, 1066, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1064, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('b232780b-0652-4211-bb35-3fbe0cf49c4b', 1070, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1071, 'test', 'F', 'F', 'dlc3', 'test.dlc.3@liferay.com', 'Welcome Test DLC 3!', 'Test', '', 'DLC 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1071, 1, 2, 'Test DLC 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1070, 7, 0, 'test.dlc.3@liferay.com', 'Test', '', 'DLC 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1072, 1, 1070, 13, 1070, 0, 0, '1072', 0, '/dlc3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1073, 1, 1072, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1074, 1, 1072, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1070);

insert into Users_Orgs (organizationId, userId) values (22, 1070);
insert into Users_Orgs (organizationId, userId) values (78, 1070);

insert into Users_Roles (roleId, userId) values (18, 1070);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1075, 1072, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1070, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('093af6ef-8eb8-4d0b-aed0-97d265b10401', 1076, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1077, 'test', 'F', 'F', 'dlc4', 'test.dlc.4@liferay.com', 'Welcome Test DLC 4!', 'Test', '', 'DLC 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1077, 1, 2, 'Test DLC 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1076, 7, 0, 'test.dlc.4@liferay.com', 'Test', '', 'DLC 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1078, 1, 1076, 13, 1076, 0, 0, '1078', 0, '/dlc4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1079, 1, 1078, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1080, 1, 1078, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1076);

insert into Users_Orgs (organizationId, userId) values (22, 1076);
insert into Users_Orgs (organizationId, userId) values (78, 1076);

insert into Users_Roles (roleId, userId) values (18, 1076);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1081, 1078, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1076, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('899ef889-f2c6-4ea0-828f-507ab157d1a1', 1082, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1083, 'test', 'F', 'F', 'dlc5', 'test.dlc.5@liferay.com', 'Welcome Test DLC 5!', 'Test', '', 'DLC 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1083, 1, 2, 'Test DLC 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1082, 7, 0, 'test.dlc.5@liferay.com', 'Test', '', 'DLC 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1084, 1, 1082, 13, 1082, 0, 0, '1084', 0, '/dlc5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1085, 1, 1084, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1086, 1, 1084, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1082);

insert into Users_Orgs (organizationId, userId) values (22, 1082);
insert into Users_Orgs (organizationId, userId) values (78, 1082);

insert into Users_Roles (roleId, userId) values (18, 1082);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1087, 1084, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1082, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e3553aef-b30e-4046-92af-1dd6f4507f6c', 1088, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1089, 'test', 'F', 'F', 'dlc6', 'test.dlc.6@liferay.com', 'Welcome Test DLC 6!', 'Test', '', 'DLC 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1089, 1, 2, 'Test DLC 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1088, 7, 0, 'test.dlc.6@liferay.com', 'Test', '', 'DLC 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1090, 1, 1088, 13, 1088, 0, 0, '1090', 0, '/dlc6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1091, 1, 1090, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1092, 1, 1090, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1088);

insert into Users_Orgs (organizationId, userId) values (22, 1088);
insert into Users_Orgs (organizationId, userId) values (78, 1088);

insert into Users_Roles (roleId, userId) values (18, 1088);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1093, 1090, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1088, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ed347dd5-8f15-4a8f-9d45-5b2fdb66a24a', 1094, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1095, 'test', 'F', 'F', 'dlc7', 'test.dlc.7@liferay.com', 'Welcome Test DLC 7!', 'Test', '', 'DLC 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1095, 1, 2, 'Test DLC 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1094, 7, 0, 'test.dlc.7@liferay.com', 'Test', '', 'DLC 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1096, 1, 1094, 13, 1094, 0, 0, '1096', 0, '/dlc7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1097, 1, 1096, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1098, 1, 1096, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1094);

insert into Users_Orgs (organizationId, userId) values (22, 1094);
insert into Users_Orgs (organizationId, userId) values (78, 1094);

insert into Users_Roles (roleId, userId) values (18, 1094);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1099, 1096, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1094, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('cfd44770-5541-4d7c-acde-4b099730a030', 1100, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1101, 'test', 'F', 'F', 'dlc8', 'test.dlc.8@liferay.com', 'Welcome Test DLC 8!', 'Test', '', 'DLC 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1101, 1, 2, 'Test DLC 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1100, 7, 0, 'test.dlc.8@liferay.com', 'Test', '', 'DLC 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1102, 1, 1100, 13, 1100, 0, 0, '1102', 0, '/dlc8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1103, 1, 1102, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1104, 1, 1102, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1100);

insert into Users_Orgs (organizationId, userId) values (22, 1100);
insert into Users_Orgs (organizationId, userId) values (78, 1100);

insert into Users_Roles (roleId, userId) values (18, 1100);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1105, 1102, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1100, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('ed901a8b-c9b5-4cc3-9e2d-15a1f57a933c', 1106, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1107, 'test', 'F', 'F', 'dlc9', 'test.dlc.9@liferay.com', 'Welcome Test DLC 9!', 'Test', '', 'DLC 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1107, 1, 2, 'Test DLC 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1106, 7, 0, 'test.dlc.9@liferay.com', 'Test', '', 'DLC 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1108, 1, 1106, 13, 1106, 0, 0, '1108', 0, '/dlc9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1109, 1, 1108, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1110, 1, 1108, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1106);

insert into Users_Orgs (organizationId, userId) values (22, 1106);
insert into Users_Orgs (organizationId, userId) values (78, 1106);

insert into Users_Roles (roleId, userId) values (18, 1106);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1111, 1108, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1106, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('132b32c2-79cf-4841-b1a6-df5aea89327d', 1112, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1113, 'test', 'F', 'F', 'dlc10', 'test.dlc.10@liferay.com', 'Welcome Test DLC 10!', 'Test', '', 'DLC 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1113, 1, 2, 'Test DLC 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1112, 7, 0, 'test.dlc.10@liferay.com', 'Test', '', 'DLC 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1114, 1, 1112, 13, 1112, 0, 0, '1114', 0, '/dlc10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1115, 1, 1114, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1116, 1, 1114, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1112);

insert into Users_Orgs (organizationId, userId) values (22, 1112);
insert into Users_Orgs (organizationId, userId) values (78, 1112);

insert into Users_Roles (roleId, userId) values (18, 1112);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1117, 1114, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1112, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test DLC 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('cdc8a09b-9dcb-4b53-9ac5-bbcea424c963', 1118, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1119, 'test', 'F', 'F', 'hkg1', 'test.hkg.1@liferay.com', 'Welcome Test HKG 1!', 'Test', '', 'HKG 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1119, 1, 2, 'Test HKG 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1118, 7, 0, 'test.hkg.1@liferay.com', 'Test', '', 'HKG 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1120, 1, 1118, 13, 1118, 0, 0, '1120', 0, '/hkg1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1121, 1, 1120, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1122, 1, 1120, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1118);

insert into Users_Orgs (organizationId, userId) values (22, 1118);
insert into Users_Orgs (organizationId, userId) values (82, 1118);

insert into Users_Roles (roleId, userId) values (18, 1118);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1123, 1120, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1118, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('832871e9-7bf2-48ee-a605-900301730446', 1124, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1125, 'test', 'F', 'F', 'hkg2', 'test.hkg.2@liferay.com', 'Welcome Test HKG 2!', 'Test', '', 'HKG 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1125, 1, 2, 'Test HKG 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1124, 7, 0, 'test.hkg.2@liferay.com', 'Test', '', 'HKG 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1126, 1, 1124, 13, 1124, 0, 0, '1126', 0, '/hkg2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1127, 1, 1126, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1128, 1, 1126, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1124);

insert into Users_Orgs (organizationId, userId) values (22, 1124);
insert into Users_Orgs (organizationId, userId) values (82, 1124);

insert into Users_Roles (roleId, userId) values (18, 1124);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1129, 1126, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1124, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('a6d04c7f-4045-4a4a-b0b9-a0c4b7a8160c', 1130, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1131, 'test', 'F', 'F', 'hkg3', 'test.hkg.3@liferay.com', 'Welcome Test HKG 3!', 'Test', '', 'HKG 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1131, 1, 2, 'Test HKG 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1130, 7, 0, 'test.hkg.3@liferay.com', 'Test', '', 'HKG 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1132, 1, 1130, 13, 1130, 0, 0, '1132', 0, '/hkg3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1133, 1, 1132, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1134, 1, 1132, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1130);

insert into Users_Orgs (organizationId, userId) values (22, 1130);
insert into Users_Orgs (organizationId, userId) values (82, 1130);

insert into Users_Roles (roleId, userId) values (18, 1130);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1135, 1132, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1130, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('f397d364-fa95-4244-ad3e-1ac325e908a6', 1136, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1137, 'test', 'F', 'F', 'hkg4', 'test.hkg.4@liferay.com', 'Welcome Test HKG 4!', 'Test', '', 'HKG 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1137, 1, 2, 'Test HKG 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1136, 7, 0, 'test.hkg.4@liferay.com', 'Test', '', 'HKG 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1138, 1, 1136, 13, 1136, 0, 0, '1138', 0, '/hkg4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1139, 1, 1138, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1140, 1, 1138, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1136);

insert into Users_Orgs (organizationId, userId) values (22, 1136);
insert into Users_Orgs (organizationId, userId) values (82, 1136);

insert into Users_Roles (roleId, userId) values (18, 1136);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1141, 1138, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1136, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e3326777-2324-4702-80f9-85a6a9c0b7c0', 1142, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1143, 'test', 'F', 'F', 'hkg5', 'test.hkg.5@liferay.com', 'Welcome Test HKG 5!', 'Test', '', 'HKG 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1143, 1, 2, 'Test HKG 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1142, 7, 0, 'test.hkg.5@liferay.com', 'Test', '', 'HKG 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1144, 1, 1142, 13, 1142, 0, 0, '1144', 0, '/hkg5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1145, 1, 1144, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1146, 1, 1144, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1142);

insert into Users_Orgs (organizationId, userId) values (22, 1142);
insert into Users_Orgs (organizationId, userId) values (82, 1142);

insert into Users_Roles (roleId, userId) values (18, 1142);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1147, 1144, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1142, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('92d5276e-8480-4f3b-aacc-4794981b8529', 1148, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1149, 'test', 'F', 'F', 'hkg6', 'test.hkg.6@liferay.com', 'Welcome Test HKG 6!', 'Test', '', 'HKG 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1149, 1, 2, 'Test HKG 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1148, 7, 0, 'test.hkg.6@liferay.com', 'Test', '', 'HKG 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1150, 1, 1148, 13, 1148, 0, 0, '1150', 0, '/hkg6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1151, 1, 1150, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1152, 1, 1150, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1148);

insert into Users_Orgs (organizationId, userId) values (22, 1148);
insert into Users_Orgs (organizationId, userId) values (82, 1148);

insert into Users_Roles (roleId, userId) values (18, 1148);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1153, 1150, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1148, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('86a91c6c-4655-4122-917b-f3bf83290ba1', 1154, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1155, 'test', 'F', 'F', 'hkg7', 'test.hkg.7@liferay.com', 'Welcome Test HKG 7!', 'Test', '', 'HKG 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1155, 1, 2, 'Test HKG 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1154, 7, 0, 'test.hkg.7@liferay.com', 'Test', '', 'HKG 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1156, 1, 1154, 13, 1154, 0, 0, '1156', 0, '/hkg7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1157, 1, 1156, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1158, 1, 1156, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1154);

insert into Users_Orgs (organizationId, userId) values (22, 1154);
insert into Users_Orgs (organizationId, userId) values (82, 1154);

insert into Users_Roles (roleId, userId) values (18, 1154);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1159, 1156, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1154, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('7b87ab15-ebff-4996-9826-492f87e4f5b7', 1160, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1161, 'test', 'F', 'F', 'hkg8', 'test.hkg.8@liferay.com', 'Welcome Test HKG 8!', 'Test', '', 'HKG 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1161, 1, 2, 'Test HKG 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1160, 7, 0, 'test.hkg.8@liferay.com', 'Test', '', 'HKG 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1162, 1, 1160, 13, 1160, 0, 0, '1162', 0, '/hkg8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1163, 1, 1162, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1164, 1, 1162, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1160);

insert into Users_Orgs (organizationId, userId) values (22, 1160);
insert into Users_Orgs (organizationId, userId) values (82, 1160);

insert into Users_Roles (roleId, userId) values (18, 1160);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1165, 1162, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1160, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('1596d311-65fc-47e4-b027-317303aed222', 1166, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1167, 'test', 'F', 'F', 'hkg9', 'test.hkg.9@liferay.com', 'Welcome Test HKG 9!', 'Test', '', 'HKG 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1167, 1, 2, 'Test HKG 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1166, 7, 0, 'test.hkg.9@liferay.com', 'Test', '', 'HKG 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1168, 1, 1166, 13, 1166, 0, 0, '1168', 0, '/hkg9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1169, 1, 1168, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1170, 1, 1168, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1166);

insert into Users_Orgs (organizationId, userId) values (22, 1166);
insert into Users_Orgs (organizationId, userId) values (82, 1166);

insert into Users_Roles (roleId, userId) values (18, 1166);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1171, 1168, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1166, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('9a910c00-da60-4d87-a8e9-acd72c92c909', 1172, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1173, 'test', 'F', 'F', 'hkg10', 'test.hkg.10@liferay.com', 'Welcome Test HKG 10!', 'Test', '', 'HKG 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1173, 1, 2, 'Test HKG 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1172, 7, 0, 'test.hkg.10@liferay.com', 'Test', '', 'HKG 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1174, 1, 1172, 13, 1172, 0, 0, '1174', 0, '/hkg10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1175, 1, 1174, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1176, 1, 1174, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1172);

insert into Users_Orgs (organizationId, userId) values (22, 1172);
insert into Users_Orgs (organizationId, userId) values (82, 1172);

insert into Users_Roles (roleId, userId) values (18, 1172);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1177, 1174, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1172, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test HKG 10', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('9955ee06-aa8a-490f-beaa-b226f2bc0575', 1178, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1179, 'test', 'F', 'F', 'kul1', 'test.kul.1@liferay.com', 'Welcome Test KUL 1!', 'Test', '', 'KUL 1', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1179, 1, 2, 'Test KUL 1', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1178, 7, 0, 'test.kul.1@liferay.com', 'Test', '', 'KUL 1', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1180, 1, 1178, 13, 1178, 0, 0, '1180', 0, '/kul1', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1181, 1, 1180, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1182, 1, 1180, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1178);

insert into Users_Orgs (organizationId, userId) values (22, 1178);
insert into Users_Orgs (organizationId, userId) values (86, 1178);

insert into Users_Roles (roleId, userId) values (18, 1178);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1183, 1180, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1178, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 1', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('6b370aeb-c9a6-4314-afa0-804ea36a8f24', 1184, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1185, 'test', 'F', 'F', 'kul2', 'test.kul.2@liferay.com', 'Welcome Test KUL 2!', 'Test', '', 'KUL 2', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1185, 1, 2, 'Test KUL 2', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1184, 7, 0, 'test.kul.2@liferay.com', 'Test', '', 'KUL 2', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1186, 1, 1184, 13, 1184, 0, 0, '1186', 0, '/kul2', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1187, 1, 1186, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1188, 1, 1186, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1184);

insert into Users_Orgs (organizationId, userId) values (22, 1184);
insert into Users_Orgs (organizationId, userId) values (86, 1184);

insert into Users_Roles (roleId, userId) values (18, 1184);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1189, 1186, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1184, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 2', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('94465865-a47d-4cd1-8ce2-66359549bab4', 1190, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1191, 'test', 'F', 'F', 'kul3', 'test.kul.3@liferay.com', 'Welcome Test KUL 3!', 'Test', '', 'KUL 3', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1191, 1, 2, 'Test KUL 3', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1190, 7, 0, 'test.kul.3@liferay.com', 'Test', '', 'KUL 3', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1192, 1, 1190, 13, 1190, 0, 0, '1192', 0, '/kul3', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1193, 1, 1192, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1194, 1, 1192, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1190);

insert into Users_Orgs (organizationId, userId) values (22, 1190);
insert into Users_Orgs (organizationId, userId) values (86, 1190);

insert into Users_Roles (roleId, userId) values (18, 1190);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1195, 1192, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1190, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 3', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('426b9f67-507a-4dac-9335-451f078df602', 1196, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1197, 'test', 'F', 'F', 'kul4', 'test.kul.4@liferay.com', 'Welcome Test KUL 4!', 'Test', '', 'KUL 4', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1197, 1, 2, 'Test KUL 4', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1196, 7, 0, 'test.kul.4@liferay.com', 'Test', '', 'KUL 4', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1198, 1, 1196, 13, 1196, 0, 0, '1198', 0, '/kul4', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1199, 1, 1198, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1200, 1, 1198, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1196);

insert into Users_Orgs (organizationId, userId) values (22, 1196);
insert into Users_Orgs (organizationId, userId) values (86, 1196);

insert into Users_Roles (roleId, userId) values (18, 1196);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1201, 1198, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1196, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 4', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('8fc062a7-f6f7-4a22-9dc8-dda23e47cf7a', 1202, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1203, 'test', 'F', 'F', 'kul5', 'test.kul.5@liferay.com', 'Welcome Test KUL 5!', 'Test', '', 'KUL 5', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1203, 1, 2, 'Test KUL 5', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1202, 7, 0, 'test.kul.5@liferay.com', 'Test', '', 'KUL 5', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1204, 1, 1202, 13, 1202, 0, 0, '1204', 0, '/kul5', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1205, 1, 1204, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1206, 1, 1204, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1202);

insert into Users_Orgs (organizationId, userId) values (22, 1202);
insert into Users_Orgs (organizationId, userId) values (86, 1202);

insert into Users_Roles (roleId, userId) values (18, 1202);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1207, 1204, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1202, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 5', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('92519aac-8bd3-4555-8fae-fa543a86863a', 1208, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1209, 'test', 'F', 'F', 'kul6', 'test.kul.6@liferay.com', 'Welcome Test KUL 6!', 'Test', '', 'KUL 6', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1209, 1, 2, 'Test KUL 6', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1208, 7, 0, 'test.kul.6@liferay.com', 'Test', '', 'KUL 6', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1210, 1, 1208, 13, 1208, 0, 0, '1210', 0, '/kul6', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1211, 1, 1210, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1212, 1, 1210, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1208);

insert into Users_Orgs (organizationId, userId) values (22, 1208);
insert into Users_Orgs (organizationId, userId) values (86, 1208);

insert into Users_Roles (roleId, userId) values (18, 1208);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1213, 1210, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1208, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 6', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('e70f60a3-550f-4531-92bb-773243207502', 1214, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1215, 'test', 'F', 'F', 'kul7', 'test.kul.7@liferay.com', 'Welcome Test KUL 7!', 'Test', '', 'KUL 7', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1215, 1, 2, 'Test KUL 7', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1214, 7, 0, 'test.kul.7@liferay.com', 'Test', '', 'KUL 7', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1216, 1, 1214, 13, 1214, 0, 0, '1216', 0, '/kul7', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1217, 1, 1216, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1218, 1, 1216, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1214);

insert into Users_Orgs (organizationId, userId) values (22, 1214);
insert into Users_Orgs (organizationId, userId) values (86, 1214);

insert into Users_Roles (roleId, userId) values (18, 1214);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1219, 1216, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1214, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 7', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('18ce56d8-ed8a-4e84-bc90-f42ff28497dc', 1220, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1221, 'test', 'F', 'F', 'kul8', 'test.kul.8@liferay.com', 'Welcome Test KUL 8!', 'Test', '', 'KUL 8', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1221, 1, 2, 'Test KUL 8', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1220, 7, 0, 'test.kul.8@liferay.com', 'Test', '', 'KUL 8', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1222, 1, 1220, 13, 1220, 0, 0, '1222', 0, '/kul8', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1223, 1, 1222, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1224, 1, 1222, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1220);

insert into Users_Orgs (organizationId, userId) values (22, 1220);
insert into Users_Orgs (organizationId, userId) values (86, 1220);

insert into Users_Roles (roleId, userId) values (18, 1220);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1225, 1222, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1220, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 8', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('9a043ff0-3b22-423f-98af-ca8be3b974f4', 1226, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1227, 'test', 'F', 'F', 'kul9', 'test.kul.9@liferay.com', 'Welcome Test KUL 9!', 'Test', '', 'KUL 9', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1227, 1, 2, 'Test KUL 9', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1226, 7, 0, 'test.kul.9@liferay.com', 'Test', '', 'KUL 9', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1228, 1, 1226, 13, 1226, 0, 0, '1228', 0, '/kul9', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1229, 1, 1228, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1230, 1, 1228, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1226);

insert into Users_Orgs (organizationId, userId) values (22, 1226);
insert into Users_Orgs (organizationId, userId) values (86, 1226);

insert into Users_Roles (roleId, userId) values (18, 1226);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1231, 1228, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1226, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 9', '', '', '', 0, 0, 0, 0, 0);

insert into User_ (uuid_, userId, companyId, createDate, modifiedDate, defaultUser, contactId, password_, passwordEncrypted, passwordReset, screenName, emailAddress, greeting, firstName, middleName, lastName, loginDate, failedLoginAttempts, agreedToTermsOfUse, status) values ('d7e85771-61c0-4918-8983-85b42256ec2c', 1232, 1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'F', 1233, 'test', 'F', 'F', 'kul10', 'test.kul.10@liferay.com', 'Welcome Test KUL 10!', 'Test', '', 'KUL 10', CURRENT YEAR TO FRACTION, 0, 'T', 0);

insert into Contact_ (contactId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, accountId, parentContactId, emailAddress, firstName, middleName, lastName, male, birthday) values (1233, 1, 2, 'Test KUL 10', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1232, 7, 0, 'test.kul.10@liferay.com', 'Test', '', 'KUL 10', 'T', '1970-01-01 00:00:00.0');

insert into Group_ (groupId, companyId, creatorUserId, classNameId, classPK, parentGroupId, liveGroupId, name, type_, friendlyURL, active_) values (1234, 1, 1232, 13, 1232, 0, 0, '1234', 0, '/kul10', 'T');

insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1235, 1, 1234, 'T', 'F', 'classic', '01', 0);
insert into LayoutSet (layoutSetId, companyId, groupId, privateLayout, logo, themeId, colorSchemeId, pageCount) values (1236, 1, 1234, 'F', 'F', 'classic', '01', 0);

insert into Users_Groups (groupId, userId) values (19, 1232);

insert into Users_Orgs (organizationId, userId) values (22, 1232);
insert into Users_Orgs (organizationId, userId) values (86, 1232);

insert into Users_Roles (roleId, userId) values (18, 1232);

insert into AssetEntry (entryId, groupId, companyId, userId, userName, createDate, modifiedDate, classNameId, classPK, classUuid, classTypeId, visible, startDate, endDate, publishDate, expirationDate, mimeType, title, description, summary, url, layoutUuid, height, width, priority, viewCount) VALUES (1237, 1234, 1, 2, 'Joe Bloggs', CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 13, 1232, '', 0, 'F', NULL, NULL, NULL, NULL, '', 'Test KUL 10', '', '', '', 0, 0, 0, 0, 0);












insert into Release_ (releaseId, createDate, modifiedDate, servletContextName, buildNumber, verified) values (1, CURRENT YEAR TO FRACTION, CURRENT YEAR TO FRACTION, 'portal', 6200, 'F');


create table QUARTZ_BLOB_TRIGGERS (
	SCHED_NAME varchar(120) not null,
	TRIGGER_NAME varchar(200) not null,
	TRIGGER_GROUP varchar(200) not null,
	BLOB_DATA blob,
	primary key (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_CALENDARS (
	SCHED_NAME varchar(120) not null,
	CALENDAR_NAME varchar(200) not null,
	CALENDAR blob not null,
	primary key (SCHED_NAME,CALENDAR_NAME)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_CRON_TRIGGERS (
	SCHED_NAME varchar(120) not null,
	TRIGGER_NAME varchar(200) not null,
	TRIGGER_GROUP varchar(200) not null,
	CRON_EXPRESSION varchar(200) not null,
	TIME_ZONE_ID varchar(80),
	primary key (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_FIRED_TRIGGERS (
	SCHED_NAME varchar(120) not null,
	ENTRY_ID varchar(95) not null,
	TRIGGER_NAME varchar(200) not null,
	TRIGGER_GROUP varchar(200) not null,
	INSTANCE_NAME varchar(200) not null,
	FIRED_TIME int8 not null,
	PRIORITY int not null,
	STATE varchar(16) not null,
	JOB_NAME varchar(200),
	JOB_GROUP varchar(200),
	IS_NONCONCURRENT boolean NULL,
	REQUESTS_RECOVERY boolean NULL,
	primary key (SCHED_NAME, ENTRY_ID)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_JOB_DETAILS (
	SCHED_NAME varchar(120) not null,
	JOB_NAME varchar(200) not null,
	JOB_GROUP varchar(200) not null,
	DESCRIPTION varchar(250),
	JOB_CLASS_NAME varchar(250) not null,
	IS_DURABLE boolean not null,
	IS_NONCONCURRENT boolean not null,
	IS_UPDATE_DATA boolean not null,
	REQUESTS_RECOVERY boolean not null,
	JOB_DATA blob,
	primary key (SCHED_NAME, JOB_NAME, JOB_GROUP)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_LOCKS (
	SCHED_NAME varchar(120) not null,
	LOCK_NAME varchar(40) not null ,
	primary key (SCHED_NAME, LOCK_NAME)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_PAUSED_TRIGGER_GRPS (
	SCHED_NAME varchar(120) not null,
	TRIGGER_GROUP varchar(200) not null,
	primary key (SCHED_NAME, TRIGGER_GROUP)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_SCHEDULER_STATE (
	SCHED_NAME varchar(120) not null,
	INSTANCE_NAME varchar(200) not null,
	LAST_CHECKIN_TIME int8 not null,
	CHECKIN_INTERVAL int8 not null,
	primary key (SCHED_NAME, INSTANCE_NAME)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_SIMPLE_TRIGGERS (
	SCHED_NAME varchar(120) not null,
	TRIGGER_NAME varchar(200) not null,
	TRIGGER_GROUP varchar(200) not null,
	REPEAT_COUNT int8 not null,
	REPEAT_INTERVAL int8 not null,
	TIMES_TRIGGERED int8 not null,
	primary key (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_SIMPROP_TRIGGERS (
	SCHED_NAME varchar(120) not null,
	TRIGGER_NAME varchar(200) not null,
	TRIGGER_GROUP varchar(200) not null,
	STR_PROP_1 varchar(512),
	STR_PROP_2 varchar(512),
	STR_PROP_3 varchar(512),
	INT_PROP_1 int,
	INT_PROP_2 int,
	LONG_PROP_1 int8,
	LONG_PROP_2 int8,
	DEC_PROP_1 NUMERIC(13,4),
	DEC_PROP_2 NUMERIC(13,4),
	BOOL_PROP_1 boolean,
	BOOL_PROP_2 boolean,
	primary key (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
)
extent size 16 next size 16
lock mode row;

create table QUARTZ_TRIGGERS (
	SCHED_NAME varchar(120) not null,
	TRIGGER_NAME varchar(200) not null,
	TRIGGER_GROUP varchar(200) not null,
	JOB_NAME varchar(200) not null,
	JOB_GROUP varchar(200) not null,
	DESCRIPTION varchar(250),
	NEXT_FIRE_TIME int8,
	PREV_FIRE_TIME int8,
	PRIORITY int,
	TRIGGER_STATE varchar(16) not null,
	TRIGGER_TYPE varchar(8) not null,
	START_TIME int8 not null,
	END_TIME int8,
	CALENDAR_NAME varchar(200),
	MISFIRE_INSTR int,
	JOB_DATA blob,
	primary key  (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP)
)
extent size 16 next size 16
lock mode row;



create index IX_88328984 on QUARTZ_JOB_DETAILS (SCHED_NAME, JOB_GROUP);
create index IX_779BCA37 on QUARTZ_JOB_DETAILS (SCHED_NAME, REQUESTS_RECOVERY);

create index IX_BE3835E5 on QUARTZ_FIRED_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP);
create index IX_4BD722BM on QUARTZ_FIRED_TRIGGERS (SCHED_NAME, TRIGGER_GROUP);
create index IX_204D31E8 on QUARTZ_FIRED_TRIGGERS (SCHED_NAME, INSTANCE_NAME);
create index IX_339E078M on QUARTZ_FIRED_TRIGGERS (SCHED_NAME, INSTANCE_NAME, REQUESTS_RECOVERY);
create index IX_5005E3AF on QUARTZ_FIRED_TRIGGERS (SCHED_NAME, JOB_NAME, JOB_GROUP);
create index IX_BC2F03B0 on QUARTZ_FIRED_TRIGGERS (SCHED_NAME, JOB_GROUP);

create index IX_186442A4 on QUARTZ_TRIGGERS (SCHED_NAME, TRIGGER_NAME, TRIGGER_GROUP, TRIGGER_STATE);
create index IX_1BA1F9DC on QUARTZ_TRIGGERS (SCHED_NAME, TRIGGER_GROUP);
create index IX_91CA7CCE on QUARTZ_TRIGGERS (SCHED_NAME, TRIGGER_GROUP, NEXT_FIRE_TIME, TRIGGER_STATE, MISFIRE_INSTR);
create index IX_D219AFDE on QUARTZ_TRIGGERS (SCHED_NAME, TRIGGER_GROUP, TRIGGER_STATE);
create index IX_A85822A0 on QUARTZ_TRIGGERS (SCHED_NAME, JOB_NAME, JOB_GROUP);
create index IX_8AA50BE1 on QUARTZ_TRIGGERS (SCHED_NAME, JOB_GROUP);
create index IX_EEFE382A on QUARTZ_TRIGGERS (SCHED_NAME, NEXT_FIRE_TIME);
create index IX_F026CF4C on QUARTZ_TRIGGERS (SCHED_NAME, NEXT_FIRE_TIME, TRIGGER_STATE);
create index IX_F2DD7C7E on QUARTZ_TRIGGERS (SCHED_NAME, NEXT_FIRE_TIME, TRIGGER_STATE, MISFIRE_INSTR);
create index IX_1F92813C on QUARTZ_TRIGGERS (SCHED_NAME, NEXT_FIRE_TIME, MISFIRE_INSTR);
create index IX_99108B6E on QUARTZ_TRIGGERS (SCHED_NAME, TRIGGER_STATE);
create index IX_CD7132D0 on QUARTZ_TRIGGERS (SCHED_NAME, CALENDAR_NAME);



